/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _Qt3DRenderAPI_H
#define _Qt3DRenderAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_0 0
#define sipName_0 &sipStrings_Qt3DRender[0]
#define sipNameNr_Qt3DRender__QPickingSettings__FaceOrientationPickingMode 58
#define sipName_Qt3DRender__QPickingSettings__FaceOrientationPickingMode &sipStrings_Qt3DRender[58]
#define sipNameNr_115 115
#define sipName_115 &sipStrings_Qt3DRender[115]
#define sipNameNr_170 170
#define sipName_170 &sipStrings_Qt3DRender[170]
#define sipNameNr_Qt3DRender__QStencilTestArguments__StencilFaceMode 222
#define sipName_Qt3DRender__QStencilTestArguments__StencilFaceMode &sipStrings_Qt3DRender[222]
#define sipNameNr_Qt3DRender__QStencilTestArguments__StencilFunction 273
#define sipName_Qt3DRender__QStencilTestArguments__StencilFunction &sipStrings_Qt3DRender[273]
#define sipNameNr_Qt3DRender__QBlitFramebuffer__InterpolationMethod 324
#define sipName_Qt3DRender__QBlitFramebuffer__InterpolationMethod &sipStrings_Qt3DRender[324]
#define sipNameNr_Qt3DRender__QStencilOperationArguments__Operation 374
#define sipName_Qt3DRender__QStencilOperationArguments__Operation &sipStrings_Qt3DRender[374]
#define sipNameNr_424 424
#define sipName_424 &sipStrings_Qt3DRender[424]
#define sipNameNr_Qt3DRender__QAbstractTexture__ComparisonFunction 473
#define sipName_Qt3DRender__QAbstractTexture__ComparisonFunction &sipStrings_Qt3DRender[473]
#define sipNameNr_Qt3DRender__QRenderTargetOutput__AttachmentPoint 522
#define sipName_Qt3DRender__QRenderTargetOutput__AttachmentPoint &sipStrings_Qt3DRender[522]
#define sipNameNr_Qt3DRender__QStencilOperationArguments__FaceMode 571
#define sipName_Qt3DRender__QStencilOperationArguments__FaceMode &sipStrings_Qt3DRender[571]
#define sipNameNr_620 620
#define sipName_620 &sipStrings_Qt3DRender[620]
#define sipNameNr_666 666
#define sipName_666 &sipStrings_Qt3DRender[666]
#define sipNameNr_Qt3DRender__QBlendEquationArguments__Blending 712
#define sipName_Qt3DRender__QBlendEquationArguments__Blending &sipStrings_Qt3DRender[712]
#define sipNameNr_Qt3DRender__QGraphicsApiFilter__OpenGLProfile 758
#define sipName_Qt3DRender__QGraphicsApiFilter__OpenGLProfile &sipStrings_Qt3DRender[758]
#define sipNameNr_804 804
#define sipName_804 &sipStrings_Qt3DRender[804]
#define sipNameNr_Qt3DRender__QAbstractTexture__ComparisonMode 849
#define sipName_Qt3DRender__QAbstractTexture__ComparisonMode &sipStrings_Qt3DRender[849]
#define sipNameNr_Qt3DRender__QCamera__CameraTranslationOption 894
#define sipName_Qt3DRender__QCamera__CameraTranslationOption &sipStrings_Qt3DRender[894]
#define sipNameNr_Qt3DRender__QGeometryRenderer__PrimitiveType 939
#define sipName_Qt3DRender__QGeometryRenderer__PrimitiveType &sipStrings_Qt3DRender[939]
#define sipNameNr_Qt3DRender__QPickingSettings__PickResultMode 984
#define sipName_Qt3DRender__QPickingSettings__PickResultMode &sipStrings_Qt3DRender[984]
#define sipNameNr_1029 1029
#define sipName_1029 &sipStrings_Qt3DRender[1029]
#define sipNameNr_Qt3DRender__QAbstractTexture__TextureFormat 1073
#define sipName_Qt3DRender__QAbstractTexture__TextureFormat &sipStrings_Qt3DRender[1073]
#define sipNameNr_1117 1117
#define sipName_1117 &sipStrings_Qt3DRender[1117]
#define sipNameNr_Qt3DRender__QAbstractRayCaster__FilterMode 1160
#define sipName_Qt3DRender__QAbstractRayCaster__FilterMode &sipStrings_Qt3DRender[1160]
#define sipNameNr_Qt3DRender__QClearBuffers__BufferTypeFlags 1203
#define sipName_Qt3DRender__QClearBuffers__BufferTypeFlags &sipStrings_Qt3DRender[1203]
#define sipNameNr_1246 1246
#define sipName_1246 &sipStrings_Qt3DRender[1246]
#define sipNameNr_1288 1288
#define sipName_1288 &sipStrings_Qt3DRender[1288]
#define sipNameNr_Qt3DRender__QAbstractTexture__CubeMapFace 1330
#define sipName_Qt3DRender__QAbstractTexture__CubeMapFace &sipStrings_Qt3DRender[1330]
#define sipNameNr_Qt3DRender__QBlendEquation__BlendFunction 1372
#define sipName_Qt3DRender__QBlendEquation__BlendFunction &sipStrings_Qt3DRender[1372]
#define sipNameNr_Qt3DRender__QLevelOfDetail__ThresholdType 1414
#define sipName_Qt3DRender__QLevelOfDetail__ThresholdType &sipStrings_Qt3DRender[1414]
#define sipNameNr_Qt3DRender__QRenderSettings__RenderPolicy 1456
#define sipName_Qt3DRender__QRenderSettings__RenderPolicy &sipStrings_Qt3DRender[1456]
#define sipNameNr_1498 1498
#define sipName_1498 &sipStrings_Qt3DRender[1498]
#define sipNameNr_Qt3DRender__QAbstractTexture__HandleType 1539
#define sipName_Qt3DRender__QAbstractTexture__HandleType &sipStrings_Qt3DRender[1539]
#define sipNameNr_Qt3DRender__QFrontFace__WindingDirection 1580
#define sipName_Qt3DRender__QFrontFace__WindingDirection &sipStrings_Qt3DRender[1580]
#define sipNameNr_Qt3DRender__QLevelOfDetailBoundingSphere 1621
#define sipName_Qt3DRender__QLevelOfDetailBoundingSphere &sipStrings_Qt3DRender[1621]
#define sipNameNr_Qt3DRender__QPickingSettings__PickMethod 1662
#define sipName_Qt3DRender__QPickingSettings__PickMethod &sipStrings_Qt3DRender[1662]
#define sipNameNr_Qt3DRender__QRenderCapabilities__Profile 1703
#define sipName_Qt3DRender__QRenderCapabilities__Profile &sipStrings_Qt3DRender[1703]
#define sipNameNr_tessellationEvaluationShaderGraphChanged 1744
#define sipName_tessellationEvaluationShaderGraphChanged &sipStrings_Qt3DRender[1744]
#define sipNameNr_Qt3DRender__QAbstractRayCaster__RunMode 1785
#define sipName_Qt3DRender__QAbstractRayCaster__RunMode &sipStrings_Qt3DRender[1785]
#define sipNameNr_Qt3DRender__QCameraLens__ProjectionType 1825
#define sipName_Qt3DRender__QCameraLens__ProjectionType &sipStrings_Qt3DRender[1825]
#define sipNameNr_Qt3DRender__QSceneLoader__ComponentType 1865
#define sipName_Qt3DRender__QSceneLoader__ComponentType &sipStrings_Qt3DRender[1865]
#define sipNameNr_Qt3DRender__QSubtreeEnabler__Enablement 1905
#define sipName_Qt3DRender__QSubtreeEnabler__Enablement &sipStrings_Qt3DRender[1905]
#define sipNameNr_tessellationEvaluationShaderCodeChanged 1945
#define sipName_tessellationEvaluationShaderCodeChanged &sipStrings_Qt3DRender[1945]
#define sipNameNr_Qt3DRender__QAttribute__VertexBaseType 1985
#define sipName_Qt3DRender__QAttribute__VertexBaseType &sipStrings_Qt3DRender[1985]
#define sipNameNr_Qt3DRender__QMemoryBarrier__Operations 2024
#define sipName_Qt3DRender__QMemoryBarrier__Operations &sipStrings_Qt3DRender[2024]
#define sipNameNr_Qt3DRender__QShaderProgram__ShaderType 2063
#define sipName_Qt3DRender__QShaderProgram__ShaderType &sipStrings_Qt3DRender[2063]
#define sipNameNr_Qt3DRender__QStencilOperationArguments 2102
#define sipName_Qt3DRender__QStencilOperationArguments &sipStrings_Qt3DRender[2102]
#define sipNameNr_Qt3DRender__QTexture2DMultisampleArray 2141
#define sipName_Qt3DRender__QTexture2DMultisampleArray &sipStrings_Qt3DRender[2141]
#define sipNameNr_Qt3DRender__QTextureImageDataGenerator 2180
#define sipName_Qt3DRender__QTextureImageDataGenerator &sipStrings_Qt3DRender[2180]
#define sipNameNr_Qt3DRender__QTextureWrapMode__WrapMode 2219
#define sipName_Qt3DRender__QTextureWrapMode__WrapMode &sipStrings_Qt3DRender[2219]
#define sipNameNr_boundingVolumePositionAttributeChanged 2258
#define sipName_boundingVolumePositionAttributeChanged &sipStrings_Qt3DRender[2258]
#define sipNameNr_defaultTextureCoordinate1AttributeName 2297
#define sipName_defaultTextureCoordinate1AttributeName &sipStrings_Qt3DRender[2297]
#define sipNameNr_defaultTextureCoordinate2AttributeName 2336
#define sipName_defaultTextureCoordinate2AttributeName &sipStrings_Qt3DRender[2336]
#define sipNameNr_Qt3DRender__QAlphaTest__AlphaFunction 2375
#define sipName_Qt3DRender__QAlphaTest__AlphaFunction &sipStrings_Qt3DRender[2375]
#define sipNameNr_Qt3DRender__QAttribute__AttributeType 2413
#define sipName_Qt3DRender__QAttribute__AttributeType &sipStrings_Qt3DRender[2413]
#define sipNameNr_Qt3DRender__QClearBuffers__BufferType 2451
#define sipName_Qt3DRender__QClearBuffers__BufferType &sipStrings_Qt3DRender[2451]
#define sipNameNr_Qt3DRender__QDepthTest__DepthFunction 2489
#define sipName_Qt3DRender__QDepthTest__DepthFunction &sipStrings_Qt3DRender[2489]
#define sipNameNr_Qt3DRender__QMemoryBarrier__Operation 2527
#define sipName_Qt3DRender__QMemoryBarrier__Operation &sipStrings_Qt3DRender[2527]
#define sipNameNr_Qt3DRender__QRenderAspect__RenderType 2565
#define sipName_Qt3DRender__QRenderAspect__RenderType &sipStrings_Qt3DRender[2565]
#define sipNameNr_Qt3DRender__QShaderImage__ImageFormat 2603
#define sipName_Qt3DRender__QShaderImage__ImageFormat &sipStrings_Qt3DRender[2603]
#define sipNameNr_defaultTextureCoordinateAttributeName 2641
#define sipName_defaultTextureCoordinateAttributeName &sipStrings_Qt3DRender[2641]
#define sipNameNr_tessellationControlShaderGraphChanged 2679
#define sipName_tessellationControlShaderGraphChanged &sipStrings_Qt3DRender[2679]
#define sipNameNr_Qt3DRender__QAbstractTexture__Filter 2717
#define sipName_Qt3DRender__QAbstractTexture__Filter &sipStrings_Qt3DRender[2717]
#define sipNameNr_Qt3DRender__QAbstractTexture__Status 2754
#define sipName_Qt3DRender__QAbstractTexture__Status &sipStrings_Qt3DRender[2754]
#define sipNameNr_Qt3DRender__QAbstractTexture__Target 2791
#define sipName_Qt3DRender__QAbstractTexture__Target &sipStrings_Qt3DRender[2791]
#define sipNameNr_Qt3DRender__QComputeCommand__RunType 2828
#define sipName_Qt3DRender__QComputeCommand__RunType &sipStrings_Qt3DRender[2828]
#define sipNameNr_Qt3DRender__QLayerFilter__FilterMode 2865
#define sipName_Qt3DRender__QLayerFilter__FilterMode &sipStrings_Qt3DRender[2865]
#define sipNameNr_Qt3DRender__QMultiSampleAntiAliasing 2902
#define sipName_Qt3DRender__QMultiSampleAntiAliasing &sipStrings_Qt3DRender[2902]
#define sipNameNr_Qt3DRender__QRenderCapabilities__API 2939
#define sipName_Qt3DRender__QRenderCapabilities__API &sipStrings_Qt3DRender[2939]
#define sipNameNr_setTessellationEvaluationShaderGraph 2976
#define sipName_setTessellationEvaluationShaderGraph &sipStrings_Qt3DRender[2976]
#define sipNameNr_tessellationControlShaderCodeChanged 3013
#define sipName_tessellationControlShaderCodeChanged &sipStrings_Qt3DRender[3013]
#define sipNameNr_Qt3DRender__PropertyReaderInterface 3050
#define sipName_Qt3DRender__PropertyReaderInterface &sipStrings_Qt3DRender[3050]
#define sipNameNr_Qt3DRender__QBlendEquationArguments 3086
#define sipName_Qt3DRender__QBlendEquationArguments &sipStrings_Qt3DRender[3086]
#define sipNameNr_Qt3DRender__QGraphicsApiFilter__Api 3122
#define sipName_Qt3DRender__QGraphicsApiFilter__Api &sipStrings_Qt3DRender[3122]
#define sipNameNr_Qt3DRender__QRasterMode__RasterMode 3158
#define sipName_Qt3DRender__QRasterMode__RasterMode &sipStrings_Qt3DRender[3158]
#define sipNameNr_setTessellationEvaluationShaderCode 3194
#define sipName_setTessellationEvaluationShaderCode &sipStrings_Qt3DRender[3194]
#define sipNameNr_3230 3230
#define sipName_3230 &sipStrings_Qt3DRender[3230]
#define sipNameNr_3265 3265
#define sipName_3265 &sipStrings_Qt3DRender[3265]
#define sipNameNr_Qt3DRender__QCullFace__CullingMode 3300
#define sipName_Qt3DRender__QCullFace__CullingMode &sipStrings_Qt3DRender[3300]
#define sipNameNr_Qt3DRender__QRayCasterHit__HitType 3335
#define sipName_Qt3DRender__QRayCasterHit__HitType &sipStrings_Qt3DRender[3335]
#define sipNameNr_Qt3DRender__QRenderSurfaceSelector 3370
#define sipName_Qt3DRender__QRenderSurfaceSelector &sipStrings_Qt3DRender[3370]
#define sipNameNr_Qt3DRender__QShaderProgram__Format 3405
#define sipName_Qt3DRender__QShaderProgram__Format &sipStrings_Qt3DRender[3405]
#define sipNameNr_Qt3DRender__QShaderProgram__Status 3440
#define sipName_Qt3DRender__QShaderProgram__Status &sipStrings_Qt3DRender[3440]
#define sipNameNr_Qt3DRender__QWaitFence__HandleType 3475
#define sipName_Qt3DRender__QWaitFence__HandleType &sipStrings_Qt3DRender[3475]
#define sipNameNr_setBoundingVolumePositionAttribute 3510
#define sipName_setBoundingVolumePositionAttribute &sipStrings_Qt3DRender[3510]
#define sipNameNr_stencilTestFailureOperationChanged 3545
#define sipName_stencilTestFailureOperationChanged &sipStrings_Qt3DRender[3545]
#define sipNameNr_ProjectedScreenPixelSizeThreshold 3580
#define sipName_ProjectedScreenPixelSizeThreshold &sipStrings_Qt3DRender[3580]
#define sipNameNr_3614 3614
#define sipName_3614 &sipStrings_Qt3DRender[3614]
#define sipNameNr_Qt3DRender__QAbstractTextureImage 3648
#define sipName_Qt3DRender__QAbstractTextureImage &sipStrings_Qt3DRender[3648]
#define sipNameNr_Qt3DRender__QPickEvent__Modifiers 3682
#define sipName_Qt3DRender__QPickEvent__Modifiers &sipStrings_Qt3DRender[3682]
#define sipNameNr_Qt3DRender__QRasterMode__FaceMode 3716
#define sipName_Qt3DRender__QRasterMode__FaceMode &sipStrings_Qt3DRender[3716]
#define sipNameNr_Qt3DRender__QRenderTargetSelector 3750
#define sipName_Qt3DRender__QRenderTargetSelector &sipStrings_Qt3DRender[3750]
#define sipNameNr_Qt3DRender__QSetFence__HandleType 3784
#define sipName_Qt3DRender__QSetFence__HandleType &sipStrings_Qt3DRender[3784]
#define sipNameNr_Qt3DRender__QShaderProgramBuilder 3818
#define sipName_Qt3DRender__QShaderProgramBuilder &sipStrings_Qt3DRender[3818]
#define sipNameNr_Qt3DRender__QSortPolicy__SortType 3852
#define sipName_Qt3DRender__QSortPolicy__SortType &sipStrings_Qt3DRender[3852]
#define sipNameNr_Qt3DRender__QStencilTestArguments 3886
#define sipName_Qt3DRender__QStencilTestArguments &sipStrings_Qt3DRender[3886]
#define sipNameNr_Qt3DRender__QTexture2DMultisample 3920
#define sipName_Qt3DRender__QTexture2DMultisample &sipStrings_Qt3DRender[3920]
#define sipNameNr_Qt3DRender__QTextureImage__Status 3954
#define sipName_Qt3DRender__QTextureImage__Status &sipStrings_Qt3DRender[3954]
#define sipNameNr_destinationAttachmentPointChanged 3988
#define sipName_destinationAttachmentPointChanged &sipStrings_Qt3DRender[3988]
#define sipNameNr_faceOrientationPickingModeChanged 4022
#define sipName_faceOrientationPickingModeChanged &sipStrings_Qt3DRender[4022]
#define sipNameNr_setTessellationControlShaderGraph 4056
#define sipName_setTessellationControlShaderGraph &sipStrings_Qt3DRender[4056]
#define sipNameNr_tessellationEvaluationShaderGraph 4090
#define sipName_tessellationEvaluationShaderGraph &sipStrings_Qt3DRender[4090]
#define sipNameNr_4124 4124
#define sipName_4124 &sipStrings_Qt3DRender[4124]
#define sipNameNr_4157 4157
#define sipName_4157 &sipStrings_Qt3DRender[4157]
#define sipNameNr_4190 4190
#define sipName_4190 &sipStrings_Qt3DRender[4190]
#define sipNameNr_4223 4223
#define sipName_4223 &sipStrings_Qt3DRender[4223]
#define sipNameNr_Qt3DRender__QAbstractLight__Type 4256
#define sipName_Qt3DRender__QAbstractLight__Type &sipStrings_Qt3DRender[4256]
#define sipNameNr_Qt3DRender__QBufferDataGenerator 4289
#define sipName_Qt3DRender__QBufferDataGenerator &sipStrings_Qt3DRender[4289]
#define sipNameNr_Qt3DRender__QLevelOfDetailSwitch 4322
#define sipName_Qt3DRender__QLevelOfDetailSwitch &sipStrings_Qt3DRender[4322]
#define sipNameNr_Qt3DRender__QPaintedTextureImage 4355
#define sipName_Qt3DRender__QPaintedTextureImage &sipStrings_Qt3DRender[4355]
#define sipNameNr_Qt3DRender__QPointSize__SizeMode 4388
#define sipName_Qt3DRender__QPointSize__SizeMode &sipStrings_Qt3DRender[4388]
#define sipNameNr_Qt3DRender__QSceneLoader__Status 4421
#define sipName_Qt3DRender__QSceneLoader__Status &sipStrings_Qt3DRender[4421]
#define sipNameNr_Qt3DRender__QShaderImage__Access 4454
#define sipName_Qt3DRender__QShaderImage__Access &sipStrings_Qt3DRender[4454]
#define sipNameNr_Qt3DRender__QTextureCubeMapArray 4487
#define sipName_Qt3DRender__QTextureCubeMapArray &sipStrings_Qt3DRender[4487]
#define sipNameNr_defaultJointIndicesAttributeName 4520
#define sipName_defaultJointIndicesAttributeName &sipStrings_Qt3DRender[4520]
#define sipNameNr_defaultJointWeightsAttributeName 4553
#define sipName_defaultJointWeightsAttributeName &sipStrings_Qt3DRender[4553]
#define sipNameNr_depthTestFailureOperationChanged 4586
#define sipName_depthTestFailureOperationChanged &sipStrings_Qt3DRender[4586]
#define sipNameNr_setTessellationControlShaderCode 4619
#define sipName_setTessellationControlShaderCode &sipStrings_Qt3DRender[4619]
#define sipNameNr_tessellationEvaluationShaderCode 4652
#define sipName_tessellationEvaluationShaderCode &sipStrings_Qt3DRender[4652]
#define sipNameNr_Qt3DRender__QBuffer__AccessType 4685
#define sipName_Qt3DRender__QBuffer__AccessType &sipStrings_Qt3DRender[4685]
#define sipNameNr_Qt3DRender__QBuffer__BufferType 4717
#define sipName_Qt3DRender__QBuffer__BufferType &sipStrings_Qt3DRender[4717]
#define sipNameNr_Qt3DRender__QPickEvent__Buttons 4749
#define sipName_Qt3DRender__QPickEvent__Buttons &sipStrings_Qt3DRender[4749]
#define sipNameNr_Qt3DRender__QRenderCapabilities 4781
#define sipName_Qt3DRender__QRenderCapabilities &sipStrings_Qt3DRender[4781]
#define sipNameNr_Qt3DRender__QRenderCaptureReply 4813
#define sipName_Qt3DRender__QRenderCaptureReply &sipStrings_Qt3DRender[4813]
#define sipNameNr_Qt3DRender__QRenderTargetOutput 4845
#define sipName_Qt3DRender__QRenderTargetOutput &sipStrings_Qt3DRender[4845]
#define sipNameNr_boundingVolumePositionAttribute 4877
#define sipName_boundingVolumePositionAttribute &sipStrings_Qt3DRender[4877]
#define sipNameNr_externalRenderTargetSizeChanged 4909
#define sipName_externalRenderTargetSizeChanged &sipStrings_Qt3DRender[4909]
#define sipNameNr_Qt3DRender__QAbstractRayCaster 4941
#define sipName_Qt3DRender__QAbstractRayCaster &sipStrings_Qt3DRender[4941]
#define sipNameNr_Qt3DRender__QBuffer__UsageType 4972
#define sipName_Qt3DRender__QBuffer__UsageType &sipStrings_Qt3DRender[4972]
#define sipNameNr_Qt3DRender__QGraphicsApiFilter 5003
#define sipName_Qt3DRender__QGraphicsApiFilter &sipStrings_Qt3DRender[5003]
#define sipNameNr_Qt3DRender__QPickTriangleEvent 5034
#define sipName_Qt3DRender__QPickTriangleEvent &sipStrings_Qt3DRender[5034]
#define sipNameNr_Qt3DRender__QTextureDataUpdate 5065
#define sipName_Qt3DRender__QTextureDataUpdate &sipStrings_Qt3DRender[5065]
#define sipNameNr_SRGB8_PunchThrough_Alpha1_ETC2 5096
#define sipName_SRGB8_PunchThrough_Alpha1_ETC2 &sipStrings_Qt3DRender[5096]
#define sipNameNr_primitiveRestartEnabledChanged 5127
#define sipName_primitiveRestartEnabledChanged &sipStrings_Qt3DRender[5127]
#define sipNameNr_setAutoMipMapGenerationEnabled 5158
#define sipName_setAutoMipMapGenerationEnabled &sipStrings_Qt3DRender[5158]
#define sipNameNr_setStencilTestFailureOperation 5189
#define sipName_setStencilTestFailureOperation &sipStrings_Qt3DRender[5189]
#define sipNameNr_tessellationControlShaderGraph 5220
#define sipName_tessellationControlShaderGraph &sipStrings_Qt3DRender[5220]
#define sipNameNr_Qt3DRender__QDirectionalLight 5251
#define sipName_Qt3DRender__QDirectionalLight &sipStrings_Qt3DRender[5251]
#define sipNameNr_Qt3DRender__QEnvironmentLight 5281
#define sipName_Qt3DRender__QEnvironmentLight &sipStrings_Qt3DRender[5281]
#define sipNameNr_Qt3DRender__QGeometryRenderer 5311
#define sipName_Qt3DRender__QGeometryRenderer &sipStrings_Qt3DRender[5311]
#define sipNameNr_Qt3DRender__QRenderPassFilter 5341
#define sipName_Qt3DRender__QRenderPassFilter &sipStrings_Qt3DRender[5341]
#define sipNameNr_Qt3DRender__QStencilOperation 5371
#define sipName_Qt3DRender__QStencilOperation &sipStrings_Qt3DRender[5371]
#define sipNameNr_Qt3DRender__QTextureGenerator 5401
#define sipName_Qt3DRender__QTextureGenerator &sipStrings_Qt3DRender[5401]
#define sipNameNr_Qt3DRender__QTextureImageData 5431
#define sipName_Qt3DRender__QTextureImageData &sipStrings_Qt3DRender[5431]
#define sipNameNr_Qt3DRender__QTextureRectangle 5461
#define sipName_Qt3DRender__QTextureRectangle &sipStrings_Qt3DRender[5461]
#define sipNameNr_RGB8_PunchThrough_Alpha1_ETC2 5097
#define sipName_RGB8_PunchThrough_Alpha1_ETC2 &sipStrings_Qt3DRender[5097]
#define sipNameNr_isAutoMipMapGenerationEnabled 5491
#define sipName_isAutoMipMapGenerationEnabled &sipStrings_Qt3DRender[5491]
#define sipNameNr_setDestinationAttachmentPoint 5521
#define sipName_setDestinationAttachmentPoint &sipStrings_Qt3DRender[5521]
#define sipNameNr_setFaceOrientationPickingMode 5551
#define sipName_setFaceOrientationPickingMode &sipStrings_Qt3DRender[5551]
#define sipNameNr_tessellationControlShaderCode 5581
#define sipName_tessellationControlShaderCode &sipStrings_Qt3DRender[5581]
#define sipNameNr_QLevelOfDetailBoundingSphere 1633
#define sipName_QLevelOfDetailBoundingSphere &sipStrings_Qt3DRender[1633]
#define sipNameNr_5611 5611
#define sipName_5611 &sipStrings_Qt3DRender[5611]
#define sipNameNr_Qt3DRender__QAbstractFunctor 5640
#define sipName_Qt3DRender__QAbstractFunctor &sipStrings_Qt3DRender[5640]
#define sipNameNr_Qt3DRender__QAbstractTexture 5669
#define sipName_Qt3DRender__QAbstractTexture &sipStrings_Qt3DRender[5669]
#define sipNameNr_Qt3DRender__QBlitFramebuffer 5698
#define sipName_Qt3DRender__QBlitFramebuffer &sipStrings_Qt3DRender[5698]
#define sipNameNr_Qt3DRender__QDispatchCompute 5727
#define sipName_Qt3DRender__QDispatchCompute &sipStrings_Qt3DRender[5727]
#define sipNameNr_Qt3DRender__QGeometryFactory 5756
#define sipName_Qt3DRender__QGeometryFactory &sipStrings_Qt3DRender[5756]
#define sipNameNr_Qt3DRender__QPickingSettings 5785
#define sipName_Qt3DRender__QPickingSettings &sipStrings_Qt3DRender[5785]
#define sipNameNr_Qt3DRender__QProximityFilter 5814
#define sipName_Qt3DRender__QProximityFilter &sipStrings_Qt3DRender[5814]
#define sipNameNr_Qt3DRender__QScreenRayCaster 5843
#define sipName_Qt3DRender__QScreenRayCaster &sipStrings_Qt3DRender[5843]
#define sipNameNr_Qt3DRender__QSeamlessCubemap 5872
#define sipName_Qt3DRender__QSeamlessCubemap &sipStrings_Qt3DRender[5872]
#define sipNameNr_Qt3DRender__QSharedGLTexture 5901
#define sipName_Qt3DRender__QSharedGLTexture &sipStrings_Qt3DRender[5901]
#define sipNameNr_Qt3DRender__QTechniqueFilter 5930
#define sipName_Qt3DRender__QTechniqueFilter &sipStrings_Qt3DRender[5930]
#define sipNameNr_Qt3DRender__QTextureWrapMode 5959
#define sipName_Qt3DRender__QTextureWrapMode &sipStrings_Qt3DRender[5959]
#define sipNameNr_allTestsPassOperationChanged 5988
#define sipName_allTestsPassOperationChanged &sipStrings_Qt3DRender[5988]
#define sipNameNr_defaultPositionAttributeName 6017
#define sipName_defaultPositionAttributeName &sipStrings_Qt3DRender[6017]
#define sipNameNr_indexBufferByteOffsetChanged 6046
#define sipName_indexBufferByteOffsetChanged &sipStrings_Qt3DRender[6046]
#define sipNameNr_setDepthTestFailureOperation 6075
#define sipName_setDepthTestFailureOperation &sipStrings_Qt3DRender[6075]
#define sipNameNr_sourceAttachmentPointChanged 6104
#define sipName_sourceAttachmentPointChanged &sipStrings_Qt3DRender[6104]
#define sipNameNr_Qt3DRender__QCameraSelector 6133
#define sipName_Qt3DRender__QCameraSelector &sipStrings_Qt3DRender[6133]
#define sipNameNr_Qt3DRender__QComputeCommand 6161
#define sipName_Qt3DRender__QComputeCommand &sipStrings_Qt3DRender[6161]
#define sipNameNr_Qt3DRender__QFrameGraphNode 6189
#define sipName_Qt3DRender__QFrameGraphNode &sipStrings_Qt3DRender[6189]
#define sipNameNr_Qt3DRender__QFrustumCulling 6217
#define sipName_Qt3DRender__QFrustumCulling &sipStrings_Qt3DRender[6217]
#define sipNameNr_Qt3DRender__QPickPointEvent 6245
#define sipName_Qt3DRender__QPickPointEvent &sipStrings_Qt3DRender[6245]
#define sipNameNr_Qt3DRender__QRenderSettings 6273
#define sipName_Qt3DRender__QRenderSettings &sipStrings_Qt3DRender[6273]
#define sipNameNr_Qt3DRender__QRenderStateSet 6301
#define sipName_Qt3DRender__QRenderStateSet &sipStrings_Qt3DRender[6301]
#define sipNameNr_Qt3DRender__QSubtreeEnabler 6329
#define sipName_Qt3DRender__QSubtreeEnabler &sipStrings_Qt3DRender[6329]
#define sipNameNr_Qt3DRender__QTexture1DArray 6357
#define sipName_Qt3DRender__QTexture1DArray &sipStrings_Qt3DRender[6357]
#define sipNameNr_Qt3DRender__QTexture2DArray 6385
#define sipName_Qt3DRender__QTexture2DArray &sipStrings_Qt3DRender[6385]
#define sipNameNr_Qt3DRender__QTextureCubeMap 6413
#define sipName_Qt3DRender__QTextureCubeMap &sipStrings_Qt3DRender[6413]
#define sipNameNr_defaultTangentAttributeName 6441
#define sipName_defaultTangentAttributeName &sipStrings_Qt3DRender[6441]
#define sipNameNr_quadraticAttenuationChanged 6469
#define sipName_quadraticAttenuationChanged &sipStrings_Qt3DRender[6469]
#define sipNameNr_setExternalRenderTargetSize 6497
#define sipName_setExternalRenderTargetSize &sipStrings_Qt3DRender[6497]
#define sipNameNr_stencilTestFailureOperation 6525
#define sipName_stencilTestFailureOperation &sipStrings_Qt3DRender[6525]
#define sipNameNr_FaceOrientationPickingMode 88
#define sipName_FaceOrientationPickingMode &sipStrings_Qt3DRender[88]
#define sipNameNr_QStencilOperationArguments 2114
#define sipName_QStencilOperationArguments &sipStrings_Qt3DRender[2114]
#define sipNameNr_QTexture2DMultisampleArray 2153
#define sipName_QTexture2DMultisampleArray &sipStrings_Qt3DRender[2153]
#define sipNameNr_QTextureImageDataGenerator 2192
#define sipName_QTextureImageDataGenerator &sipStrings_Qt3DRender[2192]
#define sipNameNr_Qt3DRender__QAbstractLight 6553
#define sipName_Qt3DRender__QAbstractLight &sipStrings_Qt3DRender[6553]
#define sipNameNr_Qt3DRender__QAlphaCoverage 6580
#define sipName_Qt3DRender__QAlphaCoverage &sipStrings_Qt3DRender[6580]
#define sipNameNr_Qt3DRender__QBlendEquation 6607
#define sipName_Qt3DRender__QBlendEquation &sipStrings_Qt3DRender[6607]
#define sipNameNr_Qt3DRender__QLevelOfDetail 6634
#define sipName_Qt3DRender__QLevelOfDetail &sipStrings_Qt3DRender[6634]
#define sipNameNr_Qt3DRender__QMemoryBarrier 6661
#define sipName_Qt3DRender__QMemoryBarrier &sipStrings_Qt3DRender[6661]
#define sipNameNr_Qt3DRender__QPickLineEvent 6688
#define sipName_Qt3DRender__QPickLineEvent &sipStrings_Qt3DRender[6688]
#define sipNameNr_Qt3DRender__QPolygonOffset 6715
#define sipName_Qt3DRender__QPolygonOffset &sipStrings_Qt3DRender[6715]
#define sipNameNr_Qt3DRender__QRenderCapture 6742
#define sipName_Qt3DRender__QRenderCapture &sipStrings_Qt3DRender[6742]
#define sipNameNr_Qt3DRender__QShaderProgram 6769
#define sipName_Qt3DRender__QShaderProgram &sipStrings_Qt3DRender[6769]
#define sipNameNr_Qt3DRender__QTextureBuffer 6796
#define sipName_Qt3DRender__QTextureBuffer &sipStrings_Qt3DRender[6796]
#define sipNameNr_Qt3DRender__QTextureLoader 6823
#define sipName_Qt3DRender__QTextureLoader &sipStrings_Qt3DRender[6823]
#define sipNameNr_constantAttenuationChanged 6850
#define sipName_constantAttenuationChanged &sipStrings_Qt3DRender[6850]
#define sipNameNr_defaultNormalAttributeName 6877
#define sipName_defaultNormalAttributeName &sipStrings_Qt3DRender[6877]
#define sipNameNr_destinationAttachmentPoint 6904
#define sipName_destinationAttachmentPoint &sipStrings_Qt3DRender[6904]
#define sipNameNr_faceOrientationPickingMode 6931
#define sipName_faceOrientationPickingMode &sipStrings_Qt3DRender[6931]
#define sipNameNr_fragmentShaderGraphChanged 6958
#define sipName_fragmentShaderGraphChanged &sipStrings_Qt3DRender[6958]
#define sipNameNr_geometryShaderGraphChanged 6985
#define sipName_geometryShaderGraphChanged &sipStrings_Qt3DRender[6985]
#define sipNameNr_interpolationMethodChanged 7012
#define sipName_interpolationMethodChanged &sipStrings_Qt3DRender[7012]
#define sipNameNr_magnificationFilterChanged 7039
#define sipName_magnificationFilterChanged &sipStrings_Qt3DRender[7039]
#define sipNameNr_maxComputeSharedMemorySize 7066
#define sipName_maxComputeSharedMemorySize &sipStrings_Qt3DRender[7066]
#define sipNameNr_notifyDataGeneratorChanged 7093
#define sipName_notifyDataGeneratorChanged &sipStrings_Qt3DRender[7093]
#define sipNameNr_setPrimitiveRestartEnabled 7120
#define sipName_setPrimitiveRestartEnabled &sipStrings_Qt3DRender[7120]
#define sipNameNr_worldSpaceToleranceChanged 7147
#define sipName_worldSpaceToleranceChanged &sipStrings_Qt3DRender[7147]
#define sipNameNr_DistanceToCameraThreshold 7174
#define sipName_DistanceToCameraThreshold &sipStrings_Qt3DRender[7174]
#define sipNameNr_GeometryRendererComponent 7200
#define sipName_GeometryRendererComponent &sipStrings_Qt3DRender[7200]
#define sipNameNr_Qt3DRender__QClearBuffers 7226
#define sipName_Qt3DRender__QClearBuffers &sipStrings_Qt3DRender[7226]
#define sipNameNr_Qt3DRender__QMesh__Status 7252
#define sipName_Qt3DRender__QMesh__Status &sipStrings_Qt3DRender[7252]
#define sipNameNr_Qt3DRender__QObjectPicker 7278
#define sipName_Qt3DRender__QObjectPicker &sipStrings_Qt3DRender[7278]
#define sipNameNr_Qt3DRender__QRayCasterHit 7304
#define sipName_Qt3DRender__QRayCasterHit &sipStrings_Qt3DRender[7304]
#define sipNameNr_Qt3DRender__QRenderAspect 7330
#define sipName_Qt3DRender__QRenderAspect &sipStrings_Qt3DRender[7330]
#define sipNameNr_Qt3DRender__QRenderTarget 7356
#define sipName_Qt3DRender__QRenderTarget &sipStrings_Qt3DRender[7356]
#define sipNameNr_Qt3DRender__QTextureImage 7382
#define sipName_Qt3DRender__QTextureImage &sipStrings_Qt3DRender[7382]
#define sipNameNr_comparisonFunctionChanged 7408
#define sipName_comparisonFunctionChanged &sipStrings_Qt3DRender[7408]
#define sipNameNr_computeShaderGraphChanged 7434
#define sipName_computeShaderGraphChanged &sipStrings_Qt3DRender[7434]
#define sipNameNr_defaultColorAttributeName 7460
#define sipName_defaultColorAttributeName &sipStrings_Qt3DRender[7460]
#define sipNameNr_depthTestFailureOperation 7486
#define sipName_depthTestFailureOperation &sipStrings_Qt3DRender[7486]
#define sipNameNr_fragmentShaderCodeChanged 7512
#define sipName_fragmentShaderCodeChanged &sipStrings_Qt3DRender[7512]
#define sipNameNr_geometryShaderCodeChanged 7538
#define sipName_geometryShaderCodeChanged &sipStrings_Qt3DRender[7538]
#define sipNameNr_minificationFilterChanged 7564
#define sipName_minificationFilterChanged &sipStrings_Qt3DRender[7564]
#define sipNameNr_setOrthographicProjection 7590
#define sipName_setOrthographicProjection &sipStrings_Qt3DRender[7590]
#define sipNameNr_DiscardAllMatchingLayers 7616
#define sipName_DiscardAllMatchingLayers &sipStrings_Qt3DRender[7616]
#define sipNameNr_DiscardAnyMatchingLayers 7641
#define sipName_DiscardAnyMatchingLayers &sipStrings_Qt3DRender[7641]
#define sipNameNr_OneMinusDestinationAlpha 7666
#define sipName_OneMinusDestinationAlpha &sipStrings_Qt3DRender[7666]
#define sipNameNr_OneMinusDestinationColor 7691
#define sipName_OneMinusDestinationColor &sipStrings_Qt3DRender[7691]
#define sipNameNr_QMultiSampleAntiAliasing 2914
#define sipName_QMultiSampleAntiAliasing &sipStrings_Qt3DRender[2914]
#define sipNameNr_Qt3DRender__QLayerFilter 7716
#define sipName_Qt3DRender__QLayerFilter &sipStrings_Qt3DRender[7716]
#define sipNameNr_Qt3DRender__QNoDepthMask 7741
#define sipName_Qt3DRender__QNoDepthMask &sipStrings_Qt3DRender[7741]
#define sipNameNr_Qt3DRender__QRenderState 7766
#define sipName_Qt3DRender__QRenderState &sipStrings_Qt3DRender[7766]
#define sipNameNr_Qt3DRender__QSceneLoader 7791
#define sipName_Qt3DRender__QSceneLoader &sipStrings_Qt3DRender[7791]
#define sipNameNr_Qt3DRender__QScissorTest 7816
#define sipName_Qt3DRender__QScissorTest &sipStrings_Qt3DRender[7816]
#define sipNameNr_Qt3DRender__QShaderImage 7841
#define sipName_Qt3DRender__QShaderImage &sipStrings_Qt3DRender[7841]
#define sipNameNr_Qt3DRender__QStencilMask 7866
#define sipName_Qt3DRender__QStencilMask &sipStrings_Qt3DRender[7866]
#define sipNameNr_Qt3DRender__QStencilTest 7891
#define sipName_Qt3DRender__QStencilTest &sipStrings_Qt3DRender[7891]
#define sipNameNr_Qt3DRender__QTextureData 7916
#define sipName_Qt3DRender__QTextureData &sipStrings_Qt3DRender[7916]
#define sipNameNr_Target2DMultisampleArray 7941
#define sipName_Target2DMultisampleArray &sipStrings_Qt3DRender[7941]
#define sipNameNr_clearStencilValueChanged 7966
#define sipName_clearStencilValueChanged &sipStrings_Qt3DRender[7966]
#define sipNameNr_computeShaderCodeChanged 7991
#define sipName_computeShaderCodeChanged &sipStrings_Qt3DRender[7991]
#define sipNameNr_distanceThresholdChanged 8016
#define sipName_distanceThresholdChanged &sipStrings_Qt3DRender[8016]
#define sipNameNr_externalRenderTargetSize 8041
#define sipName_externalRenderTargetSize &sipStrings_Qt3DRender[8041]
#define sipNameNr_graphicsApiFilterChanged 8066
#define sipName_graphicsApiFilterChanged &sipStrings_Qt3DRender[8066]
#define sipNameNr_linearAttenuationChanged 8091
#define sipName_linearAttenuationChanged &sipStrings_Qt3DRender[8091]
#define sipNameNr_maximumAnisotropyChanged 8116
#define sipName_maximumAnisotropyChanged &sipStrings_Qt3DRender[8116]
#define sipNameNr_restartIndexValueChanged 8141
#define sipName_restartIndexValueChanged &sipStrings_Qt3DRender[8141]
#define sipNameNr_setAllTestsPassOperation 8166
#define sipName_setAllTestsPassOperation &sipStrings_Qt3DRender[8166]
#define sipNameNr_setIndexBufferByteOffset 8191
#define sipName_setIndexBufferByteOffset &sipStrings_Qt3DRender[8191]
#define sipNameNr_setPerspectiveProjection 8216
#define sipName_setPerspectiveProjection &sipStrings_Qt3DRender[8216]
#define sipNameNr_setSourceAttachmentPoint 8241
#define sipName_setSourceAttachmentPoint &sipStrings_Qt3DRender[8241]
#define sipNameNr_surfacePixelRatioChanged 8266
#define sipName_surfacePixelRatioChanged &sipStrings_Qt3DRender[8266]
#define sipNameNr_vertexShaderGraphChanged 8291
#define sipName_vertexShaderGraphChanged &sipStrings_Qt3DRender[8291]
#define sipNameNr_AcceptAllMatchingLayers 8316
#define sipName_AcceptAllMatchingLayers &sipStrings_Qt3DRender[8316]
#define sipNameNr_AcceptAnyMatchingLayers 8340
#define sipName_AcceptAnyMatchingLayers &sipStrings_Qt3DRender[8340]
#define sipNameNr_CameraTranslationOption 915
#define sipName_CameraTranslationOption &sipStrings_Qt3DRender[915]
#define sipNameNr_ColorDepthStencilBuffer 8364
#define sipName_ColorDepthStencilBuffer &sipStrings_Qt3DRender[8364]
#define sipNameNr_DontTranslateViewCenter 8388
#define sipName_DontTranslateViewCenter &sipStrings_Qt3DRender[8388]
#define sipNameNr_PropertyReaderInterface 3062
#define sipName_PropertyReaderInterface &sipStrings_Qt3DRender[3062]
#define sipNameNr_QBlendEquationArguments 3098
#define sipName_QBlendEquationArguments &sipStrings_Qt3DRender[3098]
#define sipNameNr_Qt3DRender__QCameraLens 8412
#define sipName_Qt3DRender__QCameraLens &sipStrings_Qt3DRender[8412]
#define sipNameNr_Qt3DRender__QDepthRange 8436
#define sipName_Qt3DRender__QDepthRange &sipStrings_Qt3DRender[8436]
#define sipNameNr_Qt3DRender__QPointLight 8460
#define sipName_Qt3DRender__QPointLight &sipStrings_Qt3DRender[8460]
#define sipNameNr_Qt3DRender__QRasterMode 8484
#define sipName_Qt3DRender__QRasterMode &sipStrings_Qt3DRender[8484]
#define sipNameNr_Qt3DRender__QRenderPass 8508
#define sipName_Qt3DRender__QRenderPass &sipStrings_Qt3DRender[8508]
#define sipNameNr_Qt3DRender__QShaderData 8532
#define sipName_Qt3DRender__QShaderData &sipStrings_Qt3DRender[8532]
#define sipNameNr_Qt3DRender__QSortPolicy 8556
#define sipName_Qt3DRender__QSortPolicy &sipStrings_Qt3DRender[8556]
#define sipNameNr_activeFrameGraphChanged 8580
#define sipName_activeFrameGraphChanged &sipStrings_Qt3DRender[8580]
#define sipNameNr_destinationAlphaChanged 8604
#define sipName_destinationAlphaChanged &sipStrings_Qt3DRender[8604]
#define sipNameNr_primitiveRestartEnabled 8628
#define sipName_primitiveRestartEnabled &sipStrings_Qt3DRender[8628]
#define sipNameNr_projectionMatrixChanged 8652
#define sipName_projectionMatrixChanged &sipStrings_Qt3DRender[8652]
#define sipNameNr_setQuadraticAttenuation 8676
#define sipName_setQuadraticAttenuation &sipStrings_Qt3DRender[8676]
#define sipNameNr_vertexShaderCodeChanged 8700
#define sipName_vertexShaderCodeChanged &sipStrings_Qt3DRender[8700]
#define sipNameNr_verticesPerPatchChanged 8724
#define sipName_verticesPerPatchChanged &sipStrings_Qt3DRender[8724]
#define sipNameNr_OrthographicProjection 7593
#define sipName_OrthographicProjection &sipStrings_Qt3DRender[7593]
#define sipNameNr_QRenderSurfaceSelector 3382
#define sipName_QRenderSurfaceSelector &sipStrings_Qt3DRender[3382]
#define sipNameNr_Qt3DRender__QAlphaTest 8748
#define sipName_Qt3DRender__QAlphaTest &sipStrings_Qt3DRender[8748]
#define sipNameNr_Qt3DRender__QAttribute 8771
#define sipName_Qt3DRender__QAttribute &sipStrings_Qt3DRender[8771]
#define sipNameNr_Qt3DRender__QClipPlane 8794
#define sipName_Qt3DRender__QClipPlane &sipStrings_Qt3DRender[8794]
#define sipNameNr_Qt3DRender__QColorMask 8817
#define sipName_Qt3DRender__QColorMask &sipStrings_Qt3DRender[8817]
#define sipNameNr_Qt3DRender__QDepthTest 8840
#define sipName_Qt3DRender__QDepthTest &sipStrings_Qt3DRender[8840]
#define sipNameNr_Qt3DRender__QDithering 8863
#define sipName_Qt3DRender__QDithering &sipStrings_Qt3DRender[8863]
#define sipNameNr_Qt3DRender__QFilterKey 8886
#define sipName_Qt3DRender__QFilterKey &sipStrings_Qt3DRender[8886]
#define sipNameNr_Qt3DRender__QFrontFace 8909
#define sipName_Qt3DRender__QFrontFace &sipStrings_Qt3DRender[8909]
#define sipNameNr_Qt3DRender__QLineWidth 8932
#define sipName_Qt3DRender__QLineWidth &sipStrings_Qt3DRender[8932]
#define sipNameNr_Qt3DRender__QNoPicking 8955
#define sipName_Qt3DRender__QNoPicking &sipStrings_Qt3DRender[8955]
#define sipNameNr_Qt3DRender__QParameter 8978
#define sipName_Qt3DRender__QParameter &sipStrings_Qt3DRender[8978]
#define sipNameNr_Qt3DRender__QPickEvent 9001
#define sipName_Qt3DRender__QPickEvent &sipStrings_Qt3DRender[9001]
#define sipNameNr_Qt3DRender__QPointSize 9024
#define sipName_Qt3DRender__QPointSize &sipStrings_Qt3DRender[9024]
#define sipNameNr_Qt3DRender__QRayCaster 9047
#define sipName_Qt3DRender__QRayCaster &sipStrings_Qt3DRender[9047]
#define sipNameNr_Qt3DRender__QSpotLight 9070
#define sipName_Qt3DRender__QSpotLight &sipStrings_Qt3DRender[9070]
#define sipNameNr_Qt3DRender__QTechnique 9093
#define sipName_Qt3DRender__QTechnique &sipStrings_Qt3DRender[9093]
#define sipNameNr_Qt3DRender__QTexture1D 9116
#define sipName_Qt3DRender__QTexture1D &sipStrings_Qt3DRender[9116]
#define sipNameNr_Qt3DRender__QTexture2D 9139
#define sipName_Qt3DRender__QTexture2D &sipStrings_Qt3DRender[9139]
#define sipNameNr_Qt3DRender__QTexture3D 9162
#define sipName_Qt3DRender__QTexture3D &sipStrings_Qt3DRender[9162]
#define sipNameNr_Qt3DRender__QWaitFence 9185
#define sipName_Qt3DRender__QWaitFence &sipStrings_Qt3DRender[9185]
#define sipNameNr_TessellationEvaluation 9208
#define sipName_TessellationEvaluation &sipStrings_Qt3DRender[9208]
#define sipNameNr_TriangleStripAdjacency 9231
#define sipName_TriangleStripAdjacency &sipStrings_Qt3DRender[9231]
#define sipNameNr_attachmentPointChanged 9254
#define sipName_attachmentPointChanged &sipStrings_Qt3DRender[9254]
#define sipNameNr_clearDepthValueChanged 9277
#define sipName_clearDepthValueChanged &sipStrings_Qt3DRender[9277]
#define sipNameNr_destinationRectChanged 9300
#define sipName_destinationRectChanged &sipStrings_Qt3DRender[9300]
#define sipNameNr_destinationRgbaChanged 9323
#define sipName_destinationRgbaChanged &sipStrings_Qt3DRender[9323]
#define sipNameNr_frontOutputMaskChanged 9346
#define sipName_frontOutputMaskChanged &sipStrings_Qt3DRender[9346]
#define sipNameNr_generateMipMapsChanged 9369
#define sipName_generateMipMapsChanged &sipStrings_Qt3DRender[9369]
#define sipNameNr_setConstantAttenuation 9392
#define sipName_setConstantAttenuation &sipStrings_Qt3DRender[9392]
#define sipNameNr_setFragmentShaderGraph 9415
#define sipName_setFragmentShaderGraph &sipStrings_Qt3DRender[9415]
#define sipNameNr_setGeometryShaderGraph 9438
#define sipName_setGeometryShaderGraph &sipStrings_Qt3DRender[9438]
#define sipNameNr_setInterpolationMethod 9461
#define sipName_setInterpolationMethod &sipStrings_Qt3DRender[9461]
#define sipNameNr_setMagnificationFilter 9484
#define sipName_setMagnificationFilter &sipStrings_Qt3DRender[9484]
#define sipNameNr_setWorldSpaceTolerance 9507
#define sipName_setWorldSpaceTolerance &sipStrings_Qt3DRender[9507]
#define sipNameNr_stencilFunctionChanged 9530
#define sipName_stencilFunctionChanged &sipStrings_Qt3DRender[9530]
#define sipNameNr_BoundingVolumePicking 9553
#define sipName_BoundingVolumePicking &sipStrings_Qt3DRender[9553]
#define sipNameNr_DrawIndirectAttribute 9575
#define sipName_DrawIndirectAttribute &sipStrings_Qt3DRender[9575]
#define sipNameNr_OneMinusConstantAlpha 9597
#define sipName_OneMinusConstantAlpha &sipStrings_Qt3DRender[9597]
#define sipNameNr_OneMinusConstantColor 9619
#define sipName_OneMinusConstantColor &sipStrings_Qt3DRender[9619]
#define sipNameNr_OneMinusSource1Color0 9641
#define sipName_OneMinusSource1Color0 &sipStrings_Qt3DRender[9641]
#define sipNameNr_PerspectiveProjection 8219
#define sipName_PerspectiveProjection &sipStrings_Qt3DRender[8219]
#define sipNameNr_QAbstractTextureImage 3660
#define sipName_QAbstractTextureImage &sipStrings_Qt3DRender[3660]
#define sipNameNr_QRenderTargetSelector 3762
#define sipName_QRenderTargetSelector &sipStrings_Qt3DRender[3762]
#define sipNameNr_QShaderProgramBuilder 3830
#define sipName_QShaderProgramBuilder &sipStrings_Qt3DRender[3830]
#define sipNameNr_QStencilTestArguments 3898
#define sipName_QStencilTestArguments &sipStrings_Qt3DRender[3898]
#define sipNameNr_QTexture2DMultisample 3932
#define sipName_QTexture2DMultisample &sipStrings_Qt3DRender[3932]
#define sipNameNr_Qt3DRender__QCullFace 9663
#define sipName_Qt3DRender__QCullFace &sipStrings_Qt3DRender[9663]
#define sipNameNr_Qt3DRender__QGeometry 9685
#define sipName_Qt3DRender__QGeometry &sipStrings_Qt3DRender[9685]
#define sipNameNr_Qt3DRender__QMaterial 9707
#define sipName_Qt3DRender__QMaterial &sipStrings_Qt3DRender[9707]
#define sipNameNr_Qt3DRender__QSetFence 9729
#define sipName_Qt3DRender__QSetFence &sipStrings_Qt3DRender[9729]
#define sipNameNr_Qt3DRender__QViewport 9751
#define sipName_Qt3DRender__QViewport &sipStrings_Qt3DRender[9751]
#define sipNameNr_RGB_BP_UNSIGNED_FLOAT 9773
#define sipName_RGB_BP_UNSIGNED_FLOAT &sipStrings_Qt3DRender[9773]
#define sipNameNr_SRGB8_Alpha8_ETC2_EAC 9795
#define sipName_SRGB8_Alpha8_ETC2_EAC &sipStrings_Qt3DRender[9795]
#define sipNameNr_allTestsPassOperation 9817
#define sipName_allTestsPassOperation &sipStrings_Qt3DRender[9817]
#define sipNameNr_backOutputMaskChanged 9839
#define sipName_backOutputMaskChanged &sipStrings_Qt3DRender[9839]
#define sipNameNr_comparisonMaskChanged 9861
#define sipName_comparisonMaskChanged &sipStrings_Qt3DRender[9861]
#define sipNameNr_comparisonModeChanged 9883
#define sipName_comparisonModeChanged &sipStrings_Qt3DRender[9883]
#define sipNameNr_destinationRgbChanged 9905
#define sipName_destinationRgbChanged &sipStrings_Qt3DRender[9905]
#define sipNameNr_indexBufferByteOffset 9927
#define sipName_indexBufferByteOffset &sipStrings_Qt3DRender[9927]
#define sipNameNr_localDirectionChanged 9949
#define sipName_localDirectionChanged &sipStrings_Qt3DRender[9949]
#define sipNameNr_maxComputeInvocations 9971
#define sipName_maxComputeInvocations &sipStrings_Qt3DRender[9971]
#define sipNameNr_normalizedRectChanged 9993
#define sipName_normalizedRectChanged &sipStrings_Qt3DRender[9993]
#define sipNameNr_pickResultModeChanged 10015
#define sipName_pickResultModeChanged &sipStrings_Qt3DRender[10015]
#define sipNameNr_projectionTypeChanged 10037
#define sipName_projectionTypeChanged &sipStrings_Qt3DRender[10037]
#define sipNameNr_referenceValueChanged 10059
#define sipName_referenceValueChanged &sipStrings_Qt3DRender[10059]
#define sipNameNr_rotateAboutViewCenter 10081
#define sipName_rotateAboutViewCenter &sipStrings_Qt3DRender[10081]
#define sipNameNr_setComparisonFunction 10103
#define sipName_setComparisonFunction &sipStrings_Qt3DRender[10103]
#define sipNameNr_setComputeShaderGraph 10125
#define sipName_setComputeShaderGraph &sipStrings_Qt3DRender[10125]
#define sipNameNr_setFragmentShaderCode 10147
#define sipName_setFragmentShaderCode &sipStrings_Qt3DRender[10147]
#define sipNameNr_setGeometryShaderCode 10169
#define sipName_setGeometryShaderCode &sipStrings_Qt3DRender[10169]
#define sipNameNr_setMinificationFilter 10191
#define sipName_setMinificationFilter &sipStrings_Qt3DRender[10191]
#define sipNameNr_sourceAttachmentPoint 10213
#define sipName_sourceAttachmentPoint &sipStrings_Qt3DRender[10213]
#define sipNameNr_vertexBaseTypeChanged 10235
#define sipName_vertexBaseTypeChanged &sipStrings_Qt3DRender[10235]
#define sipNameNr_volumeOverrideChanged 10257
#define sipName_volumeOverrideChanged &sipStrings_Qt3DRender[10257]
#define sipNameNr_waitOperationsChanged 10279
#define sipName_waitOperationsChanged &sipStrings_Qt3DRender[10279]
#define sipNameNr_worldDirectionChanged 10301
#define sipName_worldDirectionChanged &sipStrings_Qt3DRender[10301]
#define sipNameNr_CompatibilityProfile 10323
#define sipName_CompatibilityProfile &sipStrings_Qt3DRender[10323]
#define sipNameNr_LuminanceAlphaFormat 10344
#define sipName_LuminanceAlphaFormat &sipStrings_Qt3DRender[10344]
#define sipNameNr_NearestMipMapNearest 10365
#define sipName_NearestMipMapNearest &sipStrings_Qt3DRender[10365]
#define sipNameNr_OneMinusSource1Alpha 10386
#define sipName_OneMinusSource1Alpha &sipStrings_Qt3DRender[10386]
#define sipNameNr_OneMinusSource1Color 10407
#define sipName_OneMinusSource1Color &sipStrings_Qt3DRender[10407]
#define sipNameNr_QBufferDataGenerator 4301
#define sipName_QBufferDataGenerator &sipStrings_Qt3DRender[4301]
#define sipNameNr_QLevelOfDetailSwitch 4334
#define sipName_QLevelOfDetailSwitch &sipStrings_Qt3DRender[4334]
#define sipNameNr_QPaintedTextureImage 4367
#define sipName_QPaintedTextureImage &sipStrings_Qt3DRender[4367]
#define sipNameNr_QTextureCubeMapArray 4499
#define sipName_QTextureCubeMapArray &sipStrings_Qt3DRender[4499]
#define sipNameNr_VertexAttributeArray 10428
#define sipName_VertexAttributeArray &sipStrings_Qt3DRender[10428]
#define sipNameNr_alphaFunctionChanged 10449
#define sipName_alphaFunctionChanged &sipStrings_Qt3DRender[10449]
#define sipNameNr_attributeTypeChanged 10470
#define sipName_attributeTypeChanged &sipStrings_Qt3DRender[10470]
#define sipNameNr_blendFunctionChanged 10491
#define sipName_blendFunctionChanged &sipStrings_Qt3DRender[10491]
#define sipNameNr_containsMouseChanged 10512
#define sipName_containsMouseChanged &sipStrings_Qt3DRender[10512]
#define sipNameNr_createBoundingSphere 10533
#define sipName_createBoundingSphere &sipStrings_Qt3DRender[10533]
#define sipNameNr_depthFunctionChanged 10554
#define sipName_depthFunctionChanged &sipStrings_Qt3DRender[10554]
#define sipNameNr_enabledLayersChanged 10575
#define sipName_enabledLayersChanged &sipStrings_Qt3DRender[10575]
#define sipNameNr_firstInstanceChanged 10596
#define sipName_firstInstanceChanged &sipStrings_Qt3DRender[10596]
#define sipNameNr_instanceCountChanged 10617
#define sipName_instanceCountChanged &sipStrings_Qt3DRender[10617]
#define sipNameNr_parentFrameGraphNode 10638
#define sipName_parentFrameGraphNode &sipStrings_Qt3DRender[10638]
#define sipNameNr_primitiveTypeChanged 10659
#define sipName_primitiveTypeChanged &sipStrings_Qt3DRender[10659]
#define sipNameNr_quadraticAttenuation 10680
#define sipName_quadraticAttenuation &sipStrings_Qt3DRender[10680]
#define sipNameNr_setClearStencilValue 10701
#define sipName_setClearStencilValue &sipStrings_Qt3DRender[10701]
#define sipNameNr_setComputeShaderCode 10722
#define sipName_setComputeShaderCode &sipStrings_Qt3DRender[10722]
#define sipNameNr_setDistanceThreshold 10743
#define sipName_setDistanceThreshold &sipStrings_Qt3DRender[10743]
#define sipNameNr_setFrustumProjection 10764
#define sipName_setFrustumProjection &sipStrings_Qt3DRender[10764]
#define sipNameNr_setLinearAttenuation 10785
#define sipName_setLinearAttenuation &sipStrings_Qt3DRender[10785]
#define sipNameNr_setMaximumAnisotropy 10806
#define sipName_setMaximumAnisotropy &sipStrings_Qt3DRender[10806]
#define sipNameNr_setRestartIndexValue 10827
#define sipName_setRestartIndexValue &sipStrings_Qt3DRender[10827]
#define sipNameNr_setSurfacePixelRatio 10848
#define sipName_setSurfacePixelRatio &sipStrings_Qt3DRender[10848]
#define sipNameNr_setVertexShaderGraph 10869
#define sipName_setVertexShaderGraph &sipStrings_Qt3DRender[10869]
#define sipNameNr_shaderProgramChanged 10890
#define sipName_shaderProgramChanged &sipStrings_Qt3DRender[10890]
#define sipNameNr_thresholdTypeChanged 10911
#define sipName_thresholdTypeChanged &sipStrings_Qt3DRender[10911]
#define sipNameNr_CameraLensComponent 10932
#define sipName_CameraLensComponent &sipStrings_Qt3DRender[10932]
#define sipNameNr_CompareGreaterEqual 10952
#define sipName_CompareGreaterEqual &sipStrings_Qt3DRender[10952]
#define sipNameNr_CompareRefToTexture 10972
#define sipName_CompareRefToTexture &sipStrings_Qt3DRender[10972]
#define sipNameNr_InterpolationMethod 354
#define sipName_InterpolationMethod &sipStrings_Qt3DRender[354]
#define sipNameNr_LinearMipMapNearest 10992
#define sipName_LinearMipMapNearest &sipStrings_Qt3DRender[10992]
#define sipNameNr_NearestMipMapLinear 11012
#define sipName_NearestMipMapLinear &sipStrings_Qt3DRender[11012]
#define sipNameNr_NearestPriorityPick 11032
#define sipName_NearestPriorityPick &sipStrings_Qt3DRender[11032]
#define sipNameNr_OneMinusSourceAlpha 11052
#define sipName_OneMinusSourceAlpha &sipStrings_Qt3DRender[11052]
#define sipNameNr_OneMinusSourceColor 11072
#define sipName_OneMinusSourceColor &sipStrings_Qt3DRender[11072]
#define sipNameNr_QRenderCapabilities 4793
#define sipName_QRenderCapabilities &sipStrings_Qt3DRender[4793]
#define sipNameNr_QRenderCaptureReply 4825
#define sipName_QRenderCaptureReply &sipStrings_Qt3DRender[4825]
#define sipNameNr_QRenderTargetOutput 4857
#define sipName_QRenderTargetOutput &sipStrings_Qt3DRender[4857]
#define sipNameNr_Qt3DRender__QBuffer 11092
#define sipName_Qt3DRender__QBuffer &sipStrings_Qt3DRender[11092]
#define sipNameNr_Qt3DRender__QCamera 11112
#define sipName_Qt3DRender__QCamera &sipStrings_Qt3DRender[11112]
#define sipNameNr_Qt3DRender__QEffect 11132
#define sipName_Qt3DRender__QEffect &sipStrings_Qt3DRender[11132]
#define sipNameNr_Qt3DRender__QNoDraw 11152
#define sipName_Qt3DRender__QNoDraw &sipStrings_Qt3DRender[11152]
#define sipNameNr_RGB_BP_SIGNED_FLOAT 11172
#define sipName_RGB_BP_SIGNED_FLOAT &sipStrings_Qt3DRender[11172]
#define sipNameNr_ShaderStorageBuffer 11192
#define sipName_ShaderStorageBuffer &sipStrings_Qt3DRender[11192]
#define sipNameNr_SourceAlphaSaturate 11212
#define sipName_SourceAlphaSaturate &sipStrings_Qt3DRender[11212]
#define sipNameNr_Target2DMultisample 11232
#define sipName_Target2DMultisample &sipStrings_Qt3DRender[11232]
#define sipNameNr_TessellationControl 11252
#define sipName_TessellationControl &sipStrings_Qt3DRender[11252]
#define sipNameNr_TranslateViewCenter 8392
#define sipName_TranslateViewCenter &sipStrings_Qt3DRender[8392]
#define sipNameNr_constantAttenuation 11272
#define sipName_constantAttenuation &sipStrings_Qt3DRender[11272]
#define sipNameNr_currentIndexChanged 11292
#define sipName_currentIndexChanged &sipStrings_Qt3DRender[11292]
#define sipNameNr_fragmentShaderGraph 11312
#define sipName_fragmentShaderGraph &sipStrings_Qt3DRender[11312]
#define sipNameNr_geometryShaderGraph 11332
#define sipName_geometryShaderGraph &sipStrings_Qt3DRender[11332]
#define sipNameNr_hoverEnabledChanged 11352
#define sipName_hoverEnabledChanged &sipStrings_Qt3DRender[11352]
#define sipNameNr_interpolationMethod 11372
#define sipName_interpolationMethod &sipStrings_Qt3DRender[11372]
#define sipNameNr_magnificationFilter 11392
#define sipName_magnificationFilter &sipStrings_Qt3DRender[11392]
#define sipNameNr_majorVersionChanged 11412
#define sipName_majorVersionChanged &sipStrings_Qt3DRender[11412]
#define sipNameNr_minorVersionChanged 11432
#define sipName_minorVersionChanged &sipStrings_Qt3DRender[11432]
#define sipNameNr_renderPolicyChanged 11452
#define sipName_renderPolicyChanged &sipStrings_Qt3DRender[11452]
#define sipNameNr_rollAboutViewCenter 11472
#define sipName_rollAboutViewCenter &sipStrings_Qt3DRender[11472]
#define sipNameNr_setActiveFrameGraph 11492
#define sipName_setActiveFrameGraph &sipStrings_Qt3DRender[11492]
#define sipNameNr_setDestinationAlpha 11512
#define sipName_setDestinationAlpha &sipStrings_Qt3DRender[11512]
#define sipNameNr_setProjectionMatrix 11532
#define sipName_setProjectionMatrix &sipStrings_Qt3DRender[11532]
#define sipNameNr_setVertexShaderCode 11552
#define sipName_setVertexShaderCode &sipStrings_Qt3DRender[11552]
#define sipNameNr_setVerticesPerPatch 11572
#define sipName_setVerticesPerPatch &sipStrings_Qt3DRender[11572]
#define sipNameNr_tiltAboutViewCenter 11592
#define sipName_tiltAboutViewCenter &sipStrings_Qt3DRender[11592]
#define sipNameNr_worldSpaceTolerance 11612
#define sipName_worldSpaceTolerance &sipStrings_Qt3DRender[11612]
#define sipNameNr_ComparisonFunction 503
#define sipName_ComparisonFunction &sipStrings_Qt3DRender[503]
#define sipNameNr_DepthStencilBuffer 8369
#define sipName_DepthStencilBuffer &sipStrings_Qt3DRender[8369]
#define sipNameNr_DrawIndirectBuffer 11632
#define sipName_DrawIndirectBuffer &sipStrings_Qt3DRender[11632]
#define sipNameNr_LineStripAdjacency 11651
#define sipName_LineStripAdjacency &sipStrings_Qt3DRender[11651]
#define sipNameNr_LinearMipMapLinear 11670
#define sipName_LinearMipMapLinear &sipStrings_Qt3DRender[11670]
#define sipNameNr_QAbstractRayCaster 4953
#define sipName_QAbstractRayCaster &sipStrings_Qt3DRender[4953]
#define sipNameNr_QGraphicsApiFilter 5015
#define sipName_QGraphicsApiFilter &sipStrings_Qt3DRender[5015]
#define sipNameNr_QPickTriangleEvent 5046
#define sipName_QPickTriangleEvent &sipStrings_Qt3DRender[5046]
#define sipNameNr_QTextureDataUpdate 5077
#define sipName_QTextureDataUpdate &sipStrings_Qt3DRender[5077]
#define sipNameNr_Qt3DRender__QLayer 11689
#define sipName_Qt3DRender__QLayer &sipStrings_Qt3DRender[11689]
#define sipNameNr_Qt3DRender__Render 11708
#define sipName_Qt3DRender__Render &sipStrings_Qt3DRender[11708]
#define sipNameNr_TargetCubeMapArray 11727
#define sipName_TargetCubeMapArray &sipStrings_Qt3DRender[11727]
#define sipNameNr_TransformComponent 11746
#define sipName_TransformComponent &sipStrings_Qt3DRender[11746]
#define sipNameNr_TrianglesAdjacency 11765
#define sipName_TrianglesAdjacency &sipStrings_Qt3DRender[11765]
#define sipNameNr_alphaMaskedChanged 11784
#define sipName_alphaMaskedChanged &sipStrings_Qt3DRender[11784]
#define sipNameNr_aspectRatioChanged 11803
#define sipName_aspectRatioChanged &sipStrings_Qt3DRender[11803]
#define sipNameNr_bufferIndexChanged 11822
#define sipName_bufferIndexChanged &sipStrings_Qt3DRender[11822]
#define sipNameNr_colorBufferChanged 11841
#define sipName_colorBufferChanged &sipStrings_Qt3DRender[11841]
#define sipNameNr_comparisonFunction 11860
#define sipName_comparisonFunction &sipStrings_Qt3DRender[11860]
#define sipNameNr_computeShaderGraph 11879
#define sipName_computeShaderGraph &sipStrings_Qt3DRender[11879]
#define sipNameNr_cutOffAngleChanged 11898
#define sipName_cutOffAngleChanged &sipStrings_Qt3DRender[11898]
#define sipNameNr_destinationChanged 11917
#define sipName_destinationChanged &sipStrings_Qt3DRender[11917]
#define sipNameNr_dragEnabledChanged 11936
#define sipName_dragEnabledChanged &sipStrings_Qt3DRender[11936]
#define sipNameNr_fieldOfViewChanged 11955
#define sipName_fieldOfViewChanged &sipStrings_Qt3DRender[11955]
#define sipNameNr_firstVertexChanged 11974
#define sipName_firstVertexChanged &sipStrings_Qt3DRender[11974]
#define sipNameNr_fragmentShaderCode 11993
#define sipName_fragmentShaderCode &sipStrings_Qt3DRender[11993]
#define sipNameNr_geometryShaderCode 12012
#define sipName_geometryShaderCode &sipStrings_Qt3DRender[12012]
#define sipNameNr_greenMaskedChanged 12031
#define sipName_greenMaskedChanged &sipStrings_Qt3DRender[12031]
#define sipNameNr_indexOffsetChanged 12050
#define sipName_indexOffsetChanged &sipStrings_Qt3DRender[12050]
#define sipNameNr_maxWorkGroupCountX 12069
#define sipName_maxWorkGroupCountX &sipStrings_Qt3DRender[12069]
#define sipNameNr_maxWorkGroupCountY 12088
#define sipName_maxWorkGroupCountY &sipStrings_Qt3DRender[12088]
#define sipNameNr_maxWorkGroupCountZ 12107
#define sipName_maxWorkGroupCountZ &sipStrings_Qt3DRender[12107]
#define sipNameNr_minificationFilter 12126
#define sipName_minificationFilter &sipStrings_Qt3DRender[12126]
#define sipNameNr_panAboutViewCenter 12145
#define sipName_panAboutViewCenter &sipStrings_Qt3DRender[12145]
#define sipNameNr_removeTextureImage 12164
#define sipName_removeTextureImage &sipStrings_Qt3DRender[12164]
#define sipNameNr_renderCapabilities 12183
#define sipName_renderCapabilities &sipStrings_Qt3DRender[12183]
#define sipNameNr_scaleFactorChanged 12202
#define sipName_scaleFactorChanged &sipStrings_Qt3DRender[12202]
#define sipNameNr_setAttachmentPoint 12221
#define sipName_setAttachmentPoint &sipStrings_Qt3DRender[12221]
#define sipNameNr_setClearDepthValue 12240
#define sipName_setClearDepthValue &sipStrings_Qt3DRender[12240]
#define sipNameNr_setDestinationRect 12259
#define sipName_setDestinationRect &sipStrings_Qt3DRender[12259]
#define sipNameNr_setDestinationRgba 12278
#define sipName_setDestinationRgba &sipStrings_Qt3DRender[12278]
#define sipNameNr_setFrontOutputMask 12297
#define sipName_setFrontOutputMask &sipStrings_Qt3DRender[12297]
#define sipNameNr_setGenerateMipMaps 12316
#define sipName_setGenerateMipMaps &sipStrings_Qt3DRender[12316]
#define sipNameNr_setGeometryFactory 12335
#define sipName_setGeometryFactory &sipStrings_Qt3DRender[12335]
#define sipNameNr_setStencilFunction 12354
#define sipName_setStencilFunction &sipStrings_Qt3DRender[12354]
#define sipNameNr_sourceAlphaChanged 12373
#define sipName_sourceAlphaChanged &sipStrings_Qt3DRender[12373]
#define sipNameNr_supportsImageStore 12392
#define sipName_supportsImageStore &sipStrings_Qt3DRender[12392]
#define sipNameNr_vertexCountChanged 12411
#define sipName_vertexCountChanged &sipStrings_Qt3DRender[12411]
#define sipNameNr_FrustumProjection 10767
#define sipName_FrustumProjection &sipStrings_Qt3DRender[10767]
#define sipNameNr_MaterialComponent 12430
#define sipName_MaterialComponent &sipStrings_Qt3DRender[12430]
#define sipNameNr_PixelUnpackBuffer 12448
#define sipName_PixelUnpackBuffer &sipStrings_Qt3DRender[12448]
#define sipNameNr_QDirectionalLight 5263
#define sipName_QDirectionalLight &sipStrings_Qt3DRender[5263]
#define sipNameNr_QEnvironmentLight 5293
#define sipName_QEnvironmentLight &sipStrings_Qt3DRender[5293]
#define sipNameNr_QGeometryRenderer 5323
#define sipName_QGeometryRenderer &sipStrings_Qt3DRender[5323]
#define sipNameNr_QRenderPassFilter 5353
#define sipName_QRenderPassFilter &sipStrings_Qt3DRender[5353]
#define sipNameNr_QStencilOperation 5383
#define sipName_QStencilOperation &sipStrings_Qt3DRender[5383]
#define sipNameNr_QTextureGenerator 5413
#define sipName_QTextureGenerator &sipStrings_Qt3DRender[5413]
#define sipNameNr_QTextureImageData 5443
#define sipName_QTextureImageData &sipStrings_Qt3DRender[5443]
#define sipNameNr_QTextureRectangle 5473
#define sipName_QTextureRectangle &sipStrings_Qt3DRender[5473]
#define sipNameNr_Qt3DRender__QMesh 12466
#define sipName_Qt3DRender__QMesh &sipStrings_Qt3DRender[12466]
#define sipNameNr_ShaderImageAccess 12484
#define sipName_ShaderImageAccess &sipStrings_Qt3DRender[12484]
#define sipNameNr_TransformFeedback 12502
#define sipName_TransformFeedback &sipStrings_Qt3DRender[12502]
#define sipNameNr_accessTypeChanged 12520
#define sipName_accessTypeChanged &sipStrings_Qt3DRender[12520]
#define sipNameNr_blueMaskedChanged 12538
#define sipName_blueMaskedChanged &sipStrings_Qt3DRender[12538]
#define sipNameNr_byteOffsetChanged 12556
#define sipName_byteOffsetChanged &sipStrings_Qt3DRender[12556]
#define sipNameNr_byteStrideChanged 12574
#define sipName_byteStrideChanged &sipStrings_Qt3DRender[12574]
#define sipNameNr_clearColorChanged 12592
#define sipName_clearColorChanged &sipStrings_Qt3DRender[12592]
#define sipNameNr_clearStencilValue 12610
#define sipName_clearStencilValue &sipStrings_Qt3DRender[12610]
#define sipNameNr_computeShaderCode 12628
#define sipName_computeShaderCode &sipStrings_Qt3DRender[12628]
#define sipNameNr_depthStepsChanged 12646
#define sipName_depthStepsChanged &sipStrings_Qt3DRender[12646]
#define sipNameNr_distanceThreshold 12664
#define sipName_distanceThreshold &sipStrings_Qt3DRender[12664]
#define sipNameNr_enablementChanged 12682
#define sipName_enablementChanged &sipStrings_Qt3DRender[12682]
#define sipNameNr_extensionsChanged 12700
#define sipName_extensionsChanged &sipStrings_Qt3DRender[12700]
#define sipNameNr_filterModeChanged 12718
#define sipName_filterModeChanged &sipStrings_Qt3DRender[12718]
#define sipNameNr_graphicsApiFilter 12736
#define sipName_graphicsApiFilter &sipStrings_Qt3DRender[12736]
#define sipNameNr_handleTypeChanged 12754
#define sipName_handleTypeChanged &sipStrings_Qt3DRender[12754]
#define sipNameNr_irradianceChanged 12772
#define sipName_irradianceChanged &sipStrings_Qt3DRender[12772]
#define sipNameNr_linearAttenuation 12790
#define sipName_linearAttenuation &sipStrings_Qt3DRender[12790]
#define sipNameNr_localIntersection 12808
#define sipName_localIntersection &sipStrings_Qt3DRender[12808]
#define sipNameNr_maxWorkGroupSizeX 12826
#define sipName_maxWorkGroupSizeX &sipStrings_Qt3DRender[12826]
#define sipNameNr_maxWorkGroupSizeY 12844
#define sipName_maxWorkGroupSizeY &sipStrings_Qt3DRender[12844]
#define sipNameNr_maxWorkGroupSizeZ 12862
#define sipName_maxWorkGroupSizeZ &sipStrings_Qt3DRender[12862]
#define sipNameNr_maximumAnisotropy 12880
#define sipName_maximumAnisotropy &sipStrings_Qt3DRender[12880]
#define sipNameNr_pickMethodChanged 12898
#define sipName_pickMethodChanged &sipStrings_Qt3DRender[12898]
#define sipNameNr_planeIndexChanged 12916
#define sipName_planeIndexChanged &sipStrings_Qt3DRender[12916]
#define sipNameNr_rasterModeChanged 12934
#define sipName_rasterModeChanged &sipStrings_Qt3DRender[12934]
#define sipNameNr_removeRenderState 12952
#define sipName_removeRenderState &sipStrings_Qt3DRender[12952]
#define sipNameNr_restartIndexValue 12970
#define sipName_restartIndexValue &sipStrings_Qt3DRender[12970]
#define sipNameNr_setBackOutputMask 12988
#define sipName_setBackOutputMask &sipStrings_Qt3DRender[12988]
#define sipNameNr_setComparisonMask 13006
#define sipName_setComparisonMask &sipStrings_Qt3DRender[13006]
#define sipNameNr_setComparisonMode 13024
#define sipName_setComparisonMode &sipStrings_Qt3DRender[13024]
#define sipNameNr_setDestinationRgb 13042
#define sipName_setDestinationRgb &sipStrings_Qt3DRender[13042]
#define sipNameNr_setLocalDirection 13060
#define sipName_setLocalDirection &sipStrings_Qt3DRender[13060]
#define sipNameNr_setNormalizedRect 13078
#define sipName_setNormalizedRect &sipStrings_Qt3DRender[13078]
#define sipNameNr_setPickResultMode 13096
#define sipName_setPickResultMode &sipStrings_Qt3DRender[13096]
#define sipNameNr_setProjectionType 13114
#define sipName_setProjectionType &sipStrings_Qt3DRender[13114]
#define sipNameNr_setReferenceValue 13132
#define sipName_setReferenceValue &sipStrings_Qt3DRender[13132]
#define sipNameNr_setVertexBaseType 13150
#define sipName_setVertexBaseType &sipStrings_Qt3DRender[13150]
#define sipNameNr_setVolumeOverride 13168
#define sipName_setVolumeOverride &sipStrings_Qt3DRender[13168]
#define sipNameNr_setWaitOperations 13186
#define sipName_setWaitOperations &sipStrings_Qt3DRender[13186]
#define sipNameNr_setWorldDirection 13204
#define sipName_setWorldDirection &sipStrings_Qt3DRender[13204]
#define sipNameNr_sip_simplewrapper 13222
#define sipName_sip_simplewrapper &sipStrings_Qt3DRender[13222]
#define sipNameNr_sourceRectChanged 13240
#define sipName_sourceRectChanged &sipStrings_Qt3DRender[13240]
#define sipNameNr_sourceRgbaChanged 13258
#define sipName_sourceRgbaChanged &sipStrings_Qt3DRender[13258]
#define sipNameNr_surfacePixelRatio 13276
#define sipName_surfacePixelRatio &sipStrings_Qt3DRender[13276]
#define sipNameNr_thresholdsChanged 13294
#define sipName_thresholdsChanged &sipStrings_Qt3DRender[13294]
#define sipNameNr_vertexShaderGraph 13312
#define sipName_vertexShaderGraph &sipStrings_Qt3DRender[13312]
#define sipNameNr_vertexSizeChanged 13330
#define sipName_vertexSizeChanged &sipStrings_Qt3DRender[13330]
#define sipNameNr_viewCenterChanged 13348
#define sipName_viewCenterChanged &sipStrings_Qt3DRender[13348]
#define sipNameNr_viewMatrixChanged 13366
#define sipName_viewMatrixChanged &sipStrings_Qt3DRender[13366]
#define sipNameNr_viewVectorChanged 13384
#define sipName_viewVectorChanged &sipStrings_Qt3DRender[13384]
#define sipNameNr_workGroupXChanged 13402
#define sipName_workGroupXChanged &sipStrings_Qt3DRender[13402]
#define sipNameNr_workGroupYChanged 13420
#define sipName_workGroupYChanged &sipStrings_Qt3DRender[13420]
#define sipNameNr_workGroupZChanged 13438
#define sipName_workGroupZChanged &sipStrings_Qt3DRender[13438]
#define sipNameNr_worldIntersection 13456
#define sipName_worldIntersection &sipStrings_Qt3DRender[13456]
#define sipNameNr_ColorDepthBuffer 13474
#define sipName_ColorDepthBuffer &sipStrings_Qt3DRender[13474]
#define sipNameNr_CommpareNotEqual 13491
#define sipName_CommpareNotEqual &sipStrings_Qt3DRender[13491]
#define sipNameNr_CompareLessEqual 13508
#define sipName_CompareLessEqual &sipStrings_Qt3DRender[13508]
#define sipNameNr_CounterClockWise 13525
#define sipName_CounterClockWise &sipStrings_Qt3DRender[13525]
#define sipNameNr_CubeMapNegativeX 13542
#define sipName_CubeMapNegativeX &sipStrings_Qt3DRender[13542]
#define sipNameNr_CubeMapNegativeY 13559
#define sipName_CubeMapNegativeY &sipStrings_Qt3DRender[13559]
#define sipNameNr_CubeMapNegativeZ 13576
#define sipName_CubeMapNegativeZ &sipStrings_Qt3DRender[13576]
#define sipNameNr_CubeMapPositiveX 13593
#define sipName_CubeMapPositiveX &sipStrings_Qt3DRender[13593]
#define sipNameNr_CubeMapPositiveY 13610
#define sipName_CubeMapPositiveY &sipStrings_Qt3DRender[13610]
#define sipNameNr_CubeMapPositiveZ 13627
#define sipName_CubeMapPositiveZ &sipStrings_Qt3DRender[13627]
#define sipNameNr_CustomProjection 13644
#define sipName_CustomProjection &sipStrings_Qt3DRender[13644]
#define sipNameNr_DestinationAlpha 7674
#define sipName_DestinationAlpha &sipStrings_Qt3DRender[7674]
#define sipNameNr_DestinationColor 7699
#define sipName_DestinationColor &sipStrings_Qt3DRender[7699]
#define sipNameNr_DirectionalLight 5264
#define sipName_DirectionalLight &sipStrings_Qt3DRender[5264]
#define sipNameNr_FrontAndBackFace 13661
#define sipName_FrontAndBackFace &sipStrings_Qt3DRender[13661]
#define sipNameNr_PrimitivePicking 13678
#define sipName_PrimitivePicking &sipStrings_Qt3DRender[13678]
#define sipNameNr_PyQt5_Qt3DRender 13695
#define sipName_PyQt5_Qt3DRender &sipStrings_Qt3DRender[13695]
#define sipNameNr_QAbstractFunctor 5652
#define sipName_QAbstractFunctor &sipStrings_Qt3DRender[5652]
#define sipNameNr_QAbstractTexture 5681
#define sipName_QAbstractTexture &sipStrings_Qt3DRender[5681]
#define sipNameNr_QBlitFramebuffer 5710
#define sipName_QBlitFramebuffer &sipStrings_Qt3DRender[5710]
#define sipNameNr_QDispatchCompute 5739
#define sipName_QDispatchCompute &sipStrings_Qt3DRender[5739]
#define sipNameNr_QGeometryFactory 5768
#define sipName_QGeometryFactory &sipStrings_Qt3DRender[5768]
#define sipNameNr_QPickingSettings 5797
#define sipName_QPickingSettings &sipStrings_Qt3DRender[5797]
#define sipNameNr_QProximityFilter 5826
#define sipName_QProximityFilter &sipStrings_Qt3DRender[5826]
#define sipNameNr_QScreenRayCaster 5855
#define sipName_QScreenRayCaster &sipStrings_Qt3DRender[5855]
#define sipNameNr_QSeamlessCubemap 5884
#define sipName_QSeamlessCubemap &sipStrings_Qt3DRender[5884]
#define sipNameNr_QSharedGLTexture 5913
#define sipName_QSharedGLTexture &sipStrings_Qt3DRender[5913]
#define sipNameNr_QTechniqueFilter 5942
#define sipName_QTechniqueFilter &sipStrings_Qt3DRender[5942]
#define sipNameNr_QTextureWrapMode 5971
#define sipName_QTextureWrapMode &sipStrings_Qt3DRender[5971]
#define sipNameNr_UnknownComponent 13712
#define sipName_UnknownComponent &sipStrings_Qt3DRender[13712]
#define sipNameNr_WindingDirection 1604
#define sipName_WindingDirection &sipStrings_Qt3DRender[1604]
#define sipNameNr_activeFrameGraph 13729
#define sipName_activeFrameGraph &sipStrings_Qt3DRender[13729]
#define sipNameNr_destinationAlpha 13746
#define sipName_destinationAlpha &sipStrings_Qt3DRender[13746]
#define sipNameNr_directionChanged 13763
#define sipName_directionChanged &sipStrings_Qt3DRender[13763]
#define sipNameNr_disconnectNotify 13780
#define sipName_disconnectNotify &sipStrings_Qt3DRender[13780]
#define sipNameNr_intensityChanged 13797
#define sipName_intensityChanged &sipStrings_Qt3DRender[13797]
#define sipNameNr_maxExtentChanged 13814
#define sipName_maxExtentChanged &sipStrings_Qt3DRender[13814]
#define sipNameNr_maxTextureLayers 13831
#define sipName_maxTextureLayers &sipStrings_Qt3DRender[13831]
#define sipNameNr_minExtentChanged 13848
#define sipName_minExtentChanged &sipStrings_Qt3DRender[13848]
#define sipNameNr_nearPlaneChanged 13865
#define sipName_nearPlaneChanged &sipStrings_Qt3DRender[13865]
#define sipNameNr_nearValueChanged 13882
#define sipName_nearValueChanged &sipStrings_Qt3DRender[13882]
#define sipNameNr_projectionMatrix 13899
#define sipName_projectionMatrix &sipStrings_Qt3DRender[13899]
#define sipNameNr_recursiveChanged 13916
#define sipName_recursiveChanged &sipStrings_Qt3DRender[13916]
#define sipNameNr_redMaskedChanged 13933
#define sipName_redMaskedChanged &sipStrings_Qt3DRender[13933]
#define sipNameNr_removeRenderPass 13950
#define sipName_removeRenderPass &sipStrings_Qt3DRender[13950]
#define sipNameNr_sceneChangeEvent 13967
#define sipName_sceneChangeEvent &sipStrings_Qt3DRender[13967]
#define sipNameNr_setAlphaFunction 13984
#define sipName_setAlphaFunction &sipStrings_Qt3DRender[13984]
#define sipNameNr_setAttributeType 14001
#define sipName_setAttributeType &sipStrings_Qt3DRender[14001]
#define sipNameNr_setBlendFunction 14018
#define sipName_setBlendFunction &sipStrings_Qt3DRender[14018]
#define sipNameNr_setDataGenerator 14035
#define sipName_setDataGenerator &sipStrings_Qt3DRender[14035]
#define sipNameNr_setDepthFunction 14052
#define sipName_setDepthFunction &sipStrings_Qt3DRender[14052]
#define sipNameNr_setEnabledLayers 14069
#define sipName_setEnabledLayers &sipStrings_Qt3DRender[14069]
#define sipNameNr_setFirstInstance 14086
#define sipName_setFirstInstance &sipStrings_Qt3DRender[14086]
#define sipNameNr_setInstanceCount 14103
#define sipName_setInstanceCount &sipStrings_Qt3DRender[14103]
#define sipNameNr_setPrimitiveType 14120
#define sipName_setPrimitiveType &sipStrings_Qt3DRender[14120]
#define sipNameNr_setShaderProgram 14137
#define sipName_setShaderProgram &sipStrings_Qt3DRender[14137]
#define sipNameNr_setThresholdType 14154
#define sipName_setThresholdType &sipStrings_Qt3DRender[14154]
#define sipNameNr_sortTypesChanged 14171
#define sipName_sortTypesChanged &sipStrings_Qt3DRender[14171]
#define sipNameNr_sourceRgbChanged 14188
#define sipName_sourceRgbChanged &sipStrings_Qt3DRender[14188]
#define sipNameNr_textureIdChanged 14205
#define sipName_textureIdChanged &sipStrings_Qt3DRender[14205]
#define sipNameNr_vertexShaderCode 14222
#define sipName_vertexShaderCode &sipStrings_Qt3DRender[14222]
#define sipNameNr_verticesPerPatch 14239
#define sipName_verticesPerPatch &sipStrings_Qt3DRender[14239]
#define sipNameNr_waitOnCPUChanged 14256
#define sipName_waitOnCPUChanged &sipStrings_Qt3DRender[14256]
#define sipNameNr_AttachmentPoint 555
#define sipName_AttachmentPoint &sipStrings_Qt3DRender[555]
#define sipNameNr_BufferTypeFlags 1230
#define sipName_BufferTypeFlags &sipStrings_Qt3DRender[1230]
#define sipNameNr_ControlModifier 14273
#define sipName_ControlModifier &sipStrings_Qt3DRender[14273]
#define sipNameNr_LuminanceFormat 14289
#define sipName_LuminanceFormat &sipStrings_Qt3DRender[14289]
#define sipNameNr_OpenGLTextureId 14305
#define sipName_OpenGLTextureId &sipStrings_Qt3DRender[14305]
#define sipNameNr_PixelPackBuffer 14321
#define sipName_PixelPackBuffer &sipStrings_Qt3DRender[14321]
#define sipNameNr_QCameraSelector 6145
#define sipName_QCameraSelector &sipStrings_Qt3DRender[6145]
#define sipNameNr_QComputeCommand 6173
#define sipName_QComputeCommand &sipStrings_Qt3DRender[6173]
#define sipNameNr_QFrameGraphNode 6201
#define sipName_QFrameGraphNode &sipStrings_Qt3DRender[6201]
#define sipNameNr_QFrustumCulling 6229
#define sipName_QFrustumCulling &sipStrings_Qt3DRender[6229]
#define sipNameNr_QPickPointEvent 6257
#define sipName_QPickPointEvent &sipStrings_Qt3DRender[6257]
#define sipNameNr_QRenderSettings 6285
#define sipName_QRenderSettings &sipStrings_Qt3DRender[6285]
#define sipNameNr_QRenderStateSet 6313
#define sipName_QRenderStateSet &sipStrings_Qt3DRender[6313]
#define sipNameNr_QSubtreeEnabler 6341
#define sipName_QSubtreeEnabler &sipStrings_Qt3DRender[6341]
#define sipNameNr_QTexture1DArray 6369
#define sipName_QTexture1DArray &sipStrings_Qt3DRender[6369]
#define sipNameNr_QTexture2DArray 6397
#define sipName_QTexture2DArray &sipStrings_Qt3DRender[6397]
#define sipNameNr_QTextureCubeMap 6425
#define sipName_QTextureCubeMap &sipStrings_Qt3DRender[6425]
#define sipNameNr_ReverseSubtract 14337
#define sipName_ReverseSubtract &sipStrings_Qt3DRender[14337]
#define sipNameNr_SRGB_Alpha_DXT1 14353
#define sipName_SRGB_Alpha_DXT1 &sipStrings_Qt3DRender[14353]
#define sipNameNr_SRGB_Alpha_DXT3 14369
#define sipName_SRGB_Alpha_DXT3 &sipStrings_Qt3DRender[14369]
#define sipNameNr_SRGB_Alpha_DXT5 14385
#define sipName_SRGB_Alpha_DXT5 &sipStrings_Qt3DRender[14385]
#define sipNameNr_StateChangeCost 14401
#define sipName_StateChangeCost &sipStrings_Qt3DRender[14401]
#define sipNameNr_StencilFaceMode 257
#define sipName_StencilFaceMode &sipStrings_Qt3DRender[257]
#define sipNameNr_StencilFunction 308
#define sipName_StencilFunction &sipStrings_Qt3DRender[308]
#define sipNameNr_TargetAutomatic 14417
#define sipName_TargetAutomatic &sipStrings_Qt3DRender[14417]
#define sipNameNr_TargetRectangle 14433
#define sipName_TargetRectangle &sipStrings_Qt3DRender[14433]
#define sipNameNr_TrianglePicking 14449
#define sipName_TrianglePicking &sipStrings_Qt3DRender[14449]
#define sipNameNr_VertexAttribute 14465
#define sipName_VertexAttribute &sipStrings_Qt3DRender[14465]
#define sipNameNr_acceptedChanged 14481
#define sipName_acceptedChanged &sipStrings_Qt3DRender[14481]
#define sipNameNr_addTextureImage 14497
#define sipName_addTextureImage &sipStrings_Qt3DRender[14497]
#define sipNameNr_attachmentPoint 14513
#define sipName_attachmentPoint &sipStrings_Qt3DRender[14513]
#define sipNameNr_clearDepthValue 14529
#define sipName_clearDepthValue &sipStrings_Qt3DRender[14529]
#define sipNameNr_completeChanged 14545
#define sipName_completeChanged &sipStrings_Qt3DRender[14545]
#define sipNameNr_dataSizeChanged 14561
#define sipName_dataSizeChanged &sipStrings_Qt3DRender[14561]
#define sipNameNr_dataTypeChanged 14577
#define sipName_dataTypeChanged &sipStrings_Qt3DRender[14577]
#define sipNameNr_destinationRect 14593
#define sipName_destinationRect &sipStrings_Qt3DRender[14593]
#define sipNameNr_distanceChanged 14609
#define sipName_distanceChanged &sipStrings_Qt3DRender[14609]
#define sipNameNr_exposureChanged 14625
#define sipName_exposureChanged &sipStrings_Qt3DRender[14625]
#define sipNameNr_faceModeChanged 14641
#define sipName_faceModeChanged &sipStrings_Qt3DRender[14641]
#define sipNameNr_farPlaneChanged 14657
#define sipName_farPlaneChanged &sipStrings_Qt3DRender[14657]
#define sipNameNr_farValueChanged 14673
#define sipName_farValueChanged &sipStrings_Qt3DRender[14673]
#define sipNameNr_frontOutputMask 14689
#define sipName_frontOutputMask &sipStrings_Qt3DRender[14689]
#define sipNameNr_generateMipMaps 14705
#define sipName_generateMipMaps &sipStrings_Qt3DRender[14705]
#define sipNameNr_geometryChanged 14721
#define sipName_geometryChanged &sipStrings_Qt3DRender[14721]
#define sipNameNr_geometryFactory 14737
#define sipName_geometryFactory &sipStrings_Qt3DRender[14737]
#define sipNameNr_maxSSBOBindings 14753
#define sipName_maxSSBOBindings &sipStrings_Qt3DRender[14753]
#define sipNameNr_maxTextureUnits 14769
#define sipName_maxTextureUnits &sipStrings_Qt3DRender[14769]
#define sipNameNr_meshNameChanged 14785
#define sipName_meshNameChanged &sipStrings_Qt3DRender[14785]
#define sipNameNr_mipLevelChanged 14801
#define sipName_mipLevelChanged &sipStrings_Qt3DRender[14801]
#define sipNameNr_mirroredChanged 14817
#define sipName_mirroredChanged &sipStrings_Qt3DRender[14817]
#define sipNameNr_pickingSettings 14833
#define sipName_pickingSettings &sipStrings_Qt3DRender[14833]
#define sipNameNr_positionChanged 14849
#define sipName_positionChanged &sipStrings_Qt3DRender[14849]
#define sipNameNr_priorityChanged 14865
#define sipName_priorityChanged &sipStrings_Qt3DRender[14865]
#define sipNameNr_removeAttribute 14881
#define sipName_removeAttribute &sipStrings_Qt3DRender[14881]
#define sipNameNr_removeFilterKey 14897
#define sipName_removeFilterKey &sipStrings_Qt3DRender[14897]
#define sipNameNr_removeParameter 14913
#define sipName_removeParameter &sipStrings_Qt3DRender[14913]
#define sipNameNr_removeTechnique 14929
#define sipName_removeTechnique &sipStrings_Qt3DRender[14929]
#define sipNameNr_setCurrentIndex 14945
#define sipName_setCurrentIndex &sipStrings_Qt3DRender[14945]
#define sipNameNr_setHoverEnabled 14961
#define sipName_setHoverEnabled &sipStrings_Qt3DRender[14961]
#define sipNameNr_setMajorVersion 14977
#define sipName_setMajorVersion &sipStrings_Qt3DRender[14977]
#define sipNameNr_setMinorVersion 14993
#define sipName_setMinorVersion &sipStrings_Qt3DRender[14993]
#define sipNameNr_setRenderPolicy 15009
#define sipName_setRenderPolicy &sipStrings_Qt3DRender[15009]
#define sipNameNr_sizeModeChanged 15025
#define sipName_sizeModeChanged &sipStrings_Qt3DRender[15025]
#define sipNameNr_specularChanged 15041
#define sipName_specularChanged &sipStrings_Qt3DRender[15041]
#define sipNameNr_stencilFunction 15057
#define sipName_stencilFunction &sipStrings_Qt3DRender[15057]
#define sipNameNr_supportsCompute 15073
#define sipName_supportsCompute &sipStrings_Qt3DRender[15073]
#define sipNameNr_syncDataChanged 15089
#define sipName_syncDataChanged &sipStrings_Qt3DRender[15089]
#define sipNameNr_upVectorChanged 15105
#define sipName_upVectorChanged &sipStrings_Qt3DRender[15105]
#define sipNameNr_CompareGreater 15121
#define sipName_CompareGreater &sipStrings_Qt3DRender[15121]
#define sipNameNr_ComparisonMode 879
#define sipName_ComparisonMode &sipStrings_Qt3DRender[879]
#define sipNameNr_GreaterOrEqual 15136
#define sipName_GreaterOrEqual &sipStrings_Qt3DRender[15136]
#define sipNameNr_IndexAttribute 15151
#define sipName_IndexAttribute &sipStrings_Qt3DRender[15151]
#define sipNameNr_KeypadModifier 15166
#define sipName_KeypadModifier &sipStrings_Qt3DRender[15166]
#define sipNameNr_LightComponent 15181
#define sipName_LightComponent &sipStrings_Qt3DRender[15181]
#define sipNameNr_LinesAdjacency 15196
#define sipName_LinesAdjacency &sipStrings_Qt3DRender[15196]
#define sipNameNr_MirroredRepeat 15211
#define sipName_MirroredRepeat &sipStrings_Qt3DRender[15211]
#define sipNameNr_PickResultMode 1014
#define sipName_PickResultMode &sipStrings_Qt3DRender[1014]
#define sipNameNr_ProjectionType 1850
#define sipName_ProjectionType &sipStrings_Qt3DRender[1850]
#define sipNameNr_QAbstractLight 6565
#define sipName_QAbstractLight &sipStrings_Qt3DRender[6565]
#define sipNameNr_QAlphaCoverage 6592
#define sipName_QAlphaCoverage &sipStrings_Qt3DRender[6592]
#define sipNameNr_QBlendEquation 6619
#define sipName_QBlendEquation &sipStrings_Qt3DRender[6619]
#define sipNameNr_QLevelOfDetail 6646
#define sipName_QLevelOfDetail &sipStrings_Qt3DRender[6646]
#define sipNameNr_QMemoryBarrier 6673
#define sipName_QMemoryBarrier &sipStrings_Qt3DRender[6673]
#define sipNameNr_QPickLineEvent 6700
#define sipName_QPickLineEvent &sipStrings_Qt3DRender[6700]
#define sipNameNr_QPolygonOffset 6727
#define sipName_QPolygonOffset &sipStrings_Qt3DRender[6727]
#define sipNameNr_QRenderCapture 6754
#define sipName_QRenderCapture &sipStrings_Qt3DRender[6754]
#define sipNameNr_QShaderProgram 6781
#define sipName_QShaderProgram &sipStrings_Qt3DRender[6781]
#define sipNameNr_QTextureBuffer 6808
#define sipName_QTextureBuffer &sipStrings_Qt3DRender[6808]
#define sipNameNr_QTextureLoader 6835
#define sipName_QTextureLoader &sipStrings_Qt3DRender[6835]
#define sipNameNr_RG11_EAC_SNorm 15226
#define sipName_RG11_EAC_SNorm &sipStrings_Qt3DRender[15226]
#define sipNameNr_RG11_EAC_UNorm 15241
#define sipName_RG11_EAC_UNorm &sipStrings_Qt3DRender[15241]
#define sipNameNr_RGBA8_ETC2_EAC 15256
#define sipName_RGBA8_ETC2_EAC &sipStrings_Qt3DRender[15256]
#define sipNameNr_RG_ATI2N_SNorm 15271
#define sipName_RG_ATI2N_SNorm &sipStrings_Qt3DRender[15271]
#define sipNameNr_RG_ATI2N_UNorm 15286
#define sipName_RG_ATI2N_UNorm &sipStrings_Qt3DRender[15286]
#define sipNameNr_VertexBaseType 2009
#define sipName_VertexBaseType &sipStrings_Qt3DRender[2009]
#define sipNameNr_addRenderState 15301
#define sipName_addRenderState &sipStrings_Qt3DRender[15301]
#define sipNameNr_backOutputMask 15316
#define sipName_backOutputMask &sipStrings_Qt3DRender[15316]
#define sipNameNr_buffersChanged 15331
#define sipName_buffersChanged &sipStrings_Qt3DRender[15331]
#define sipNameNr_comparisonMask 15346
#define sipName_comparisonMask &sipStrings_Qt3DRender[15346]
#define sipNameNr_comparisonMode 15361
#define sipName_comparisonMode &sipStrings_Qt3DRender[15361]
#define sipNameNr_destinationRgb 15376
#define sipName_destinationRgb &sipStrings_Qt3DRender[15376]
#define sipNameNr_divisorChanged 15391
#define sipName_divisorChanged &sipStrings_Qt3DRender[15391]
#define sipNameNr_isHoverEnabled 15406
#define sipName_isHoverEnabled &sipStrings_Qt3DRender[15406]
#define sipNameNr_layeredChanged 15421
#define sipName_layeredChanged &sipStrings_Qt3DRender[15421]
#define sipNameNr_localDirection 15436
#define sipName_localDirection &sipStrings_Qt3DRender[15436]
#define sipNameNr_maxTextureSize 15451
#define sipName_maxTextureSize &sipStrings_Qt3DRender[15451]
#define sipNameNr_maxUBOBindings 15466
#define sipName_maxUBOBindings &sipStrings_Qt3DRender[15466]
#define sipNameNr_normalizedRect 15481
#define sipName_normalizedRect &sipStrings_Qt3DRender[15481]
#define sipNameNr_pickResultMode 15496
#define sipName_pickResultMode &sipStrings_Qt3DRender[15496]
#define sipNameNr_pressedChanged 15511
#define sipName_pressedChanged &sipStrings_Qt3DRender[15511]
#define sipNameNr_primitiveIndex 15526
#define sipName_primitiveIndex &sipStrings_Qt3DRender[15526]
#define sipNameNr_profileChanged 15541
#define sipName_profileChanged &sipStrings_Qt3DRender[15541]
#define sipNameNr_projectionType 15556
#define sipName_projectionType &sipStrings_Qt3DRender[15556]
#define sipNameNr_propertyReader 15571
#define sipName_propertyReader &sipStrings_Qt3DRender[15571]
#define sipNameNr_referenceValue 15586
#define sipName_referenceValue &sipStrings_Qt3DRender[15586]
#define sipNameNr_requestCapture 15601
#define sipName_requestCapture &sipStrings_Qt3DRender[15601]
#define sipNameNr_runModeChanged 15616
#define sipName_runModeChanged &sipStrings_Qt3DRender[15616]
#define sipNameNr_runTypeChanged 15631
#define sipName_runTypeChanged &sipStrings_Qt3DRender[15631]
#define sipNameNr_samplesChanged 15646
#define sipName_samplesChanged &sipStrings_Qt3DRender[15646]
#define sipNameNr_setAlphaMasked 15661
#define sipName_setAlphaMasked &sipStrings_Qt3DRender[15661]
#define sipNameNr_setAspectRatio 15676
#define sipName_setAspectRatio &sipStrings_Qt3DRender[15676]
#define sipNameNr_setBufferIndex 15691
#define sipName_setBufferIndex &sipStrings_Qt3DRender[15691]
#define sipNameNr_setColorBuffer 15706
#define sipName_setColorBuffer &sipStrings_Qt3DRender[15706]
#define sipNameNr_setCutOffAngle 15721
#define sipName_setCutOffAngle &sipStrings_Qt3DRender[15721]
#define sipNameNr_setDestination 15736
#define sipName_setDestination &sipStrings_Qt3DRender[15736]
#define sipNameNr_setDragEnabled 15751
#define sipName_setDragEnabled &sipStrings_Qt3DRender[15751]
#define sipNameNr_setFieldOfView 15766
#define sipName_setFieldOfView &sipStrings_Qt3DRender[15766]
#define sipNameNr_setFirstVertex 15781
#define sipName_setFirstVertex &sipStrings_Qt3DRender[15781]
#define sipNameNr_setGreenMasked 15796
#define sipName_setGreenMasked &sipStrings_Qt3DRender[15796]
#define sipNameNr_setIndexOffset 15811
#define sipName_setIndexOffset &sipStrings_Qt3DRender[15811]
#define sipNameNr_setPixelFormat 15826
#define sipName_setPixelFormat &sipStrings_Qt3DRender[15826]
#define sipNameNr_setScaleFactor 15841
#define sipName_setScaleFactor &sipStrings_Qt3DRender[15841]
#define sipNameNr_setSourceAlpha 15856
#define sipName_setSourceAlpha &sipStrings_Qt3DRender[15856]
#define sipNameNr_setVertexCount 15871
#define sipName_setVertexCount &sipStrings_Qt3DRender[15871]
#define sipNameNr_surfaceChanged 15886
#define sipName_surfaceChanged &sipStrings_Qt3DRender[15886]
#define sipNameNr_textureChanged 15901
#define sipName_textureChanged &sipStrings_Qt3DRender[15901]
#define sipNameNr_timeoutChanged 15916
#define sipName_timeoutChanged &sipStrings_Qt3DRender[15916]
#define sipNameNr_translateWorld 15931
#define sipName_translateWorld &sipStrings_Qt3DRender[15931]
#define sipNameNr_vertexBaseType 15946
#define sipName_vertexBaseType &sipStrings_Qt3DRender[15946]
#define sipNameNr_volumeOverride 15961
#define sipName_volumeOverride &sipStrings_Qt3DRender[15961]
#define sipNameNr_waitOperations 15976
#define sipName_waitOperations &sipStrings_Qt3DRender[15976]
#define sipNameNr_worldDirection 15991
#define sipName_worldDirection &sipStrings_Qt3DRender[15991]
#define sipNameNr_AlphaFunction 2399
#define sipName_AlphaFunction &sipStrings_Qt3DRender[2399]
#define sipNameNr_AtomicCounter 16006
#define sipName_AtomicCounter &sipStrings_Qt3DRender[16006]
#define sipNameNr_AttributeType 2437
#define sipName_AttributeType &sipStrings_Qt3DRender[2437]
#define sipNameNr_BlendFunction 1400
#define sipName_BlendFunction &sipStrings_Qt3DRender[1400]
#define sipNameNr_ClampToBorder 16020
#define sipName_ClampToBorder &sipStrings_Qt3DRender[16020]
#define sipNameNr_CompareAlways 16034
#define sipName_CompareAlways &sipStrings_Qt3DRender[16034]
#define sipNameNr_ComponentType 1891
#define sipName_ComponentType &sipStrings_Qt3DRender[1891]
#define sipNameNr_ConstantAlpha 9605
#define sipName_ConstantAlpha &sipStrings_Qt3DRender[9605]
#define sipNameNr_ConstantColor 9627
#define sipName_ConstantColor &sipStrings_Qt3DRender[9627]
#define sipNameNr_DecrementWrap 16048
#define sipName_DecrementWrap &sipStrings_Qt3DRender[16048]
#define sipNameNr_DepthFunction 2513
#define sipName_DepthFunction &sipStrings_Qt3DRender[2513]
#define sipNameNr_IncrementWrap 16062
#define sipName_IncrementWrap &sipStrings_Qt3DRender[16062]
#define sipNameNr_OpenGLFenceId 16076
#define sipName_OpenGLFenceId &sipStrings_Qt3DRender[16076]
#define sipNameNr_OpenGLProfile 790
#define sipName_OpenGLProfile &sipStrings_Qt3DRender[790]
#define sipNameNr_PrimitiveType 970
#define sipName_PrimitiveType &sipStrings_Qt3DRender[970]
#define sipNameNr_QClearBuffers 7238
#define sipName_QClearBuffers &sipStrings_Qt3DRender[7238]
#define sipNameNr_QObjectPicker 7290
#define sipName_QObjectPicker &sipStrings_Qt3DRender[7290]
#define sipNameNr_QRayCasterHit 7316
#define sipName_QRayCasterHit &sipStrings_Qt3DRender[7316]
#define sipNameNr_QRenderAspect 7342
#define sipName_QRenderAspect &sipStrings_Qt3DRender[7342]
#define sipNameNr_QRenderTarget 7368
#define sipName_QRenderTarget &sipStrings_Qt3DRender[7368]
#define sipNameNr_QTextureImage 7394
#define sipName_QTextureImage &sipStrings_Qt3DRender[7394]
#define sipNameNr_R11_EAC_SNorm 16090
#define sipName_R11_EAC_SNorm &sipStrings_Qt3DRender[16090]
#define sipNameNr_R11_EAC_UNorm 16104
#define sipName_R11_EAC_UNorm &sipStrings_Qt3DRender[16104]
#define sipNameNr_R_ATI1N_SNorm 16118
#define sipName_R_ATI1N_SNorm &sipStrings_Qt3DRender[16118]
#define sipNameNr_R_ATI1N_UNorm 16132
#define sipName_R_ATI1N_UNorm &sipStrings_Qt3DRender[16132]
#define sipNameNr_SRGB_BP_UNorm 16146
#define sipName_SRGB_BP_UNorm &sipStrings_Qt3DRender[16146]
#define sipNameNr_ShaderStorage 16160
#define sipName_ShaderStorage &sipStrings_Qt3DRender[16160]
#define sipNameNr_ShiftModifier 16174
#define sipName_ShiftModifier &sipStrings_Qt3DRender[16174]
#define sipNameNr_StencilBuffer 8374
#define sipName_StencilBuffer &sipStrings_Qt3DRender[8374]
#define sipNameNr_Target1DArray 16188
#define sipName_Target1DArray &sipStrings_Qt3DRender[16188]
#define sipNameNr_Target2DArray 16202
#define sipName_Target2DArray &sipStrings_Qt3DRender[16202]
#define sipNameNr_TargetCubeMap 16216
#define sipName_TargetCubeMap &sipStrings_Qt3DRender[16216]
#define sipNameNr_TextureFormat 1103
#define sipName_TextureFormat &sipStrings_Qt3DRender[1103]
#define sipNameNr_TextureUpdate 16230
#define sipName_TextureUpdate &sipStrings_Qt3DRender[16230]
#define sipNameNr_ThresholdType 1442
#define sipName_ThresholdType &sipStrings_Qt3DRender[1442]
#define sipNameNr_TriangleStrip 16244
#define sipName_TriangleStrip &sipStrings_Qt3DRender[16244]
#define sipNameNr_UniformBuffer 16258
#define sipName_UniformBuffer &sipStrings_Qt3DRender[16258]
#define sipNameNr_UnsignedShort 16272
#define sipName_UnsignedShort &sipStrings_Qt3DRender[16272]
#define sipNameNr_accessChanged 16286
#define sipName_accessChanged &sipStrings_Qt3DRender[16286]
#define sipNameNr_addRenderPass 16300
#define sipName_addRenderPass &sipStrings_Qt3DRender[16300]
#define sipNameNr_alphaFunction 16314
#define sipName_alphaFunction &sipStrings_Qt3DRender[16314]
#define sipNameNr_attributeType 16328
#define sipName_attributeType &sipStrings_Qt3DRender[16328]
#define sipNameNr_blendFunction 16342
#define sipName_blendFunction &sipStrings_Qt3DRender[16342]
#define sipNameNr_bottomChanged 16356
#define sipName_bottomChanged &sipStrings_Qt3DRender[16356]
#define sipNameNr_bufferChanged 16370
#define sipName_bufferChanged &sipStrings_Qt3DRender[16370]
#define sipNameNr_cameraChanged 16384
#define sipName_cameraChanged &sipStrings_Qt3DRender[16384]
#define sipNameNr_connectNotify 13783
#define sipName_connectNotify &sipStrings_Qt3DRender[13783]
#define sipNameNr_containsMouse 16398
#define sipName_containsMouse &sipStrings_Qt3DRender[16398]
#define sipNameNr_dataAvailable 16412
#define sipName_dataAvailable &sipStrings_Qt3DRender[16412]
#define sipNameNr_dataGenerator 16426
#define sipName_dataGenerator &sipStrings_Qt3DRender[16426]
#define sipNameNr_depthFunction 16440
#define sipName_depthFunction &sipStrings_Qt3DRender[16440]
#define sipNameNr_driverVersion 16454
#define sipName_driverVersion &sipStrings_Qt3DRender[16454]
#define sipNameNr_effectChanged 16468
#define sipName_effectChanged &sipStrings_Qt3DRender[16468]
#define sipNameNr_enabledLayers 16482
#define sipName_enabledLayers &sipStrings_Qt3DRender[16482]
#define sipNameNr_entityChanged 16496
#define sipName_entityChanged &sipStrings_Qt3DRender[16496]
#define sipNameNr_firstInstance 16510
#define sipName_firstInstance &sipStrings_Qt3DRender[16510]
#define sipNameNr_formatChanged 16524
#define sipName_formatChanged &sipStrings_Qt3DRender[16524]
#define sipNameNr_handleChanged 16538
#define sipName_handleChanged &sipStrings_Qt3DRender[16538]
#define sipNameNr_heightChanged 16552
#define sipName_heightChanged &sipStrings_Qt3DRender[16552]
#define sipNameNr_instanceCount 16566
#define sipName_instanceCount &sipStrings_Qt3DRender[16566]
#define sipNameNr_isAlphaMasked 16580
#define sipName_isAlphaMasked &sipStrings_Qt3DRender[16580]
#define sipNameNr_isDragEnabled 16594
#define sipName_isDragEnabled &sipStrings_Qt3DRender[16594]
#define sipNameNr_isGreenMasked 16608
#define sipName_isGreenMasked &sipStrings_Qt3DRender[16608]
#define sipNameNr_layersChanged 16622
#define sipName_layersChanged &sipStrings_Qt3DRender[16622]
#define sipNameNr_lengthChanged 16636
#define sipName_lengthChanged &sipStrings_Qt3DRender[16636]
#define sipNameNr_maxImageUnits 16650
#define sipName_maxImageUnits &sipStrings_Qt3DRender[16650]
#define sipNameNr_normalChanged 16664
#define sipName_normalChanged &sipStrings_Qt3DRender[16664]
#define sipNameNr_originChanged 16678
#define sipName_originChanged &sipStrings_Qt3DRender[16678]
#define sipNameNr_primitiveType 16692
#define sipName_primitiveType &sipStrings_Qt3DRender[16692]
#define sipNameNr_requestUpdate 16706
#define sipName_requestUpdate &sipStrings_Qt3DRender[16706]
#define sipNameNr_setAccessType 16720
#define sipName_setAccessType &sipStrings_Qt3DRender[16720]
#define sipNameNr_setBlueMasked 16734
#define sipName_setBlueMasked &sipStrings_Qt3DRender[16734]
#define sipNameNr_setByteOffset 16748
#define sipName_setByteOffset &sipStrings_Qt3DRender[16748]
#define sipNameNr_setByteStride 16762
#define sipName_setByteStride &sipStrings_Qt3DRender[16762]
#define sipNameNr_setClearColor 16776
#define sipName_setClearColor &sipStrings_Qt3DRender[16776]
#define sipNameNr_setDepthSteps 16790
#define sipName_setDepthSteps &sipStrings_Qt3DRender[16790]
#define sipNameNr_setEnablement 16804
#define sipName_setEnablement &sipStrings_Qt3DRender[16804]
#define sipNameNr_setExtensions 16818
#define sipName_setExtensions &sipStrings_Qt3DRender[16818]
#define sipNameNr_setFilterMode 16832
#define sipName_setFilterMode &sipStrings_Qt3DRender[16832]
#define sipNameNr_setHandleType 16846
#define sipName_setHandleType &sipStrings_Qt3DRender[16846]
#define sipNameNr_setIrradiance 16860
#define sipName_setIrradiance &sipStrings_Qt3DRender[16860]
#define sipNameNr_setPickMethod 16874
#define sipName_setPickMethod &sipStrings_Qt3DRender[16874]
#define sipNameNr_setPlaneIndex 16888
#define sipName_setPlaneIndex &sipStrings_Qt3DRender[16888]
#define sipNameNr_setRasterMode 16902
#define sipName_setRasterMode &sipStrings_Qt3DRender[16902]
#define sipNameNr_setShaderCode 16916
#define sipName_setShaderCode &sipStrings_Qt3DRender[16916]
#define sipNameNr_setSourceRect 16930
#define sipName_setSourceRect &sipStrings_Qt3DRender[16930]
#define sipNameNr_setSourceRgba 16944
#define sipName_setSourceRgba &sipStrings_Qt3DRender[16944]
#define sipNameNr_setThresholds 16958
#define sipName_setThresholds &sipStrings_Qt3DRender[16958]
#define sipNameNr_setVertexSize 16972
#define sipName_setVertexSize &sipStrings_Qt3DRender[16972]
#define sipNameNr_setViewCenter 16986
#define sipName_setViewCenter &sipStrings_Qt3DRender[16986]
#define sipNameNr_setWorkGroupX 17000
#define sipName_setWorkGroupX &sipStrings_Qt3DRender[17000]
#define sipNameNr_setWorkGroupY 17014
#define sipName_setWorkGroupY &sipStrings_Qt3DRender[17014]
#define sipNameNr_setWorkGroupZ 17028
#define sipName_setWorkGroupZ &sipStrings_Qt3DRender[17028]
#define sipNameNr_shaderProgram 17042
#define sipName_shaderProgram &sipStrings_Qt3DRender[17042]
#define sipNameNr_smoothChanged 17056
#define sipName_smoothChanged &sipStrings_Qt3DRender[17056]
#define sipNameNr_sourceChanged 17070
#define sipName_sourceChanged &sipStrings_Qt3DRender[17070]
#define sipNameNr_statusChanged 17084
#define sipName_statusChanged &sipStrings_Qt3DRender[17084]
#define sipNameNr_targetChanged 17098
#define sipName_targetChanged &sipStrings_Qt3DRender[17098]
#define sipNameNr_textureImages 17112
#define sipName_textureImages &sipStrings_Qt3DRender[17112]
#define sipNameNr_thresholdType 17126
#define sipName_thresholdType &sipStrings_Qt3DRender[17126]
#define sipNameNr_triangleIndex 17140
#define sipName_triangleIndex &sipStrings_Qt3DRender[17140]
#define sipNameNr_vendorChanged 17154
#define sipName_vendorChanged &sipStrings_Qt3DRender[17154]
#define sipNameNr_BufferUpdate 17168
#define sipName_BufferUpdate &sipStrings_Qt3DRender[17168]
#define sipNameNr_CompareEqual 17181
#define sipName_CompareEqual &sipStrings_Qt3DRender[17181]
#define sipNameNr_CompareNever 17194
#define sipName_CompareNever &sipStrings_Qt3DRender[17194]
#define sipNameNr_DepthStencil 17207
#define sipName_DepthStencil &sipStrings_Qt3DRender[17207]
#define sipNameNr_ElementArray 17220
#define sipName_ElementArray &sipStrings_Qt3DRender[17220]
#define sipNameNr_FrontAndBack 17233
#define sipName_FrontAndBack &sipStrings_Qt3DRender[17233]
#define sipNameNr_MetaModifier 17246
#define sipName_MetaModifier &sipStrings_Qt3DRender[17246]
#define sipNameNr_MiddleButton 17259
#define sipName_MiddleButton &sipStrings_Qt3DRender[17259]
#define sipNameNr_PointPicking 17272
#define sipName_PointPicking &sipStrings_Qt3DRender[17272]
#define sipNameNr_Programmable 17285
#define sipName_Programmable &sipStrings_Qt3DRender[17285]
#define sipNameNr_QLayerFilter 7728
#define sipName_QLayerFilter &sipStrings_Qt3DRender[7728]
#define sipNameNr_QNoDepthMask 7753
#define sipName_QNoDepthMask &sipStrings_Qt3DRender[7753]
#define sipNameNr_QRenderState 7778
#define sipName_QRenderState &sipStrings_Qt3DRender[7778]
#define sipNameNr_QSceneLoader 7803
#define sipName_QSceneLoader &sipStrings_Qt3DRender[7803]
#define sipNameNr_QScissorTest 7828
#define sipName_QScissorTest &sipStrings_Qt3DRender[7828]
#define sipNameNr_QShaderImage 7853
#define sipName_QShaderImage &sipStrings_Qt3DRender[7853]
#define sipNameNr_QStencilMask 7878
#define sipName_QStencilMask &sipStrings_Qt3DRender[7878]
#define sipNameNr_QStencilTest 7903
#define sipName_QStencilTest &sipStrings_Qt3DRender[7903]
#define sipNameNr_QTextureData 7928
#define sipName_QTextureData &sipStrings_Qt3DRender[7928]
#define sipNameNr_RGBA16_SNorm 17298
#define sipName_RGBA16_SNorm &sipStrings_Qt3DRender[17298]
#define sipNameNr_RGBA16_UNorm 17311
#define sipName_RGBA16_UNorm &sipStrings_Qt3DRender[17311]
#define sipNameNr_RGB_BP_UNorm 16147
#define sipName_RGB_BP_UNorm &sipStrings_Qt3DRender[16147]
#define sipNameNr_RenderPolicy 1485
#define sipName_RenderPolicy &sipStrings_Qt3DRender[1485]
#define sipNameNr_SRGB8_Alpha8 17324
#define sipName_SRGB8_Alpha8 &sipStrings_Qt3DRender[17324]
#define sipNameNr_Source1Alpha 10394
#define sipName_Source1Alpha &sipStrings_Qt3DRender[10394]
#define sipNameNr_Source1Color 10415
#define sipName_Source1Color &sipStrings_Qt3DRender[10415]
#define sipNameNr_TargetBuffer 17337
#define sipName_TargetBuffer &sipStrings_Qt3DRender[17337]
#define sipNameNr_TextureFetch 17350
#define sipName_TextureFetch &sipStrings_Qt3DRender[17350]
#define sipNameNr_UnsignedByte 17363
#define sipName_UnsignedByte &sipStrings_Qt3DRender[17363]
#define sipNameNr_VertexBuffer 17376
#define sipName_VertexBuffer &sipStrings_Qt3DRender[17376]
#define sipNameNr_addAttribute 17389
#define sipName_addAttribute &sipStrings_Qt3DRender[17389]
#define sipNameNr_addFilterKey 17402
#define sipName_addFilterKey &sipStrings_Qt3DRender[17402]
#define sipNameNr_addImageData 17415
#define sipName_addImageData &sipStrings_Qt3DRender[17415]
#define sipNameNr_addParameter 17428
#define sipName_addParameter &sipStrings_Qt3DRender[17428]
#define sipNameNr_addTechnique 17441
#define sipName_addTechnique &sipStrings_Qt3DRender[17441]
#define sipNameNr_colorChanged 17454
#define sipName_colorChanged &sipStrings_Qt3DRender[17454]
#define sipNameNr_countChanged 17467
#define sipName_countChanged &sipStrings_Qt3DRender[17467]
#define sipNameNr_currentIndex 17480
#define sipName_currentIndex &sipStrings_Qt3DRender[17480]
#define sipNameNr_depthChanged 17493
#define sipName_depthChanged &sipStrings_Qt3DRender[17493]
#define sipNameNr_gammaChanged 17506
#define sipName_gammaChanged &sipStrings_Qt3DRender[17506]
#define sipNameNr_isBlueMasked 17519
#define sipName_isBlueMasked &sipStrings_Qt3DRender[17519]
#define sipNameNr_isCompressed 17532
#define sipName_isCompressed &sipStrings_Qt3DRender[17532]
#define sipNameNr_layerChanged 17545
#define sipName_layerChanged &sipStrings_Qt3DRender[17545]
#define sipNameNr_majorVersion 17558
#define sipName_majorVersion &sipStrings_Qt3DRender[17558]
#define sipNameNr_minorVersion 17571
#define sipName_minorVersion &sipStrings_Qt3DRender[17571]
#define sipNameNr_readProperty 17584
#define sipName_readProperty &sipStrings_Qt3DRender[17584]
#define sipNameNr_removeOutput 17597
#define sipName_removeOutput &sipStrings_Qt3DRender[17597]
#define sipNameNr_renderPasses 17610
#define sipName_renderPasses &sipStrings_Qt3DRender[17610]
#define sipNameNr_renderPolicy 17623
#define sipName_renderPolicy &sipStrings_Qt3DRender[17623]
#define sipNameNr_renderStates 17636
#define sipName_renderStates &sipStrings_Qt3DRender[17636]
#define sipNameNr_rightChanged 17649
#define sipName_rightChanged &sipStrings_Qt3DRender[17649]
#define sipNameNr_rollRotation 17662
#define sipName_rollRotation &sipStrings_Qt3DRender[17662]
#define sipNameNr_setDirection 17675
#define sipName_setDirection &sipStrings_Qt3DRender[17675]
#define sipNameNr_setIntensity 17688
#define sipName_setIntensity &sipStrings_Qt3DRender[17688]
#define sipNameNr_setMipLevels 17701
#define sipName_setMipLevels &sipStrings_Qt3DRender[17701]
#define sipNameNr_setNearPlane 17714
#define sipName_setNearPlane &sipStrings_Qt3DRender[17714]
#define sipNameNr_setNearValue 17727
#define sipName_setNearValue &sipStrings_Qt3DRender[17727]
#define sipNameNr_setPixelType 17740
#define sipName_setPixelType &sipStrings_Qt3DRender[17740]
#define sipNameNr_setRecursive 17753
#define sipName_setRecursive &sipStrings_Qt3DRender[17753]
#define sipNameNr_setRedMasked 17766
#define sipName_setRedMasked &sipStrings_Qt3DRender[17766]
#define sipNameNr_setSortTypes 17779
#define sipName_setSortTypes &sipStrings_Qt3DRender[17779]
#define sipNameNr_setSourceRgb 17792
#define sipName_setSourceRgb &sipStrings_Qt3DRender[17792]
#define sipNameNr_setTextureId 17805
#define sipName_setTextureId &sipStrings_Qt3DRender[17805]
#define sipNameNr_setWaitOnCPU 17818
#define sipName_setWaitOnCPU &sipStrings_Qt3DRender[17818]
#define sipNameNr_setWrapModeX 17831
#define sipName_setWrapModeX &sipStrings_Qt3DRender[17831]
#define sipNameNr_setWrapModeY 17844
#define sipName_setWrapModeY &sipStrings_Qt3DRender[17844]
#define sipNameNr_setWrapModeZ 17857
#define sipName_setWrapModeZ &sipStrings_Qt3DRender[17857]
#define sipNameNr_sortTypesInt 17870
#define sipName_sortTypesInt &sipStrings_Qt3DRender[17870]
#define sipNameNr_supportsSSBO 17883
#define sipName_supportsSSBO &sipStrings_Qt3DRender[17883]
#define sipNameNr_tiltRotation 17896
#define sipName_tiltRotation &sipStrings_Qt3DRender[17896]
#define sipNameNr_usageChanged 17909
#define sipName_usageChanged &sipStrings_Qt3DRender[17909]
#define sipNameNr_valueChanged 17922
#define sipName_valueChanged &sipStrings_Qt3DRender[17922]
#define sipNameNr_vertex1Index 17935
#define sipName_vertex1Index &sipStrings_Qt3DRender[17935]
#define sipNameNr_vertex2Index 17948
#define sipName_vertex2Index &sipStrings_Qt3DRender[17948]
#define sipNameNr_vertex3Index 17961
#define sipName_vertex3Index &sipStrings_Qt3DRender[17961]
#define sipNameNr_widthChanged 17974
#define sipName_widthChanged &sipStrings_Qt3DRender[17974]
#define sipNameNr_AlphaFormat 10353
#define sipName_AlphaFormat &sipStrings_Qt3DRender[10353]
#define sipNameNr_AltModifier 17987
#define sipName_AltModifier &sipStrings_Qt3DRender[17987]
#define sipNameNr_BackToFront 17999
#define sipName_BackToFront &sipStrings_Qt3DRender[17999]
#define sipNameNr_ClampToEdge 18011
#define sipName_ClampToEdge &sipStrings_Qt3DRender[18011]
#define sipNameNr_ColorBuffer 15709
#define sipName_ColorBuffer &sipStrings_Qt3DRender[15709]
#define sipNameNr_CompareLess 18023
#define sipName_CompareLess &sipStrings_Qt3DRender[18023]
#define sipNameNr_CompareNone 18035
#define sipName_CompareNone &sipStrings_Qt3DRender[18035]
#define sipNameNr_CoreProfile 18047
#define sipName_CoreProfile &sipStrings_Qt3DRender[18047]
#define sipNameNr_CubeMapFace 1360
#define sipName_CubeMapFace &sipStrings_Qt3DRender[1360]
#define sipNameNr_CullingMode 3323
#define sipName_CullingMode &sipStrings_Qt3DRender[3323]
#define sipNameNr_DepthBuffer 13479
#define sipName_DepthBuffer &sipStrings_Qt3DRender[13479]
#define sipNameNr_DepthFormat 18059
#define sipName_DepthFormat &sipStrings_Qt3DRender[18059]
#define sipNameNr_DynamicCopy 18071
#define sipName_DynamicCopy &sipStrings_Qt3DRender[18071]
#define sipNameNr_DynamicDraw 18083
#define sipName_DynamicDraw &sipStrings_Qt3DRender[18083]
#define sipNameNr_DynamicRead 18095
#define sipName_DynamicRead &sipStrings_Qt3DRender[18095]
#define sipNameNr_FrameBuffer 18107
#define sipName_FrameBuffer &sipStrings_Qt3DRender[18107]
#define sipNameNr_FrontToBack 18119
#define sipName_FrontToBack &sipStrings_Qt3DRender[18119]
#define sipNameNr_ImageFormat 2629
#define sipName_ImageFormat &sipStrings_Qt3DRender[2629]
#define sipNameNr_IndexBuffer 18131
#define sipName_IndexBuffer &sipStrings_Qt3DRender[18131]
#define sipNameNr_LessOrEqual 18143
#define sipName_LessOrEqual &sipStrings_Qt3DRender[18143]
#define sipNameNr_LinePicking 18155
#define sipName_LinePicking &sipStrings_Qt3DRender[18155]
#define sipNameNr_NearestPick 18167
#define sipName_NearestPick &sipStrings_Qt3DRender[18167]
#define sipNameNr_PixelBuffer 18179
#define sipName_PixelBuffer &sipStrings_Qt3DRender[18179]
#define sipNameNr_QCameraLens 8424
#define sipName_QCameraLens &sipStrings_Qt3DRender[8424]
#define sipNameNr_QDepthRange 8448
#define sipName_QDepthRange &sipStrings_Qt3DRender[8448]
#define sipNameNr_QPointLight 8472
#define sipName_QPointLight &sipStrings_Qt3DRender[8472]
#define sipNameNr_QRasterMode 8496
#define sipName_QRasterMode &sipStrings_Qt3DRender[8496]
#define sipNameNr_QRenderPass 8520
#define sipName_QRenderPass &sipStrings_Qt3DRender[8520]
#define sipNameNr_QShaderData 8544
#define sipName_QShaderData &sipStrings_Qt3DRender[8544]
#define sipNameNr_QSortPolicy 8568
#define sipName_QSortPolicy &sipStrings_Qt3DRender[8568]
#define sipNameNr_QueryBuffer 18191
#define sipName_QueryBuffer &sipStrings_Qt3DRender[18191]
#define sipNameNr_RGB16_SNorm 18203
#define sipName_RGB16_SNorm &sipStrings_Qt3DRender[18203]
#define sipNameNr_RGB16_UNorm 18215
#define sipName_RGB16_UNorm &sipStrings_Qt3DRender[18215]
#define sipNameNr_RGBA8_SNorm 18227
#define sipName_RGBA8_SNorm &sipStrings_Qt3DRender[18227]
#define sipNameNr_RGBA8_UNorm 18239
#define sipName_RGBA8_UNorm &sipStrings_Qt3DRender[18239]
#define sipNameNr_RightButton 18251
#define sipName_RightButton &sipStrings_Qt3DRender[18251]
#define sipNameNr_SourceAlpha 11060
#define sipName_SourceAlpha &sipStrings_Qt3DRender[11060]
#define sipNameNr_SourceColor 11080
#define sipName_SourceColor &sipStrings_Qt3DRender[11080]
#define sipNameNr_Synchronous 18263
#define sipName_Synchronous &sipStrings_Qt3DRender[18263]
#define sipNameNr_TriangleFan 18275
#define sipName_TriangleFan &sipStrings_Qt3DRender[18275]
#define sipNameNr_TriangleHit 18287
#define sipName_TriangleHit &sipStrings_Qt3DRender[18287]
#define sipNameNr_UnsignedInt 18299
#define sipName_UnsignedInt &sipStrings_Qt3DRender[18299]
#define sipNameNr_aspectRatio 18311
#define sipName_aspectRatio &sipStrings_Qt3DRender[18311]
#define sipNameNr_bufferIndex 18323
#define sipName_bufferIndex &sipStrings_Qt3DRender[18323]
#define sipNameNr_colorBuffer 18335
#define sipName_colorBuffer &sipStrings_Qt3DRender[18335]
#define sipNameNr_customEvent 18347
#define sipName_customEvent &sipStrings_Qt3DRender[18347]
#define sipNameNr_cutOffAngle 18359
#define sipName_cutOffAngle &sipStrings_Qt3DRender[18359]
#define sipNameNr_dataChanged 18371
#define sipName_dataChanged &sipStrings_Qt3DRender[18371]
#define sipNameNr_destination 18383
#define sipName_destination &sipStrings_Qt3DRender[18383]
#define sipNameNr_entityNames 18395
#define sipName_entityNames &sipStrings_Qt3DRender[18395]
#define sipNameNr_eventFilter 18407
#define sipName_eventFilter &sipStrings_Qt3DRender[18407]
#define sipNameNr_faceChanged 15889
#define sipName_faceChanged &sipStrings_Qt3DRender[15889]
#define sipNameNr_fieldOfView 18419
#define sipName_fieldOfView &sipStrings_Qt3DRender[18419]
#define sipNameNr_firstVertex 18431
#define sipName_firstVertex &sipStrings_Qt3DRender[18431]
#define sipNameNr_glslVersion 18443
#define sipName_glslVersion &sipStrings_Qt3DRender[18443]
#define sipNameNr_hitsChanged 18455
#define sipName_hitsChanged &sipStrings_Qt3DRender[18455]
#define sipNameNr_indexOffset 18467
#define sipName_indexOffset &sipStrings_Qt3DRender[18467]
#define sipNameNr_isRedMasked 18479
#define sipName_isRedMasked &sipStrings_Qt3DRender[18479]
#define sipNameNr_leftChanged 18491
#define sipName_leftChanged &sipStrings_Qt3DRender[18491]
#define sipNameNr_maxSSBOSize 18503
#define sipName_maxSSBOSize &sipStrings_Qt3DRender[18503]
#define sipNameNr_mipmapLevel 18515
#define sipName_mipmapLevel &sipStrings_Qt3DRender[18515]
#define sipNameNr_modeChanged 18527
#define sipName_modeChanged &sipStrings_Qt3DRender[18527]
#define sipNameNr_nameChanged 18539
#define sipName_nameChanged &sipStrings_Qt3DRender[18539]
#define sipNameNr_panRotation 18551
#define sipName_panRotation &sipStrings_Qt3DRender[18551]
#define sipNameNr_pixelFormat 18563
#define sipName_pixelFormat &sipStrings_Qt3DRender[18563]
#define sipNameNr_removeLayer 18575
#define sipName_removeLayer &sipStrings_Qt3DRender[18575]
#define sipNameNr_removeMatch 18587
#define sipName_removeMatch &sipStrings_Qt3DRender[18587]
#define sipNameNr_scaleFactor 18599
#define sipName_scaleFactor &sipStrings_Qt3DRender[18599]
#define sipNameNr_setAccepted 18611
#define sipName_setAccepted &sipStrings_Qt3DRender[18611]
#define sipNameNr_setDataSize 18623
#define sipName_setDataSize &sipStrings_Qt3DRender[18623]
#define sipNameNr_setDataType 18635
#define sipName_setDataType &sipStrings_Qt3DRender[18635]
#define sipNameNr_setDistance 18647
#define sipName_setDistance &sipStrings_Qt3DRender[18647]
#define sipNameNr_setExposure 18659
#define sipName_setExposure &sipStrings_Qt3DRender[18659]
#define sipNameNr_setFaceMode 18671
#define sipName_setFaceMode &sipStrings_Qt3DRender[18671]
#define sipNameNr_setFarPlane 18683
#define sipName_setFarPlane &sipStrings_Qt3DRender[18683]
#define sipNameNr_setFarValue 18695
#define sipName_setFarValue &sipStrings_Qt3DRender[18695]
#define sipNameNr_setGeometry 18707
#define sipName_setGeometry &sipStrings_Qt3DRender[18707]
#define sipNameNr_setMeshName 18719
#define sipName_setMeshName &sipStrings_Qt3DRender[18719]
#define sipNameNr_setMipLevel 18731
#define sipName_setMipLevel &sipStrings_Qt3DRender[18731]
#define sipNameNr_setMirrored 18743
#define sipName_setMirrored &sipStrings_Qt3DRender[18743]
#define sipNameNr_setPosition 18755
#define sipName_setPosition &sipStrings_Qt3DRender[18755]
#define sipNameNr_setPriority 18767
#define sipName_setPriority &sipStrings_Qt3DRender[18767]
#define sipNameNr_setSizeMode 18779
#define sipName_setSizeMode &sipStrings_Qt3DRender[18779]
#define sipNameNr_setSpecular 18791
#define sipName_setSpecular &sipStrings_Qt3DRender[18791]
#define sipNameNr_setSyncData 18803
#define sipName_setSyncData &sipStrings_Qt3DRender[18803]
#define sipNameNr_setUpVector 18815
#define sipName_setUpVector &sipStrings_Qt3DRender[18815]
#define sipNameNr_setWrapMode 18827
#define sipName_setWrapMode &sipStrings_Qt3DRender[18827]
#define sipNameNr_sizeChanged 18839
#define sipName_sizeChanged &sipStrings_Qt3DRender[18839]
#define sipNameNr_sourceAlpha 18851
#define sipName_sourceAlpha &sipStrings_Qt3DRender[18851]
#define sipNameNr_supportsUBO 18863
#define sipName_supportsUBO &sipStrings_Qt3DRender[18863]
#define sipNameNr_typeChanged 18875
#define sipName_typeChanged &sipStrings_Qt3DRender[18875]
#define sipNameNr_vertexCount 18887
#define sipName_vertexCount &sipStrings_Qt3DRender[18887]
#define sipNameNr_AccessType 4706
#define sipName_AccessType &sipStrings_Qt3DRender[4706]
#define sipNameNr_AllBuffers 18899
#define sipName_AllBuffers &sipStrings_Qt3DRender[18899]
#define sipNameNr_BackButton 18910
#define sipName_BackButton &sipStrings_Qt3DRender[18910]
#define sipNameNr_BufferType 2478
#define sipName_BufferType &sipStrings_Qt3DRender[2478]
#define sipNameNr_Continuous 18921
#define sipName_Continuous &sipStrings_Qt3DRender[18921]
#define sipNameNr_Enablement 1934
#define sipName_Enablement &sipStrings_Qt3DRender[1934]
#define sipNameNr_FilterMode 1192
#define sipName_FilterMode &sipStrings_Qt3DRender[1192]
#define sipNameNr_HandleType 1569
#define sipName_HandleType &sipStrings_Qt3DRender[1569]
#define sipNameNr_LeftButton 18932
#define sipName_LeftButton &sipStrings_Qt3DRender[18932]
#define sipNameNr_NoModifier 18943
#define sipName_NoModifier &sipStrings_Qt3DRender[18943]
#define sipNameNr_Operations 2052
#define sipName_Operations &sipStrings_Qt3DRender[2052]
#define sipNameNr_Persistent 18954
#define sipName_Persistent &sipStrings_Qt3DRender[18954]
#define sipNameNr_PickMethod 1692
#define sipName_PickMethod &sipStrings_Qt3DRender[1692]
#define sipNameNr_PointLight 8473
#define sipName_PointLight &sipStrings_Qt3DRender[8473]
#define sipNameNr_QAlphaTest 8760
#define sipName_QAlphaTest &sipStrings_Qt3DRender[8760]
#define sipNameNr_QAttribute 8783
#define sipName_QAttribute &sipStrings_Qt3DRender[8783]
#define sipNameNr_QClipPlane 8806
#define sipName_QClipPlane &sipStrings_Qt3DRender[8806]
#define sipNameNr_QColorMask 8829
#define sipName_QColorMask &sipStrings_Qt3DRender[8829]
#define sipNameNr_QDepthTest 8852
#define sipName_QDepthTest &sipStrings_Qt3DRender[8852]
#define sipNameNr_QDithering 8875
#define sipName_QDithering &sipStrings_Qt3DRender[8875]
#define sipNameNr_QFilterKey 8898
#define sipName_QFilterKey &sipStrings_Qt3DRender[8898]
#define sipNameNr_QFrontFace 8921
#define sipName_QFrontFace &sipStrings_Qt3DRender[8921]
#define sipNameNr_QLineWidth 8944
#define sipName_QLineWidth &sipStrings_Qt3DRender[8944]
#define sipNameNr_QNoPicking 8967
#define sipName_QNoPicking &sipStrings_Qt3DRender[8967]
#define sipNameNr_QParameter 8990
#define sipName_QParameter &sipStrings_Qt3DRender[8990]
#define sipNameNr_QPickEvent 9013
#define sipName_QPickEvent &sipStrings_Qt3DRender[9013]
#define sipNameNr_QPointSize 9036
#define sipName_QPointSize &sipStrings_Qt3DRender[9036]
#define sipNameNr_QRayCaster 9059
#define sipName_QRayCaster &sipStrings_Qt3DRender[9059]
#define sipNameNr_QSpotLight 9082
#define sipName_QSpotLight &sipStrings_Qt3DRender[9082]
#define sipNameNr_QTechnique 9105
#define sipName_QTechnique &sipStrings_Qt3DRender[9105]
#define sipNameNr_QTexture1D 9128
#define sipName_QTexture1D &sipStrings_Qt3DRender[9128]
#define sipNameNr_QTexture2D 9151
#define sipName_QTexture2D &sipStrings_Qt3DRender[9151]
#define sipNameNr_QTexture3D 9174
#define sipName_QTexture3D &sipStrings_Qt3DRender[9174]
#define sipNameNr_QWaitFence 9197
#define sipName_QWaitFence &sipStrings_Qt3DRender[9197]
#define sipNameNr_Qt3DRender 13701
#define sipName_Qt3DRender &sipStrings_Qt3DRender[13701]
#define sipNameNr_RG16_SNorm 18965
#define sipName_RG16_SNorm &sipStrings_Qt3DRender[18965]
#define sipNameNr_RG16_UNorm 18976
#define sipName_RG16_UNorm &sipStrings_Qt3DRender[18976]
#define sipNameNr_RGB8_SNorm 18987
#define sipName_RGB8_SNorm &sipStrings_Qt3DRender[18987]
#define sipNameNr_RGB8_UNorm 18998
#define sipName_RGB8_UNorm &sipStrings_Qt3DRender[18998]
#define sipNameNr_RGBAFormat 19009
#define sipName_RGBAFormat &sipStrings_Qt3DRender[19009]
#define sipNameNr_RasterMode 3183
#define sipName_RasterMode &sipStrings_Qt3DRender[3183]
#define sipNameNr_RenderType 2592
#define sipName_RenderType &sipStrings_Qt3DRender[2592]
#define sipNameNr_SRGB8_ETC2 19020
#define sipName_SRGB8_ETC2 &sipStrings_Qt3DRender[19020]
#define sipNameNr_ShaderType 2091
#define sipName_ShaderType &sipStrings_Qt3DRender[2091]
#define sipNameNr_SingleShot 19031
#define sipName_SingleShot &sipStrings_Qt3DRender[19031]
#define sipNameNr_StaticCopy 19042
#define sipName_StaticCopy &sipStrings_Qt3DRender[19042]
#define sipNameNr_StaticDraw 19053
#define sipName_StaticDraw &sipStrings_Qt3DRender[19053]
#define sipNameNr_StaticRead 19064
#define sipName_StaticRead &sipStrings_Qt3DRender[19064]
#define sipNameNr_StreamCopy 19075
#define sipName_StreamCopy &sipStrings_Qt3DRender[19075]
#define sipNameNr_StreamDraw 19086
#define sipName_StreamDraw &sipStrings_Qt3DRender[19086]
#define sipNameNr_StreamRead 19097
#define sipName_StreamRead &sipStrings_Qt3DRender[19097]
#define sipNameNr___invert__ 19108
#define sipName___invert__ &sipStrings_Qt3DRender[19108]
#define sipNameNr_accessType 19119
#define sipName_accessType &sipStrings_Qt3DRender[19119]
#define sipNameNr_apiChanged 19130
#define sipName_apiChanged &sipStrings_Qt3DRender[19130]
#define sipNameNr_attributes 19141
#define sipName_attributes &sipStrings_Qt3DRender[19141]
#define sipNameNr_byteOffset 19152
#define sipName_byteOffset &sipStrings_Qt3DRender[19152]
#define sipNameNr_byteStride 19163
#define sipName_byteStride &sipStrings_Qt3DRender[19163]
#define sipNameNr_childEvent 19174
#define sipName_childEvent &sipStrings_Qt3DRender[19174]
#define sipNameNr_clearColor 19185
#define sipName_clearColor &sipStrings_Qt3DRender[19185]
#define sipNameNr_depthSteps 19196
#define sipName_depthSteps &sipStrings_Qt3DRender[19196]
#define sipNameNr_enablement 19207
#define sipName_enablement &sipStrings_Qt3DRender[19207]
#define sipNameNr_extensions 19218
#define sipName_extensions &sipStrings_Qt3DRender[19218]
#define sipNameNr_filterKeys 19229
#define sipName_filterKeys &sipStrings_Qt3DRender[19229]
#define sipNameNr_filterMode 19240
#define sipName_filterMode &sipStrings_Qt3DRender[19240]
#define sipNameNr_frameCount 19251
#define sipName_frameCount &sipStrings_Qt3DRender[19251]
#define sipNameNr_handleType 19262
#define sipName_handleType &sipStrings_Qt3DRender[19262]
#define sipNameNr_irradiance 19273
#define sipName_irradiance &sipStrings_Qt3DRender[19273]
#define sipNameNr_isAccepted 19284
#define sipName_isAccepted &sipStrings_Qt3DRender[19284]
#define sipNameNr_isComplete 19295
#define sipName_isComplete &sipStrings_Qt3DRender[19295]
#define sipNameNr_isMirrored 19306
#define sipName_isMirrored &sipStrings_Qt3DRender[19306]
#define sipNameNr_isSyncData 19317
#define sipName_isSyncData &sipStrings_Qt3DRender[19317]
#define sipNameNr_loadSource 19328
#define sipName_loadSource &sipStrings_Qt3DRender[19328]
#define sipNameNr_logChanged 19339
#define sipName_logChanged &sipStrings_Qt3DRender[19339]
#define sipNameNr_maxSamples 19350
#define sipName_maxSamples &sipStrings_Qt3DRender[19350]
#define sipNameNr_maxUBOSize 19361
#define sipName_maxUBOSize &sipStrings_Qt3DRender[19361]
#define sipNameNr_parameters 19372
#define sipName_parameters &sipStrings_Qt3DRender[19372]
#define sipNameNr_pickMethod 19383
#define sipName_pickMethod &sipStrings_Qt3DRender[19383]
#define sipNameNr_planeIndex 19394
#define sipName_planeIndex &sipStrings_Qt3DRender[19394]
#define sipNameNr_pointIndex 19405
#define sipName_pointIndex &sipStrings_Qt3DRender[19405]
#define sipNameNr_rasterMode 19416
#define sipName_rasterMode &sipStrings_Qt3DRender[19416]
#define sipNameNr_saveToFile 19427
#define sipName_saveToFile &sipStrings_Qt3DRender[19427]
#define sipNameNr_setBuffers 19438
#define sipName_setBuffers &sipStrings_Qt3DRender[19438]
#define sipNameNr_setDivisor 19449
#define sipName_setDivisor &sipStrings_Qt3DRender[19449]
#define sipNameNr_setLayered 19460
#define sipName_setLayered &sipStrings_Qt3DRender[19460]
#define sipNameNr_setProfile 19471
#define sipName_setProfile &sipStrings_Qt3DRender[19471]
#define sipNameNr_setRunMode 19482
#define sipName_setRunMode &sipStrings_Qt3DRender[19482]
#define sipNameNr_setRunType 19493
#define sipName_setRunType &sipStrings_Qt3DRender[19493]
#define sipNameNr_setSamples 19504
#define sipName_setSamples &sipStrings_Qt3DRender[19504]
#define sipNameNr_setSurface 19515
#define sipName_setSurface &sipStrings_Qt3DRender[19515]
#define sipNameNr_setTexture 19526
#define sipName_setTexture &sipStrings_Qt3DRender[19526]
#define sipNameNr_setTimeout 19537
#define sipName_setTimeout &sipStrings_Qt3DRender[19537]
#define sipNameNr_shaderCode 19548
#define sipName_shaderCode &sipStrings_Qt3DRender[19548]
#define sipNameNr_sourceRect 19559
#define sipName_sourceRect &sipStrings_Qt3DRender[19559]
#define sipNameNr_techniques 19570
#define sipName_techniques &sipStrings_Qt3DRender[19570]
#define sipNameNr_thresholds 19581
#define sipName_thresholds &sipStrings_Qt3DRender[19581]
#define sipNameNr_timerEvent 19592
#define sipName_timerEvent &sipStrings_Qt3DRender[19592]
#define sipNameNr_topChanged 19603
#define sipName_topChanged &sipStrings_Qt3DRender[19603]
#define sipNameNr_updateData 19614
#define sipName_updateData &sipStrings_Qt3DRender[19614]
#define sipNameNr_vertexSize 19625
#define sipName_vertexSize &sipStrings_Qt3DRender[19625]
#define sipNameNr_viewCenter 19636
#define sipName_viewCenter &sipStrings_Qt3DRender[19636]
#define sipNameNr_viewEntity 19647
#define sipName_viewEntity &sipStrings_Qt3DRender[19647]
#define sipNameNr_viewMatrix 19658
#define sipName_viewMatrix &sipStrings_Qt3DRender[19658]
#define sipNameNr_viewSphere 19669
#define sipName_viewSphere &sipStrings_Qt3DRender[19669]
#define sipNameNr_viewVector 19680
#define sipName_viewVector &sipStrings_Qt3DRender[19680]
#define sipNameNr_workGroupX 19691
#define sipName_workGroupX &sipStrings_Qt3DRender[19691]
#define sipNameNr_workGroupY 19702
#define sipName_workGroupY &sipStrings_Qt3DRender[19702]
#define sipNameNr_workGroupZ 19713
#define sipName_workGroupZ &sipStrings_Qt3DRender[19713]
#define sipNameNr_Automatic 14423
#define sipName_Automatic &sipStrings_Qt3DRender[14423]
#define sipNameNr_ClockWise 13532
#define sipName_ClockWise &sipStrings_Qt3DRender[13532]
#define sipNameNr_D32FS8X24 19724
#define sipName_D32FS8X24 &sipStrings_Qt3DRender[19724]
#define sipNameNr_Decrement 19734
#define sipName_Decrement &sipStrings_Qt3DRender[19734]
#define sipNameNr_EntityHit 19744
#define sipName_EntityHit &sipStrings_Qt3DRender[19744]
#define sipNameNr_FrontFace 8922
#define sipName_FrontFace &sipStrings_Qt3DRender[8922]
#define sipNameNr_HalfFloat 19754
#define sipName_HalfFloat &sipStrings_Qt3DRender[19754]
#define sipNameNr_Increment 19764
#define sipName_Increment &sipStrings_Qt3DRender[19764]
#define sipNameNr_LineStrip 19774
#define sipName_LineStrip &sipStrings_Qt3DRender[19774]
#define sipNameNr_Modifiers 3706
#define sipName_Modifiers &sipStrings_Qt3DRender[3706]
#define sipNameNr_NoCulling 19784
#define sipName_NoCulling &sipStrings_Qt3DRender[19784]
#define sipNameNr_NoProfile 19794
#define sipName_NoProfile &sipStrings_Qt3DRender[19794]
#define sipNameNr_Operation 414
#define sipName_Operation &sipStrings_Qt3DRender[414]
#define sipNameNr_QCullFace 9675
#define sipName_QCullFace &sipStrings_Qt3DRender[9675]
#define sipNameNr_QGeometry 9697
#define sipName_QGeometry &sipStrings_Qt3DRender[9697]
#define sipNameNr_QMaterial 9719
#define sipName_QMaterial &sipStrings_Qt3DRender[9719]
#define sipNameNr_QSetFence 9741
#define sipName_QSetFence &sipStrings_Qt3DRender[9741]
#define sipNameNr_QViewport 9763
#define sipName_QViewport &sipStrings_Qt3DRender[9763]
#define sipNameNr_R16_SNorm 19804
#define sipName_R16_SNorm &sipStrings_Qt3DRender[19804]
#define sipNameNr_R16_UNorm 19814
#define sipName_R16_UNorm &sipStrings_Qt3DRender[19814]
#define sipNameNr_RG8_SNorm 19824
#define sipName_RG8_SNorm &sipStrings_Qt3DRender[19824]
#define sipNameNr_RG8_UNorm 19834
#define sipName_RG8_UNorm &sipStrings_Qt3DRender[19834]
#define sipNameNr_RGB8_ETC1 19844
#define sipName_RGB8_ETC1 &sipStrings_Qt3DRender[19844]
#define sipNameNr_RGB8_ETC2 19021
#define sipName_RGB8_ETC2 &sipStrings_Qt3DRender[19021]
#define sipNameNr_RGBA_DXT1 19854
#define sipName_RGBA_DXT1 &sipStrings_Qt3DRender[19854]
#define sipNameNr_RGBA_DXT3 19864
#define sipName_RGBA_DXT3 &sipStrings_Qt3DRender[19864]
#define sipNameNr_RGBA_DXT5 19874
#define sipName_RGBA_DXT5 &sipStrings_Qt3DRender[19874]
#define sipNameNr_RGBFormat 19884
#define sipName_RGBFormat &sipStrings_Qt3DRender[19884]
#define sipNameNr_ReadWrite 19894
#define sipName_ReadWrite &sipStrings_Qt3DRender[19894]
#define sipNameNr_SRGB_DXT1 19904
#define sipName_SRGB_DXT1 &sipStrings_Qt3DRender[19904]
#define sipNameNr_SpotLight 9083
#define sipName_SpotLight &sipStrings_Qt3DRender[9083]
#define sipNameNr_Triangles 19914
#define sipName_Triangles &sipStrings_Qt3DRender[19914]
#define sipNameNr_UsageType 4993
#define sipName_UsageType &sipStrings_Qt3DRender[4993]
#define sipNameNr_WriteOnly 19924
#define sipName_WriteOnly &sipStrings_Qt3DRender[19924]
#define sipNameNr___index__ 19934
#define sipName___index__ &sipStrings_Qt3DRender[19934]
#define sipNameNr_addOutput 19944
#define sipName_addOutput &sipStrings_Qt3DRender[19944]
#define sipNameNr_captureId 19954
#define sipName_captureId &sipStrings_Qt3DRender[19954]
#define sipNameNr_completed 19964
#define sipName_completed &sipStrings_Qt3DRender[19964]
#define sipNameNr_component 19974
#define sipName_component &sipStrings_Qt3DRender[19974]
#define sipNameNr_direction 19984
#define sipName_direction &sipStrings_Qt3DRender[19984]
#define sipNameNr_edgeIndex 19994
#define sipName_edgeIndex &sipStrings_Qt3DRender[19994]
#define sipNameNr_imageData 20004
#define sipName_imageData &sipStrings_Qt3DRender[20004]
#define sipNameNr_intensity 20014
#define sipName_intensity &sipStrings_Qt3DRender[20014]
#define sipNameNr_isPressed 20024
#define sipName_isPressed &sipStrings_Qt3DRender[20024]
#define sipNameNr_maxExtent 20034
#define sipName_maxExtent &sipStrings_Qt3DRender[20034]
#define sipNameNr_minExtent 20044
#define sipName_minExtent &sipStrings_Qt3DRender[20044]
#define sipNameNr_mipLevels 20054
#define sipName_mipLevels &sipStrings_Qt3DRender[20054]
#define sipNameNr_modifiers 20064
#define sipName_modifiers &sipStrings_Qt3DRender[20064]
#define sipNameNr_nearPlane 20074
#define sipName_nearPlane &sipStrings_Qt3DRender[20074]
#define sipNameNr_nearValue 20084
#define sipName_nearValue &sipStrings_Qt3DRender[20084]
#define sipNameNr_pixelType 20094
#define sipName_pixelType &sipStrings_Qt3DRender[20094]
#define sipNameNr_recursive 20104
#define sipName_recursive &sipStrings_Qt3DRender[20104]
#define sipNameNr_saveImage 20114
#define sipName_saveImage &sipStrings_Qt3DRender[20114]
#define sipNameNr_setAccess 20124
#define sipName_setAccess &sipStrings_Qt3DRender[20124]
#define sipNameNr_setBottom 20134
#define sipName_setBottom &sipStrings_Qt3DRender[20134]
#define sipNameNr_setBuffer 20144
#define sipName_setBuffer &sipStrings_Qt3DRender[20144]
#define sipNameNr_setCamera 20154
#define sipName_setCamera &sipStrings_Qt3DRender[20154]
#define sipNameNr_setEffect 20164
#define sipName_setEffect &sipStrings_Qt3DRender[20164]
#define sipNameNr_setEntity 20174
#define sipName_setEntity &sipStrings_Qt3DRender[20174]
#define sipNameNr_setFormat 20184
#define sipName_setFormat &sipStrings_Qt3DRender[20184]
#define sipNameNr_setHandle 20194
#define sipName_setHandle &sipStrings_Qt3DRender[20194]
#define sipNameNr_setHeight 20204
#define sipName_setHeight &sipStrings_Qt3DRender[20204]
#define sipNameNr_setLayers 20214
#define sipName_setLayers &sipStrings_Qt3DRender[20214]
#define sipNameNr_setLength 20224
#define sipName_setLength &sipStrings_Qt3DRender[20224]
#define sipNameNr_setNormal 20234
#define sipName_setNormal &sipStrings_Qt3DRender[20234]
#define sipNameNr_setOrigin 20244
#define sipName_setOrigin &sipStrings_Qt3DRender[20244]
#define sipNameNr_setSmooth 20254
#define sipName_setSmooth &sipStrings_Qt3DRender[20254]
#define sipNameNr_setSource 20264
#define sipName_setSource &sipStrings_Qt3DRender[20264]
#define sipNameNr_setStatus 20274
#define sipName_setStatus &sipStrings_Qt3DRender[20274]
#define sipNameNr_setTarget 20284
#define sipName_setTarget &sipStrings_Qt3DRender[20284]
#define sipNameNr_setVendor 20294
#define sipName_setVendor &sipStrings_Qt3DRender[20294]
#define sipNameNr_sortTypes 20304
#define sipName_sortTypes &sipStrings_Qt3DRender[20304]
#define sipNameNr_sourceRgb 20314
#define sipName_sourceRgb &sipStrings_Qt3DRender[20314]
#define sipNameNr_textureId 20324
#define sipName_textureId &sipStrings_Qt3DRender[20324]
#define sipNameNr_transform 20334
#define sipName_transform &sipStrings_Qt3DRender[20334]
#define sipNameNr_translate 20344
#define sipName_translate &sipStrings_Qt3DRender[20344]
#define sipNameNr_waitOnCPU 20354
#define sipName_waitOnCPU &sipStrings_Qt3DRender[20354]
#define sipNameNr_wrapModeX 20364
#define sipName_wrapModeX &sipStrings_Qt3DRender[20364]
#define sipNameNr_wrapModeY 20374
#define sipName_wrapModeY &sipStrings_Qt3DRender[20374]
#define sipNameNr_wrapModeZ 20384
#define sipName_wrapModeZ &sipStrings_Qt3DRender[20384]
#define sipNameNr_AllFaces 20394
#define sipName_AllFaces &sipStrings_Qt3DRender[20394]
#define sipNameNr_AllPicks 20403
#define sipName_AllPicks &sipStrings_Qt3DRender[20403]
#define sipNameNr_BackFace 13669
#define sipName_BackFace &sipStrings_Qt3DRender[13669]
#define sipNameNr_Blending 749
#define sipName_Blending &sipStrings_Qt3DRender[749]
#define sipNameNr_FaceMode 264
#define sipName_FaceMode &sipStrings_Qt3DRender[264]
#define sipNameNr_Fragment 20412
#define sipName_Fragment &sipStrings_Qt3DRender[20412]
#define sipNameNr_Geometry 9698
#define sipName_Geometry &sipStrings_Qt3DRender[9698]
#define sipNameNr_LineLoop 20421
#define sipName_LineLoop &sipStrings_Qt3DRender[20421]
#define sipNameNr_Material 9720
#define sipName_Material &sipStrings_Qt3DRender[9720]
#define sipNameNr_NoButton 20430
#define sipName_NoButton &sipStrings_Qt3DRender[20430]
#define sipNameNr_NoFormat 20439
#define sipName_NoFormat &sipStrings_Qt3DRender[20439]
#define sipNameNr_NoHandle 20448
#define sipName_NoHandle &sipStrings_Qt3DRender[20448]
#define sipNameNr_NotEqual 13499
#define sipName_NotEqual &sipStrings_Qt3DRender[13499]
#define sipNameNr_NotReady 20457
#define sipName_NotReady &sipStrings_Qt3DRender[20457]
#define sipNameNr_OnDemand 20466
#define sipName_OnDemand &sipStrings_Qt3DRender[20466]
#define sipNameNr_OpenGLES 20475
#define sipName_OpenGLES &sipStrings_Qt3DRender[20475]
#define sipNameNr_PointHit 20484
#define sipName_PointHit &sipStrings_Qt3DRender[20484]
#define sipNameNr_R8_SNorm 20493
#define sipName_R8_SNorm &sipStrings_Qt3DRender[20493]
#define sipNameNr_R8_UNorm 20502
#define sipName_R8_UNorm &sipStrings_Qt3DRender[20502]
#define sipNameNr_RG11B10F 20511
#define sipName_RG11B10F &sipStrings_Qt3DRender[20511]
#define sipNameNr_RGB10A2U 20520
#define sipName_RGB10A2U &sipStrings_Qt3DRender[20520]
#define sipNameNr_RGB_DXT1 19905
#define sipName_RGB_DXT1 &sipStrings_Qt3DRender[19905]
#define sipNameNr_ReadOnly 20529
#define sipName_ReadOnly &sipStrings_Qt3DRender[20529]
#define sipNameNr_SizeMode 4412
#define sipName_SizeMode &sipStrings_Qt3DRender[4412]
#define sipNameNr_SortType 3877
#define sipName_SortType &sipStrings_Qt3DRender[3877]
#define sipNameNr_Subtract 14344
#define sipName_Subtract &sipStrings_Qt3DRender[14344]
#define sipNameNr_Target1D 20538
#define sipName_Target1D &sipStrings_Qt3DRender[20538]
#define sipNameNr_Target2D 20547
#define sipName_Target2D &sipStrings_Qt3DRender[20547]
#define sipNameNr_Target3D 20556
#define sipName_Target3D &sipStrings_Qt3DRender[20556]
#define sipNameNr_Threaded 20565
#define sipName_Threaded &sipStrings_Qt3DRender[20565]
#define sipNameNr_WrapMode 2249
#define sipName_WrapMode &sipStrings_Qt3DRender[2249]
#define sipNameNr___bool__ 20574
#define sipName___bool__ &sipStrings_Qt3DRender[20574]
#define sipNameNr___call__ 20583
#define sipName___call__ &sipStrings_Qt3DRender[20583]
#define sipNameNr___hash__ 20592
#define sipName___hash__ &sipStrings_Qt3DRender[20592]
#define sipNameNr___iand__ 20601
#define sipName___iand__ &sipStrings_Qt3DRender[20601]
#define sipNameNr___ixor__ 20610
#define sipName___ixor__ &sipStrings_Qt3DRender[20610]
#define sipNameNr_addLayer 20619
#define sipName_addLayer &sipStrings_Qt3DRender[20619]
#define sipNameNr_addMatch 20628
#define sipName_addMatch &sipStrings_Qt3DRender[20628]
#define sipNameNr_distance 20637
#define sipName_distance &sipStrings_Qt3DRender[20637]
#define sipNameNr_entityId 20646
#define sipName_entityId &sipStrings_Qt3DRender[20646]
#define sipNameNr_exposure 20655
#define sipName_exposure &sipStrings_Qt3DRender[20655]
#define sipNameNr_faceMode 20664
#define sipName_faceMode &sipStrings_Qt3DRender[20664]
#define sipNameNr_farPlane 20673
#define sipName_farPlane &sipStrings_Qt3DRender[20673]
#define sipNameNr_farValue 20682
#define sipName_farValue &sipStrings_Qt3DRender[20682]
#define sipNameNr_geometry 20691
#define sipName_geometry &sipStrings_Qt3DRender[20691]
#define sipNameNr_matchAll 20700
#define sipName_matchAll &sipStrings_Qt3DRender[20700]
#define sipNameNr_matchAny 20709
#define sipName_matchAny &sipStrings_Qt3DRender[20709]
#define sipNameNr_meshName 20718
#define sipName_meshName &sipStrings_Qt3DRender[20718]
#define sipNameNr_mipLevel 20727
#define sipName_mipLevel &sipStrings_Qt3DRender[20727]
#define sipNameNr_position 20736
#define sipName_position &sipStrings_Qt3DRender[20736]
#define sipNameNr_priority 20745
#define sipName_priority &sipStrings_Qt3DRender[20745]
#define sipNameNr_released 20754
#define sipName_released &sipStrings_Qt3DRender[20754]
#define sipNameNr_renderer 20763
#define sipName_renderer &sipStrings_Qt3DRender[20763]
#define sipNameNr_rotation 20772
#define sipName_rotation &sipStrings_Qt3DRender[20772]
#define sipNameNr_setColor 20781
#define sipName_setColor &sipStrings_Qt3DRender[20781]
#define sipNameNr_setCount 20790
#define sipName_setCount &sipStrings_Qt3DRender[20790]
#define sipNameNr_setDepth 20799
#define sipName_setDepth &sipStrings_Qt3DRender[20799]
#define sipNameNr_setFaces 20808
#define sipName_setFaces &sipStrings_Qt3DRender[20808]
#define sipNameNr_setGamma 20817
#define sipName_setGamma &sipStrings_Qt3DRender[20817]
#define sipNameNr_setImage 20826
#define sipName_setImage &sipStrings_Qt3DRender[20826]
#define sipNameNr_setLayer 20835
#define sipName_setLayer &sipStrings_Qt3DRender[20835]
#define sipNameNr_setRight 20844
#define sipName_setRight &sipStrings_Qt3DRender[20844]
#define sipNameNr_setUsage 20853
#define sipName_setUsage &sipStrings_Qt3DRender[20853]
#define sipNameNr_setValue 20862
#define sipName_setValue &sipStrings_Qt3DRender[20862]
#define sipNameNr_setWidth 20871
#define sipName_setWidth &sipStrings_Qt3DRender[20871]
#define sipNameNr_sizeMode 20880
#define sipName_sizeMode &sipStrings_Qt3DRender[20880]
#define sipNameNr_specular 20889
#define sipName_specular &sipStrings_Qt3DRender[20889]
#define sipNameNr_upVector 20898
#define sipName_upVector &sipStrings_Qt3DRender[20898]
#define sipNameNr_viewport 20907
#define sipName_viewport &sipStrings_Qt3DRender[20907]
#define sipNameNr_wrapMode 20916
#define sipName_wrapMode &sipStrings_Qt3DRender[20916]
#define sipNameNr_xChanged 8667
#define sipName_xChanged &sipStrings_Qt3DRender[8667]
#define sipNameNr_yChanged 8132
#define sipName_yChanged &sipStrings_Qt3DRender[8132]
#define sipNameNr_zChanged 20925
#define sipName_zChanged &sipStrings_Qt3DRender[20925]
#define sipNameNr_Buttons 4773
#define sipName_Buttons &sipStrings_Qt3DRender[4773]
#define sipNameNr_Color10 20934
#define sipName_Color10 &sipStrings_Qt3DRender[20934]
#define sipNameNr_Color11 20942
#define sipName_Color11 &sipStrings_Qt3DRender[20942]
#define sipNameNr_Color12 20950
#define sipName_Color12 &sipStrings_Qt3DRender[20950]
#define sipNameNr_Color13 20958
#define sipName_Color13 &sipStrings_Qt3DRender[20958]
#define sipNameNr_Color14 20966
#define sipName_Color14 &sipStrings_Qt3DRender[20966]
#define sipNameNr_Color15 20974
#define sipName_Color15 &sipStrings_Qt3DRender[20974]
#define sipNameNr_Command 6181
#define sipName_Command &sipStrings_Qt3DRender[6181]
#define sipNameNr_Compute 5748
#define sipName_Compute &sipStrings_Qt3DRender[5748]
#define sipNameNr_DirectX 20982
#define sipName_DirectX &sipStrings_Qt3DRender[20982]
#define sipNameNr_Greater 15128
#define sipName_Greater &sipStrings_Qt3DRender[15128]
#define sipNameNr_HitType 3362
#define sipName_HitType &sipStrings_Qt3DRender[3362]
#define sipNameNr_LineHit 20990
#define sipName_LineHit &sipStrings_Qt3DRender[20990]
#define sipNameNr_Loading 20998
#define sipName_Loading &sipStrings_Qt3DRender[20998]
#define sipNameNr_Nearest 10378
#define sipName_Nearest &sipStrings_Qt3DRender[10378]
#define sipNameNr_Patches 21006
#define sipName_Patches &sipStrings_Qt3DRender[21006]
#define sipNameNr_Profile 796
#define sipName_Profile &sipStrings_Qt3DRender[796]
#define sipNameNr_QBuffer 11104
#define sipName_QBuffer &sipStrings_Qt3DRender[11104]
#define sipNameNr_QCamera 11124
#define sipName_QCamera &sipStrings_Qt3DRender[11124]
#define sipNameNr_QEffect 11144
#define sipName_QEffect &sipStrings_Qt3DRender[11144]
#define sipNameNr_QNoDraw 11164
#define sipName_QNoDraw &sipStrings_Qt3DRender[11164]
#define sipNameNr_RGB10A2 21014
#define sipName_RGB10A2 &sipStrings_Qt3DRender[21014]
#define sipNameNr_RGBA16F 21022
#define sipName_RGBA16F &sipStrings_Qt3DRender[21022]
#define sipNameNr_RGBA16I 21030
#define sipName_RGBA16I &sipStrings_Qt3DRender[21030]
#define sipNameNr_RGBA16U 21038
#define sipName_RGBA16U &sipStrings_Qt3DRender[21038]
#define sipNameNr_RGBA32F 21046
#define sipName_RGBA32F &sipStrings_Qt3DRender[21046]
#define sipNameNr_RGBA32I 21054
#define sipName_RGBA32I &sipStrings_Qt3DRender[21054]
#define sipNameNr_RGBA32U 21062
#define sipName_RGBA32U &sipStrings_Qt3DRender[21062]
#define sipNameNr_Replace 21070
#define sipName_Replace &sipStrings_Qt3DRender[21070]
#define sipNameNr_RunMode 1817
#define sipName_RunMode &sipStrings_Qt3DRender[1817]
#define sipNameNr_RunType 2857
#define sipName_RunType &sipStrings_Qt3DRender[2857]
#define sipNameNr_Stencil 17212
#define sipName_Stencil &sipStrings_Qt3DRender[17212]
#define sipNameNr_Texture 5690
#define sipName_Texture &sipStrings_Qt3DRender[5690]
#define sipNameNr_Uniform 21078
#define sipName_Uniform &sipStrings_Qt3DRender[21078]
#define sipNameNr___and__ 21086
#define sipName___and__ &sipStrings_Qt3DRender[21086]
#define sipNameNr___int__ 21094
#define sipName___int__ &sipStrings_Qt3DRender[21094]
#define sipNameNr___ior__ 21102
#define sipName___ior__ &sipStrings_Qt3DRender[21102]
#define sipNameNr___xor__ 21110
#define sipName___xor__ &sipStrings_Qt3DRender[21110]
#define sipNameNr_buffers 21118
#define sipName_buffers &sipStrings_Qt3DRender[21118]
#define sipNameNr_buttons 21126
#define sipName_buttons &sipStrings_Qt3DRender[21126]
#define sipNameNr_cleanup 21134
#define sipName_cleanup &sipStrings_Qt3DRender[21134]
#define sipNameNr_clicked 21142
#define sipName_clicked &sipStrings_Qt3DRender[21142]
#define sipNameNr_divisor 21150
#define sipName_divisor &sipStrings_Qt3DRender[21150]
#define sipNameNr_entered 21158
#define sipName_entered &sipStrings_Qt3DRender[21158]
#define sipNameNr_isEmpty 21166
#define sipName_isEmpty &sipStrings_Qt3DRender[21166]
#define sipNameNr_isValid 21174
#define sipName_isValid &sipStrings_Qt3DRender[21174]
#define sipNameNr_layered 21182
#define sipName_layered &sipStrings_Qt3DRender[21182]
#define sipNameNr_outputs 21190
#define sipName_outputs &sipStrings_Qt3DRender[21190]
#define sipNameNr_pressed 17537
#define sipName_pressed &sipStrings_Qt3DRender[17537]
#define sipNameNr_profile 21198
#define sipName_profile &sipStrings_Qt3DRender[21198]
#define sipNameNr_runMode 21206
#define sipName_runMode &sipStrings_Qt3DRender[21206]
#define sipNameNr_runType 21214
#define sipName_runType &sipStrings_Qt3DRender[21214]
#define sipNameNr_samples 21222
#define sipName_samples &sipStrings_Qt3DRender[21222]
#define sipNameNr_setData 21230
#define sipName_setData &sipStrings_Qt3DRender[21230]
#define sipNameNr_setFace 21238
#define sipName_setFace &sipStrings_Qt3DRender[21238]
#define sipNameNr_setLeft 21246
#define sipName_setLeft &sipStrings_Qt3DRender[21246]
#define sipNameNr_setMode 21254
#define sipName_setMode &sipStrings_Qt3DRender[21254]
#define sipNameNr_setName 21262
#define sipName_setName &sipStrings_Qt3DRender[21262]
#define sipNameNr_setSize 21270
#define sipName_setSize &sipStrings_Qt3DRender[21270]
#define sipNameNr_setType 21278
#define sipName_setType &sipStrings_Qt3DRender[21278]
#define sipNameNr_surface 21286
#define sipName_surface &sipStrings_Qt3DRender[21286]
#define sipNameNr_texture 21294
#define sipName_texture &sipStrings_Qt3DRender[21294]
#define sipNameNr_timeout 21302
#define sipName_timeout &sipStrings_Qt3DRender[21302]
#define sipNameNr_trigger 21310
#define sipName_trigger &sipStrings_Qt3DRender[21310]
#define sipNameNr_viewAll 21318
#define sipName_viewAll &sipStrings_Qt3DRender[21318]
#define sipNameNr_Access 4480
#define sipName_Access &sipStrings_Qt3DRender[4480]
#define sipNameNr_Always 16041
#define sipName_Always &sipStrings_Qt3DRender[16041]
#define sipNameNr_Color0 9656
#define sipName_Color0 &sipStrings_Qt3DRender[9656]
#define sipNameNr_Color1 21326
#define sipName_Color1 &sipStrings_Qt3DRender[21326]
#define sipNameNr_Color2 21333
#define sipName_Color2 &sipStrings_Qt3DRender[21333]
#define sipNameNr_Color3 21340
#define sipName_Color3 &sipStrings_Qt3DRender[21340]
#define sipNameNr_Color4 21347
#define sipName_Color4 &sipStrings_Qt3DRender[21347]
#define sipNameNr_Color5 21354
#define sipName_Color5 &sipStrings_Qt3DRender[21354]
#define sipNameNr_Color6 21361
#define sipName_Color6 &sipStrings_Qt3DRender[21361]
#define sipNameNr_Color7 21368
#define sipName_Color7 &sipStrings_Qt3DRender[21368]
#define sipNameNr_Color8 21375
#define sipName_Color8 &sipStrings_Qt3DRender[21375]
#define sipNameNr_Color9 21382
#define sipName_Color9 &sipStrings_Qt3DRender[21382]
#define sipNameNr_Double 21389
#define sipName_Double &sipStrings_Qt3DRender[21389]
#define sipNameNr_Filter 2747
#define sipName_Filter &sipStrings_Qt3DRender[2747]
#define sipNameNr_Format 1110
#define sipName_Format &sipStrings_Qt3DRender[1110]
#define sipNameNr_Invert 21396
#define sipName_Invert &sipStrings_Qt3DRender[21396]
#define sipNameNr_Linear 11025
#define sipName_Linear &sipStrings_Qt3DRender[11025]
#define sipNameNr_Manual 21403
#define sipName_Manual &sipStrings_Qt3DRender[21403]
#define sipNameNr_OpenGL 21410
#define sipName_OpenGL &sipStrings_Qt3DRender[21410]
#define sipNameNr_Points 21417
#define sipName_Points &sipStrings_Qt3DRender[21417]
#define sipNameNr_QLayer 11701
#define sipName_QLayer &sipStrings_Qt3DRender[11701]
#define sipNameNr_R5G6B5 21424
#define sipName_R5G6B5 &sipStrings_Qt3DRender[21424]
#define sipNameNr_RGB16F 21431
#define sipName_RGB16F &sipStrings_Qt3DRender[21431]
#define sipNameNr_RGB16I 21438
#define sipName_RGB16I &sipStrings_Qt3DRender[21438]
#define sipNameNr_RGB16U 21445
#define sipName_RGB16U &sipStrings_Qt3DRender[21445]
#define sipNameNr_RGB32F 21452
#define sipName_RGB32F &sipStrings_Qt3DRender[21452]
#define sipNameNr_RGB32I 21459
#define sipName_RGB32I &sipStrings_Qt3DRender[21459]
#define sipNameNr_RGB32U 21466
#define sipName_RGB32U &sipStrings_Qt3DRender[21466]
#define sipNameNr_RGB5A1 21473
#define sipName_RGB5A1 &sipStrings_Qt3DRender[21473]
#define sipNameNr_RGB9E5 21480
#define sipName_RGB9E5 &sipStrings_Qt3DRender[21480]
#define sipNameNr_RGBA8I 21487
#define sipName_RGBA8I &sipStrings_Qt3DRender[21487]
#define sipNameNr_RGBA8U 21494
#define sipName_RGBA8U &sipStrings_Qt3DRender[21494]
#define sipNameNr_Render 11720
#define sipName_Render &sipStrings_Qt3DRender[11720]
#define sipNameNr_Repeat 15219
#define sipName_Repeat &sipStrings_Qt3DRender[15219]
#define sipNameNr_Status 2784
#define sipName_Status &sipStrings_Qt3DRender[2784]
#define sipNameNr_Target 2821
#define sipName_Target &sipStrings_Qt3DRender[2821]
#define sipNameNr_Vertex 15789
#define sipName_Vertex &sipStrings_Qt3DRender[15789]
#define sipNameNr_Vulkan 21501
#define sipName_Vulkan &sipStrings_Qt3DRender[21501]
#define sipNameNr___eq__ 21508
#define sipName___eq__ &sipStrings_Qt3DRender[21508]
#define sipNameNr___ne__ 21515
#define sipName___ne__ &sipStrings_Qt3DRender[21515]
#define sipNameNr___or__ 21522
#define sipName___or__ &sipStrings_Qt3DRender[21522]
#define sipNameNr_access 21529
#define sipName_access &sipStrings_Qt3DRender[21529]
#define sipNameNr_bottom 21536
#define sipName_bottom &sipStrings_Qt3DRender[21536]
#define sipNameNr_buffer 5720
#define sipName_buffer &sipStrings_Qt3DRender[5720]
#define sipNameNr_button 21543
#define sipName_button &sipStrings_Qt3DRender[21543]
#define sipNameNr_camera 21550
#define sipName_camera &sipStrings_Qt3DRender[21550]
#define sipNameNr_center 21557
#define sipName_center &sipStrings_Qt3DRender[21557]
#define sipNameNr_effect 21564
#define sipName_effect &sipStrings_Qt3DRender[21564]
#define sipNameNr_entity 21571
#define sipName_entity &sipStrings_Qt3DRender[21571]
#define sipNameNr_exited 21578
#define sipName_exited &sipStrings_Qt3DRender[21578]
#define sipNameNr_format 21585
#define sipName_format &sipStrings_Qt3DRender[21585]
#define sipNameNr_handle 21592
#define sipName_handle &sipStrings_Qt3DRender[21592]
#define sipNameNr_height 21599
#define sipName_height &sipStrings_Qt3DRender[21599]
#define sipNameNr_layers 21606
#define sipName_layers &sipStrings_Qt3DRender[21606]
#define sipNameNr_length 21613
#define sipName_length &sipStrings_Qt3DRender[21613]
#define sipNameNr_normal 21620
#define sipName_normal &sipStrings_Qt3DRender[21620]
#define sipNameNr_offset 21627
#define sipName_offset &sipStrings_Qt3DRender[21627]
#define sipNameNr_option 21634
#define sipName_option &sipStrings_Qt3DRender[21634]
#define sipNameNr_origin 21641
#define sipName_origin &sipStrings_Qt3DRender[21641]
#define sipNameNr_parent 21648
#define sipName_parent &sipStrings_Qt3DRender[21648]
#define sipNameNr_radius 21655
#define sipName_radius &sipStrings_Qt3DRender[21655]
#define sipNameNr_rotate 21662
#define sipName_rotate &sipStrings_Qt3DRender[21662]
#define sipNameNr_setApi 21669
#define sipName_setApi &sipStrings_Qt3DRender[21669]
#define sipNameNr_setTop 21676
#define sipName_setTop &sipStrings_Qt3DRender[21676]
#define sipNameNr_smooth 21683
#define sipName_smooth &sipStrings_Qt3DRender[21683]
#define sipNameNr_source 21690
#define sipName_source &sipStrings_Qt3DRender[21690]
#define sipNameNr_status 21697
#define sipName_status &sipStrings_Qt3DRender[21697]
#define sipNameNr_stride 21704
#define sipName_stride &sipStrings_Qt3DRender[21704]
#define sipNameNr_target 21711
#define sipName_target &sipStrings_Qt3DRender[21711]
#define sipNameNr_update 21718
#define sipName_update &sipStrings_Qt3DRender[21718]
#define sipNameNr_vendor 21725
#define sipName_vendor &sipStrings_Qt3DRender[21725]
#define sipNameNr_D24S8 21732
#define sipName_D24S8 &sipStrings_Qt3DRender[21732]
#define sipNameNr_Depth 20802
#define sipName_Depth &sipStrings_Qt3DRender[20802]
#define sipNameNr_Equal 10966
#define sipName_Equal &sipStrings_Qt3DRender[10966]
#define sipNameNr_Error 21738
#define sipName_Error &sipStrings_Qt3DRender[21738]
#define sipNameNr_Fixed 21744
#define sipName_Fixed &sipStrings_Qt3DRender[21744]
#define sipNameNr_Float 19758
#define sipName_Float &sipStrings_Qt3DRender[19758]
#define sipNameNr_Front 18005
#define sipName_Front &sipStrings_Qt3DRender[18005]
#define sipNameNr_Lines 21750
#define sipName_Lines &sipStrings_Qt3DRender[21750]
#define sipNameNr_Never 17201
#define sipName_Never &sipStrings_Qt3DRender[17201]
#define sipNameNr_None_ 21756
#define sipName_None_ &sipStrings_Qt3DRender[21756]
#define sipNameNr_QMesh 12478
#define sipName_QMesh &sipStrings_Qt3DRender[12478]
#define sipNameNr_RG16F 21762
#define sipName_RG16F &sipStrings_Qt3DRender[21762]
#define sipNameNr_RG16I 21768
#define sipName_RG16I &sipStrings_Qt3DRender[21768]
#define sipNameNr_RG16U 21774
#define sipName_RG16U &sipStrings_Qt3DRender[21774]
#define sipNameNr_RG32F 21780
#define sipName_RG32F &sipStrings_Qt3DRender[21780]
#define sipNameNr_RG32I 21786
#define sipName_RG32I &sipStrings_Qt3DRender[21786]
#define sipNameNr_RG32U 21792
#define sipName_RG32U &sipStrings_Qt3DRender[21792]
#define sipNameNr_RG3B2 21798
#define sipName_RG3B2 &sipStrings_Qt3DRender[21798]
#define sipNameNr_RGB8I 21804
#define sipName_RGB8I &sipStrings_Qt3DRender[21804]
#define sipNameNr_RGB8U 21810
#define sipName_RGB8U &sipStrings_Qt3DRender[21810]
#define sipNameNr_RGBA4 21816
#define sipName_RGBA4 &sipStrings_Qt3DRender[21816]
#define sipNameNr_Ready 20460
#define sipName_Ready &sipStrings_Qt3DRender[20460]
#define sipNameNr_SPIRV 21822
#define sipName_SPIRV &sipStrings_Qt3DRender[21822]
#define sipNameNr_SRGB8 21828
#define sipName_SRGB8 &sipStrings_Qt3DRender[21828]
#define sipNameNr_Short 16280
#define sipName_Short &sipStrings_Qt3DRender[16280]
#define sipNameNr_Write 19898
#define sipName_Write &sipStrings_Qt3DRender[19898]
#define sipNameNr_color 21834
#define sipName_color &sipStrings_Qt3DRender[21834]
#define sipNameNr_count 21840
#define sipName_count &sipStrings_Qt3DRender[21840]
#define sipNameNr_depth 21846
#define sipName_depth &sipStrings_Qt3DRender[21846]
#define sipNameNr_event 21852
#define sipName_event &sipStrings_Qt3DRender[21852]
#define sipNameNr_faces 21858
#define sipName_faces &sipStrings_Qt3DRender[21858]
#define sipNameNr_front 21864
#define sipName_front &sipStrings_Qt3DRender[21864]
#define sipNameNr_gamma 21870
#define sipName_gamma &sipStrings_Qt3DRender[21870]
#define sipNameNr_image 21876
#define sipName_image &sipStrings_Qt3DRender[21876]
#define sipNameNr_layer 21882
#define sipName_layer &sipStrings_Qt3DRender[21882]
#define sipNameNr_moved 21888
#define sipName_moved &sipStrings_Qt3DRender[21888]
#define sipNameNr_paint 21894
#define sipName_paint &sipStrings_Qt3DRender[21894]
#define sipNameNr_right 21900
#define sipName_right &sipStrings_Qt3DRender[21900]
#define sipNameNr_usage 21906
#define sipName_usage &sipStrings_Qt3DRender[21906]
#define sipNameNr_value 21912
#define sipName_value &sipStrings_Qt3DRender[21912]
#define sipNameNr_width 21918
#define sipName_width &sipStrings_Qt3DRender[21918]
#define sipNameNr_Back 17241
#define sipName_Back &sipStrings_Qt3DRender[17241]
#define sipNameNr_Byte 17371
#define sipName_Byte &sipStrings_Qt3DRender[17371]
#define sipNameNr_D32F 21924
#define sipName_D32F &sipStrings_Qt3DRender[21924]
#define sipNameNr_Fill 21929
#define sipName_Fill &sipStrings_Qt3DRender[21929]
#define sipNameNr_GLSL 21934
#define sipName_GLSL &sipStrings_Qt3DRender[21934]
#define sipNameNr_Keep 21939
#define sipName_Keep &sipStrings_Qt3DRender[21939]
#define sipNameNr_Less 18030
#define sipName_Less &sipStrings_Qt3DRender[18030]
#define sipNameNr_R16F 21944
#define sipName_R16F &sipStrings_Qt3DRender[21944]
#define sipNameNr_R16I 21949
#define sipName_R16I &sipStrings_Qt3DRender[21949]
#define sipNameNr_R16U 21954
#define sipName_R16U &sipStrings_Qt3DRender[21954]
#define sipNameNr_R32F 21959
#define sipName_R32F &sipStrings_Qt3DRender[21959]
#define sipNameNr_R32I 21964
#define sipName_R32I &sipStrings_Qt3DRender[21964]
#define sipNameNr_R32U 21969
#define sipName_R32U &sipStrings_Qt3DRender[21969]
#define sipNameNr_RG8I 21974
#define sipName_RG8I &sipStrings_Qt3DRender[21974]
#define sipNameNr_RG8U 21979
#define sipName_RG8U &sipStrings_Qt3DRender[21979]
#define sipNameNr_Read 18102
#define sipName_Read &sipStrings_Qt3DRender[18102]
#define sipNameNr_Type 979
#define sipName_Type &sipStrings_Qt3DRender[979]
#define sipNameNr_Zero 21984
#define sipName_Zero &sipStrings_Qt3DRender[21984]
#define sipNameNr_back 12515
#define sipName_back &sipStrings_Qt3DRender[12515]
#define sipNameNr_data 21989
#define sipName_data &sipStrings_Qt3DRender[21989]
#define sipNameNr_face 3081
#define sipName_face &sipStrings_Qt3DRender[3081]
#define sipNameNr_hits 21994
#define sipName_hits &sipStrings_Qt3DRender[21994]
#define sipNameNr_left 21999
#define sipName_left &sipStrings_Qt3DRender[21999]
#define sipNameNr_lens 22004
#define sipName_lens &sipStrings_Qt3DRender[22004]
#define sipNameNr_mode 22009
#define sipName_mode &sipStrings_Qt3DRender[22009]
#define sipNameNr_name 22014
#define sipName_name &sipStrings_Qt3DRender[22014]
#define sipNameNr_rect 22019
#define sipName_rect &sipStrings_Qt3DRender[22019]
#define sipNameNr_roll 22024
#define sipName_roll &sipStrings_Qt3DRender[22024]
#define sipNameNr_setX 22029
#define sipName_setX &sipStrings_Qt3DRender[22029]
#define sipNameNr_setY 22034
#define sipName_setY &sipStrings_Qt3DRender[22034]
#define sipNameNr_setZ 22039
#define sipName_setZ &sipStrings_Qt3DRender[22039]
#define sipNameNr_size 22044
#define sipName_size &sipStrings_Qt3DRender[22044]
#define sipNameNr_swap 22049
#define sipName_swap &sipStrings_Qt3DRender[22049]
#define sipNameNr_tilt 22054
#define sipName_tilt &sipStrings_Qt3DRender[22054]
#define sipNameNr_type 22059
#define sipName_type &sipStrings_Qt3DRender[22059]
#define sipNameNr_API 2972
#define sipName_API &sipStrings_Qt3DRender[2972]
#define sipNameNr_Add 22064
#define sipName_Add &sipStrings_Qt3DRender[22064]
#define sipNameNr_All 20705
#define sipName_All &sipStrings_Qt3DRender[20705]
#define sipNameNr_Api 3154
#define sipName_Api &sipStrings_Qt3DRender[3154]
#define sipNameNr_D16 22068
#define sipName_D16 &sipStrings_Qt3DRender[22068]
#define sipNameNr_D24 22072
#define sipName_D24 &sipStrings_Qt3DRender[22072]
#define sipNameNr_D32 22076
#define sipName_D32 &sipStrings_Qt3DRender[22076]
#define sipNameNr_Int 17879
#define sipName_Int &sipStrings_Qt3DRender[17879]
#define sipNameNr_Max 22080
#define sipName_Max &sipStrings_Qt3DRender[22080]
#define sipNameNr_Min 22084
#define sipName_Min &sipStrings_Qt3DRender[22084]
#define sipNameNr_One 22088
#define sipName_One &sipStrings_Qt3DRender[22088]
#define sipNameNr_R8I 22092
#define sipName_R8I &sipStrings_Qt3DRender[22092]
#define sipNameNr_R8U 22096
#define sipName_R8U &sipStrings_Qt3DRender[22096]
#define sipNameNr_RHI 22100
#define sipName_RHI &sipStrings_Qt3DRender[22100]
#define sipNameNr_api 22104
#define sipName_api &sipStrings_Qt3DRender[22104]
#define sipNameNr_log 22108
#define sipName_log &sipStrings_Qt3DRender[22108]
#define sipNameNr_pan 22112
#define sipName_pan &sipStrings_Qt3DRender[22112]
#define sipNameNr_top 22116
#define sipName_top &sipStrings_Qt3DRender[22116]
#define sipNameNr_uvw 22120
#define sipName_uvw &sipStrings_Qt3DRender[22120]
#define sipNameNr_id 21179
#define sipName_id &sipStrings_Qt3DRender[21179]
#define sipNameNr_x 11550
#define sipName_x &sipStrings_Qt3DRender[11550]
#define sipNameNr_y 1496
#define sipName_y &sipStrings_Qt3DRender[1496]
#define sipNameNr_z 22124
#define sipName_z &sipStrings_Qt3DRender[22124]

#define sipMalloc                   sipAPI_Qt3DRender->api_malloc
#define sipFree                     sipAPI_Qt3DRender->api_free
#define sipBuildResult              sipAPI_Qt3DRender->api_build_result
#define sipCallMethod               sipAPI_Qt3DRender->api_call_method
#define sipCallProcedureMethod      sipAPI_Qt3DRender->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_Qt3DRender->api_call_error_handler
#define sipParseResultEx            sipAPI_Qt3DRender->api_parse_result_ex
#define sipParseResult              sipAPI_Qt3DRender->api_parse_result
#define sipParseArgs                sipAPI_Qt3DRender->api_parse_args
#define sipParseKwdArgs             sipAPI_Qt3DRender->api_parse_kwd_args
#define sipParsePair                sipAPI_Qt3DRender->api_parse_pair
#define sipInstanceDestroyed        sipAPI_Qt3DRender->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_Qt3DRender->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_Qt3DRender->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_Qt3DRender->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_Qt3DRender->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_Qt3DRender->api_convert_to_void_ptr
#define sipAddException             sipAPI_Qt3DRender->api_add_exception
#define sipNoFunction               sipAPI_Qt3DRender->api_no_function
#define sipNoMethod                 sipAPI_Qt3DRender->api_no_method
#define sipAbstractMethod           sipAPI_Qt3DRender->api_abstract_method
#define sipBadClass                 sipAPI_Qt3DRender->api_bad_class
#define sipBadCatcherResult         sipAPI_Qt3DRender->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_Qt3DRender->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_Qt3DRender->api_bad_operator_arg
#define sipTrace                    sipAPI_Qt3DRender->api_trace
#define sipTransferBack             sipAPI_Qt3DRender->api_transfer_back
#define sipTransferTo               sipAPI_Qt3DRender->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_Qt3DRender->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_Qt3DRender->api_wrapper_type
#define sipWrapperType_Type         sipAPI_Qt3DRender->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_Qt3DRender->api_voidptr_type
#define sipGetPyObject              sipAPI_Qt3DRender->api_get_pyobject
#define sipGetAddress               sipAPI_Qt3DRender->api_get_address
#define sipGetMixinAddress          sipAPI_Qt3DRender->api_get_mixin_address
#define sipGetCppPtr                sipAPI_Qt3DRender->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_Qt3DRender->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_Qt3DRender->api_call_hook
#define sipEndThread                sipAPI_Qt3DRender->api_end_thread
#define sipRaiseUnknownException    sipAPI_Qt3DRender->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_Qt3DRender->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_Qt3DRender->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_Qt3DRender->api_add_type_instance
#define sipPySlotExtend             sipAPI_Qt3DRender->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_Qt3DRender->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_Qt3DRender->api_can_convert_to_type
#define sipConvertToType            sipAPI_Qt3DRender->api_convert_to_type
#define sipForceConvertToType       sipAPI_Qt3DRender->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_Qt3DRender->api_convert_to_enum
#define sipConvertToBool            sipAPI_Qt3DRender->api_convert_to_bool
#define sipReleaseType              sipAPI_Qt3DRender->api_release_type
#define sipConvertFromType          sipAPI_Qt3DRender->api_convert_from_type
#define sipConvertFromNewType       sipAPI_Qt3DRender->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_Qt3DRender->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_Qt3DRender->api_convert_from_enum
#define sipGetState                 sipAPI_Qt3DRender->api_get_state
#define sipExportSymbol             sipAPI_Qt3DRender->api_export_symbol
#define sipImportSymbol             sipAPI_Qt3DRender->api_import_symbol
#define sipFindType                 sipAPI_Qt3DRender->api_find_type
#define sipBytes_AsChar             sipAPI_Qt3DRender->api_bytes_as_char
#define sipBytes_AsString           sipAPI_Qt3DRender->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_Qt3DRender->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_Qt3DRender->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_Qt3DRender->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_Qt3DRender->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_Qt3DRender->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_Qt3DRender->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_Qt3DRender->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_Qt3DRender->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_Qt3DRender->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_Qt3DRender->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_Qt3DRender->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_Qt3DRender->api_get_reference
#define sipKeepReference            sipAPI_Qt3DRender->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_Qt3DRender->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_Qt3DRender->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_Qt3DRender->api_type_from_py_type_object
#define sipTypeScope                sipAPI_Qt3DRender->api_type_scope
#define sipResolveTypedef           sipAPI_Qt3DRender->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_Qt3DRender->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_Qt3DRender->api_enable_autoconversion
#define sipInitMixin                sipAPI_Qt3DRender->api_init_mixin
#define sipExportModule             sipAPI_Qt3DRender->api_export_module
#define sipInitModule               sipAPI_Qt3DRender->api_init_module
#define sipGetInterpreter           sipAPI_Qt3DRender->api_get_interpreter
#define sipSetTypeUserData          sipAPI_Qt3DRender->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_Qt3DRender->api_get_type_user_data
#define sipPyTypeDict               sipAPI_Qt3DRender->api_py_type_dict
#define sipPyTypeName               sipAPI_Qt3DRender->api_py_type_name
#define sipGetCFunction             sipAPI_Qt3DRender->api_get_c_function
#define sipGetMethod                sipAPI_Qt3DRender->api_get_method
#define sipFromMethod               sipAPI_Qt3DRender->api_from_method
#define sipGetDate                  sipAPI_Qt3DRender->api_get_date
#define sipFromDate                 sipAPI_Qt3DRender->api_from_date
#define sipGetDateTime              sipAPI_Qt3DRender->api_get_datetime
#define sipFromDateTime             sipAPI_Qt3DRender->api_from_datetime
#define sipGetTime                  sipAPI_Qt3DRender->api_get_time
#define sipFromTime                 sipAPI_Qt3DRender->api_from_time
#define sipIsUserType               sipAPI_Qt3DRender->api_is_user_type
#define sipCheckPluginForType       sipAPI_Qt3DRender->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_Qt3DRender->api_unicode_new
#define sipUnicodeWrite             sipAPI_Qt3DRender->api_unicode_write
#define sipUnicodeData              sipAPI_Qt3DRender->api_unicode_data
#define sipGetBufferInfo            sipAPI_Qt3DRender->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_Qt3DRender->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_Qt3DRender->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_Qt3DRender->api_is_derived_class
#define sipGetUserObject            sipAPI_Qt3DRender->api_get_user_object
#define sipSetUserObject            sipAPI_Qt3DRender->api_set_user_object
#define sipRegisterEventHandler     sipAPI_Qt3DRender->api_register_event_handler
#define sipConvertToArray           sipAPI_Qt3DRender->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_Qt3DRender->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_Qt3DRender->api_enable_gc
#define sipPrintObject              sipAPI_Qt3DRender->api_print_object
#define sipLong_AsChar              sipAPI_Qt3DRender->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_Qt3DRender->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_Qt3DRender->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_Qt3DRender->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_Qt3DRender->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_Qt3DRender->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_Qt3DRender->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_Qt3DRender->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_Qt3DRender->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_Qt3DRender->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_Qt3DRender->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_Qt3DRender->api_long_as_size_t
#define sipVisitWrappers            sipAPI_Qt3DRender->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_Qt3DRender->api_register_exit_notifier
#define sipDeprecated               sipAPI_Qt3DRender->api_deprecated
#define sipPyTypeDictRef            sipAPI_Qt3DRender->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_Qt3DRender->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_Qt3DRender->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_Qt3DRender->api_get_frame
#define sipSetDestroyOnExit         sipAPI_Qt3DRender->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_Qt3DRender->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_Qt3DRender->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_Qt3DRender->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_Qt3DRender->api_connect_rx
#define sipConvertRx                sipAPI_Qt3DRender->api_convert_rx
#define sipDisconnectRx             sipAPI_Qt3DRender->api_disconnect_rx
#define sipFreeSipslot              sipAPI_Qt3DRender->api_free_sipslot
#define sipInvokeSlot               sipAPI_Qt3DRender->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_Qt3DRender->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_Qt3DRender->api_same_slot
#define sipSaveSlot                 sipAPI_Qt3DRender->api_save_slot
#define sipVisitSlot                sipAPI_Qt3DRender->api_visit_slot
#define sipIsPyMethod               sipAPI_Qt3DRender->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_Qt3DRender[];


#define sipType_Qt3DRender_QAbstractFunctor sipExportedTypes_Qt3DRender[21]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QAbstractFunctor;

#define sipType_Qt3DRender_QAbstractLight sipExportedTypes_Qt3DRender[22]

#define sipType_Qt3DRender_QAbstractLight_Type sipExportedTypes_Qt3DRender[23]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QAbstractLight;

#define sipType_Qt3DRender_QAbstractRayCaster sipExportedTypes_Qt3DRender[24]

#define sipType_Qt3DRender_QAbstractRayCaster_FilterMode sipExportedTypes_Qt3DRender[25]

#define sipType_Qt3DRender_QAbstractRayCaster_RunMode sipExportedTypes_Qt3DRender[26]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QAbstractRayCaster;

#define sipType_Qt3DRender_QAbstractTexture sipExportedTypes_Qt3DRender[27]

#define sipType_Qt3DRender_QAbstractTexture_HandleType sipExportedTypes_Qt3DRender[32]

#define sipType_Qt3DRender_QAbstractTexture_ComparisonMode sipExportedTypes_Qt3DRender[29]

#define sipType_Qt3DRender_QAbstractTexture_ComparisonFunction sipExportedTypes_Qt3DRender[28]

#define sipType_Qt3DRender_QAbstractTexture_CubeMapFace sipExportedTypes_Qt3DRender[30]

#define sipType_Qt3DRender_QAbstractTexture_Filter sipExportedTypes_Qt3DRender[31]

#define sipType_Qt3DRender_QAbstractTexture_TextureFormat sipExportedTypes_Qt3DRender[35]

#define sipType_Qt3DRender_QAbstractTexture_Target sipExportedTypes_Qt3DRender[34]

#define sipType_Qt3DRender_QAbstractTexture_Status sipExportedTypes_Qt3DRender[33]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QAbstractTexture;

#define sipType_Qt3DRender_QAbstractTextureImage sipExportedTypes_Qt3DRender[36]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QAbstractTextureImage;

#define sipType_Qt3DRender_QRenderState sipExportedTypes_Qt3DRender[141]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QRenderState;

#define sipType_Qt3DRender_QAlphaCoverage sipExportedTypes_Qt3DRender[37]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QAlphaCoverage;

#define sipType_Qt3DRender_QAlphaTest sipExportedTypes_Qt3DRender[38]

#define sipType_Qt3DRender_QAlphaTest_AlphaFunction sipExportedTypes_Qt3DRender[39]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QAlphaTest;

#define sipType_Qt3DRender_QAttribute sipExportedTypes_Qt3DRender[40]

#define sipType_Qt3DRender_QAttribute_VertexBaseType sipExportedTypes_Qt3DRender[42]

#define sipType_Qt3DRender_QAttribute_AttributeType sipExportedTypes_Qt3DRender[41]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QAttribute;

#define sipType_Qt3DRender_QBlendEquation sipExportedTypes_Qt3DRender[43]

#define sipType_Qt3DRender_QBlendEquation_BlendFunction sipExportedTypes_Qt3DRender[44]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QBlendEquation;

#define sipType_Qt3DRender_QBlendEquationArguments sipExportedTypes_Qt3DRender[45]

#define sipType_Qt3DRender_QBlendEquationArguments_Blending sipExportedTypes_Qt3DRender[46]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QBlendEquationArguments;

#define sipType_Qt3DRender_QFrameGraphNode sipExportedTypes_Qt3DRender[77]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QFrameGraphNode;

#define sipType_Qt3DRender_QBlitFramebuffer sipExportedTypes_Qt3DRender[47]

#define sipType_Qt3DRender_QBlitFramebuffer_InterpolationMethod sipExportedTypes_Qt3DRender[48]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QBlitFramebuffer;

#define sipType_Qt3DRender_QBuffer sipExportedTypes_Qt3DRender[49]

#define sipType_Qt3DRender_QBuffer_AccessType sipExportedTypes_Qt3DRender[50]

#define sipType_Qt3DRender_QBuffer_UsageType sipExportedTypes_Qt3DRender[52]

#define sipType_Qt3DRender_QBuffer_BufferType sipExportedTypes_Qt3DRender[51]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QBuffer;

#define sipType_Qt3DRender_QBufferDataGenerator sipExportedTypes_Qt3DRender[53]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QBufferDataGenerator;

#define sipType_Qt3DRender_QCamera sipExportedTypes_Qt3DRender[54]

#define sipType_Qt3DRender_QCamera_CameraTranslationOption sipExportedTypes_Qt3DRender[55]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QCamera;

#define sipType_Qt3DRender_QCameraLens sipExportedTypes_Qt3DRender[56]

#define sipType_Qt3DRender_QCameraLens_ProjectionType sipExportedTypes_Qt3DRender[57]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QCameraLens;

#define sipType_Qt3DRender_QCameraSelector sipExportedTypes_Qt3DRender[58]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QCameraSelector;

#define sipType_Qt3DRender_QClearBuffers sipExportedTypes_Qt3DRender[59]

#define sipType_Qt3DRender_QClearBuffers_BufferType sipExportedTypes_Qt3DRender[60]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QClearBuffers;

#define sipType_Qt3DRender_QClearBuffers_BufferTypeFlags sipExportedTypes_Qt3DRender[61]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QClearBuffers_BufferTypeFlags;

#define sipType_Qt3DRender_QClipPlane sipExportedTypes_Qt3DRender[62]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QClipPlane;

#define sipType_Qt3DRender_QComputeCommand sipExportedTypes_Qt3DRender[64]

#define sipType_Qt3DRender_QComputeCommand_RunType sipExportedTypes_Qt3DRender[65]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QComputeCommand;

#define sipType_Qt3DRender_QColorMask sipExportedTypes_Qt3DRender[63]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QColorMask;

#define sipType_Qt3DRender_QCullFace sipExportedTypes_Qt3DRender[66]

#define sipType_Qt3DRender_QCullFace_CullingMode sipExportedTypes_Qt3DRender[67]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QCullFace;

#define sipType_Qt3DRender_QDepthRange sipExportedTypes_Qt3DRender[68]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QDepthRange;

#define sipType_Qt3DRender_QDepthTest sipExportedTypes_Qt3DRender[69]

#define sipType_Qt3DRender_QDepthTest_DepthFunction sipExportedTypes_Qt3DRender[70]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QDepthTest;

#define sipType_Qt3DRender_QDirectionalLight sipExportedTypes_Qt3DRender[71]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QDirectionalLight;

#define sipType_Qt3DRender_QDispatchCompute sipExportedTypes_Qt3DRender[72]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QDispatchCompute;

#define sipType_Qt3DRender_QDithering sipExportedTypes_Qt3DRender[73]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QDithering;

#define sipType_Qt3DRender_QEffect sipExportedTypes_Qt3DRender[74]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QEffect;

#define sipType_Qt3DRender_QEnvironmentLight sipExportedTypes_Qt3DRender[75]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QEnvironmentLight;

#define sipType_Qt3DRender_QFilterKey sipExportedTypes_Qt3DRender[76]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QFilterKey;

#define sipType_Qt3DRender_QFrontFace sipExportedTypes_Qt3DRender[78]

#define sipType_Qt3DRender_QFrontFace_WindingDirection sipExportedTypes_Qt3DRender[79]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QFrontFace;

#define sipType_Qt3DRender_QFrustumCulling sipExportedTypes_Qt3DRender[80]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QFrustumCulling;

#define sipType_Qt3DRender_QGeometry sipExportedTypes_Qt3DRender[81]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QGeometry;

#define sipType_Qt3DRender_QGeometryFactory sipExportedTypes_Qt3DRender[82]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QGeometryFactory;

#define sipType_Qt3DRender_QGeometryRenderer sipExportedTypes_Qt3DRender[83]

#define sipType_Qt3DRender_QGeometryRenderer_PrimitiveType sipExportedTypes_Qt3DRender[84]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QGeometryRenderer;

#define sipType_Qt3DRender_QGraphicsApiFilter sipExportedTypes_Qt3DRender[85]

#define sipType_Qt3DRender_QGraphicsApiFilter_OpenGLProfile sipExportedTypes_Qt3DRender[87]

#define sipType_Qt3DRender_QGraphicsApiFilter_Api sipExportedTypes_Qt3DRender[86]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QGraphicsApiFilter;

#define sipType_Qt3DRender_QLayer sipExportedTypes_Qt3DRender[88]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QLayer;

#define sipType_Qt3DRender_QLayerFilter sipExportedTypes_Qt3DRender[89]

#define sipType_Qt3DRender_QLayerFilter_FilterMode sipExportedTypes_Qt3DRender[90]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QLayerFilter;

#define sipType_Qt3DRender_QLevelOfDetail sipExportedTypes_Qt3DRender[91]

#define sipType_Qt3DRender_QLevelOfDetail_ThresholdType sipExportedTypes_Qt3DRender[92]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QLevelOfDetail;

#define sipType_Qt3DRender_QLevelOfDetailBoundingSphere sipExportedTypes_Qt3DRender[93]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QLevelOfDetailBoundingSphere;

#define sipType_Qt3DRender_QLevelOfDetailSwitch sipExportedTypes_Qt3DRender[94]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QLevelOfDetailSwitch;

#define sipType_Qt3DRender_QLineWidth sipExportedTypes_Qt3DRender[95]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QLineWidth;

#define sipType_Qt3DRender_QMaterial sipExportedTypes_Qt3DRender[96]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QMaterial;

#define sipType_Qt3DRender_QMemoryBarrier sipExportedTypes_Qt3DRender[97]

#define sipType_Qt3DRender_QMemoryBarrier_Operation sipExportedTypes_Qt3DRender[98]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QMemoryBarrier;

#define sipType_Qt3DRender_QMemoryBarrier_Operations sipExportedTypes_Qt3DRender[99]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QMemoryBarrier_Operations;

#define sipType_Qt3DRender_QMesh sipExportedTypes_Qt3DRender[100]

#define sipType_Qt3DRender_QMesh_Status sipExportedTypes_Qt3DRender[101]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QMesh;

#define sipType_Qt3DRender_QMultiSampleAntiAliasing sipExportedTypes_Qt3DRender[102]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QMultiSampleAntiAliasing;

#define sipType_Qt3DRender_QNoDepthMask sipExportedTypes_Qt3DRender[103]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QNoDepthMask;

#define sipType_Qt3DRender_QNoDraw sipExportedTypes_Qt3DRender[104]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QNoDraw;

#define sipType_Qt3DRender_QNoPicking sipExportedTypes_Qt3DRender[105]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QNoPicking;

#define sipType_Qt3DRender_QObjectPicker sipExportedTypes_Qt3DRender[106]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QObjectPicker;

#define sipType_Qt3DRender_QPaintedTextureImage sipExportedTypes_Qt3DRender[107]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QPaintedTextureImage;

#define sipType_Qt3DRender_QParameter sipExportedTypes_Qt3DRender[108]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QParameter;

#define sipType_Qt3DRender_QPickEvent sipExportedTypes_Qt3DRender[109]

#define sipType_Qt3DRender_QPickEvent_Modifiers sipExportedTypes_Qt3DRender[111]

#define sipType_Qt3DRender_QPickEvent_Buttons sipExportedTypes_Qt3DRender[110]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QPickEvent;

#define sipType_Qt3DRender_QPickingSettings sipExportedTypes_Qt3DRender[115]

#define sipType_Qt3DRender_QPickingSettings_FaceOrientationPickingMode sipExportedTypes_Qt3DRender[116]

#define sipType_Qt3DRender_QPickingSettings_PickResultMode sipExportedTypes_Qt3DRender[118]

#define sipType_Qt3DRender_QPickingSettings_PickMethod sipExportedTypes_Qt3DRender[117]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QPickingSettings;

#define sipType_Qt3DRender_QPickLineEvent sipExportedTypes_Qt3DRender[112]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QPickLineEvent;

#define sipType_Qt3DRender_QPickPointEvent sipExportedTypes_Qt3DRender[113]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QPickPointEvent;

#define sipType_Qt3DRender_QPickTriangleEvent sipExportedTypes_Qt3DRender[114]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QPickTriangleEvent;

#define sipType_Qt3DRender_QPointLight sipExportedTypes_Qt3DRender[119]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QPointLight;

#define sipType_Qt3DRender_QPointSize sipExportedTypes_Qt3DRender[120]

#define sipType_Qt3DRender_QPointSize_SizeMode sipExportedTypes_Qt3DRender[121]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QPointSize;

#define sipType_Qt3DRender_QPolygonOffset sipExportedTypes_Qt3DRender[122]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QPolygonOffset;

#define sipType_Qt3DRender_QProximityFilter sipExportedTypes_Qt3DRender[123]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QProximityFilter;

#define sipType_Qt3DRender_QRasterMode sipExportedTypes_Qt3DRender[124]

#define sipType_Qt3DRender_QRasterMode_FaceMode sipExportedTypes_Qt3DRender[125]

#define sipType_Qt3DRender_QRasterMode_RasterMode sipExportedTypes_Qt3DRender[126]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QRasterMode;

#define sipType_Qt3DRender_QRayCaster sipExportedTypes_Qt3DRender[127]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QRayCaster;

#define sipType_Qt3DRender_QRayCasterHit sipExportedTypes_Qt3DRender[128]

#define sipType_Qt3DRender_QRayCasterHit_HitType sipExportedTypes_Qt3DRender[129]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QRayCasterHit;

#define sipType_Qt3DRender_Render sipExportedTypes_Qt3DRender[206]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_Render;

#define sipType_Qt3DRender_QRenderAspect sipExportedTypes_Qt3DRender[130]

#define sipType_Qt3DRender_QRenderAspect_RenderType sipExportedTypes_Qt3DRender[131]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QRenderAspect;

#define sipType_Qt3DRender_QRenderCapabilities sipExportedTypes_Qt3DRender[132]

#define sipType_Qt3DRender_QRenderCapabilities_Profile sipExportedTypes_Qt3DRender[134]

#define sipType_Qt3DRender_QRenderCapabilities_API sipExportedTypes_Qt3DRender[133]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QRenderCapabilities;

#define sipType_Qt3DRender_QRenderCaptureReply sipExportedTypes_Qt3DRender[136]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QRenderCaptureReply;

#define sipType_Qt3DRender_QRenderCapture sipExportedTypes_Qt3DRender[135]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QRenderCapture;

#define sipType_Qt3DRender_QRenderPass sipExportedTypes_Qt3DRender[137]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QRenderPass;

#define sipType_Qt3DRender_QRenderPassFilter sipExportedTypes_Qt3DRender[138]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QRenderPassFilter;

#define sipType_Qt3DRender_QRenderSettings sipExportedTypes_Qt3DRender[139]

#define sipType_Qt3DRender_QRenderSettings_RenderPolicy sipExportedTypes_Qt3DRender[140]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QRenderSettings;

#define sipType_Qt3DRender_QRenderStateSet sipExportedTypes_Qt3DRender[142]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QRenderStateSet;

#define sipType_Qt3DRender_QRenderSurfaceSelector sipExportedTypes_Qt3DRender[143]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QRenderSurfaceSelector;

#define sipType_Qt3DRender_QRenderTarget sipExportedTypes_Qt3DRender[144]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QRenderTarget;

#define sipType_Qt3DRender_QRenderTargetOutput sipExportedTypes_Qt3DRender[145]

#define sipType_Qt3DRender_QRenderTargetOutput_AttachmentPoint sipExportedTypes_Qt3DRender[146]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QRenderTargetOutput;

#define sipType_Qt3DRender_QRenderTargetSelector sipExportedTypes_Qt3DRender[147]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QRenderTargetSelector;

#define sipType_Qt3DRender_QSceneLoader sipExportedTypes_Qt3DRender[148]

#define sipType_Qt3DRender_QSceneLoader_ComponentType sipExportedTypes_Qt3DRender[149]

#define sipType_Qt3DRender_QSceneLoader_Status sipExportedTypes_Qt3DRender[150]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QSceneLoader;

#define sipType_Qt3DRender_QScissorTest sipExportedTypes_Qt3DRender[151]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QScissorTest;

#define sipType_Qt3DRender_QScreenRayCaster sipExportedTypes_Qt3DRender[152]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QScreenRayCaster;

#define sipType_Qt3DRender_QSeamlessCubemap sipExportedTypes_Qt3DRender[153]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QSeamlessCubemap;

#define sipType_Qt3DRender_QSetFence sipExportedTypes_Qt3DRender[154]

#define sipType_Qt3DRender_QSetFence_HandleType sipExportedTypes_Qt3DRender[155]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QSetFence;

#define sipType_Qt3DRender_PropertyReaderInterface sipExportedTypes_Qt3DRender[20]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_PropertyReaderInterface;

#define sipType_Qt3DRender_QShaderData sipExportedTypes_Qt3DRender[156]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QShaderData;

#define sipType_Qt3DRender_QShaderImage sipExportedTypes_Qt3DRender[157]

#define sipType_Qt3DRender_QShaderImage_ImageFormat sipExportedTypes_Qt3DRender[159]

#define sipType_Qt3DRender_QShaderImage_Access sipExportedTypes_Qt3DRender[158]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QShaderImage;

#define sipType_Qt3DRender_QShaderProgram sipExportedTypes_Qt3DRender[160]

#define sipType_Qt3DRender_QShaderProgram_Format sipExportedTypes_Qt3DRender[161]

#define sipType_Qt3DRender_QShaderProgram_Status sipExportedTypes_Qt3DRender[163]

#define sipType_Qt3DRender_QShaderProgram_ShaderType sipExportedTypes_Qt3DRender[162]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QShaderProgram;

#define sipType_Qt3DRender_QShaderProgramBuilder sipExportedTypes_Qt3DRender[164]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QShaderProgramBuilder;

#define sipType_Qt3DRender_QSortPolicy sipExportedTypes_Qt3DRender[166]

#define sipType_Qt3DRender_QSortPolicy_SortType sipExportedTypes_Qt3DRender[167]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QSortPolicy;

#define sipType_Qt3DRender_QSpotLight sipExportedTypes_Qt3DRender[168]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QSpotLight;

#define sipType_Qt3DRender_QStencilMask sipExportedTypes_Qt3DRender[169]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QStencilMask;

#define sipType_Qt3DRender_QStencilOperation sipExportedTypes_Qt3DRender[170]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QStencilOperation;

#define sipType_Qt3DRender_QStencilOperationArguments sipExportedTypes_Qt3DRender[171]

#define sipType_Qt3DRender_QStencilOperationArguments_Operation sipExportedTypes_Qt3DRender[173]

#define sipType_Qt3DRender_QStencilOperationArguments_FaceMode sipExportedTypes_Qt3DRender[172]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QStencilOperationArguments;

#define sipType_Qt3DRender_QStencilTest sipExportedTypes_Qt3DRender[174]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QStencilTest;

#define sipType_Qt3DRender_QStencilTestArguments sipExportedTypes_Qt3DRender[175]

#define sipType_Qt3DRender_QStencilTestArguments_StencilFunction sipExportedTypes_Qt3DRender[177]

#define sipType_Qt3DRender_QStencilTestArguments_StencilFaceMode sipExportedTypes_Qt3DRender[176]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QStencilTestArguments;

#define sipType_Qt3DRender_QSubtreeEnabler sipExportedTypes_Qt3DRender[178]

#define sipType_Qt3DRender_QSubtreeEnabler_Enablement sipExportedTypes_Qt3DRender[179]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QSubtreeEnabler;

#define sipType_Qt3DRender_QTechnique sipExportedTypes_Qt3DRender[180]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QTechnique;

#define sipType_Qt3DRender_QTechniqueFilter sipExportedTypes_Qt3DRender[181]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QTechniqueFilter;

#define sipType_Qt3DRender_QTexture1D sipExportedTypes_Qt3DRender[182]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QTexture1D;

#define sipType_Qt3DRender_QTexture1DArray sipExportedTypes_Qt3DRender[183]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QTexture1DArray;

#define sipType_Qt3DRender_QTexture2D sipExportedTypes_Qt3DRender[184]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QTexture2D;

#define sipType_Qt3DRender_QTexture2DArray sipExportedTypes_Qt3DRender[185]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QTexture2DArray;

#define sipType_Qt3DRender_QTexture3D sipExportedTypes_Qt3DRender[188]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QTexture3D;

#define sipType_Qt3DRender_QTextureCubeMap sipExportedTypes_Qt3DRender[190]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QTextureCubeMap;

#define sipType_Qt3DRender_QTextureCubeMapArray sipExportedTypes_Qt3DRender[191]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QTextureCubeMapArray;

#define sipType_Qt3DRender_QTexture2DMultisample sipExportedTypes_Qt3DRender[186]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QTexture2DMultisample;

#define sipType_Qt3DRender_QTexture2DMultisampleArray sipExportedTypes_Qt3DRender[187]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QTexture2DMultisampleArray;

#define sipType_Qt3DRender_QTextureRectangle sipExportedTypes_Qt3DRender[200]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QTextureRectangle;

#define sipType_Qt3DRender_QTextureBuffer sipExportedTypes_Qt3DRender[189]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QTextureBuffer;

#define sipType_Qt3DRender_QTextureLoader sipExportedTypes_Qt3DRender[199]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QTextureLoader;

#define sipType_Qt3DRender_QSharedGLTexture sipExportedTypes_Qt3DRender[165]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QSharedGLTexture;

#define sipType_Qt3DRender_QTextureData sipExportedTypes_Qt3DRender[192]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QTextureData;

#define sipType_Qt3DRender_QTextureDataUpdate sipExportedTypes_Qt3DRender[193]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QTextureDataUpdate;

#define sipType_Qt3DRender_QTextureGenerator sipExportedTypes_Qt3DRender[194]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QTextureGenerator;

#define sipType_Qt3DRender_QTextureImage sipExportedTypes_Qt3DRender[195]

#define sipType_Qt3DRender_QTextureImage_Status sipExportedTypes_Qt3DRender[196]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QTextureImage;

#define sipType_Qt3DRender_QTextureImageData sipExportedTypes_Qt3DRender[197]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QTextureImageData;

#define sipType_Qt3DRender_QTextureImageDataGenerator sipExportedTypes_Qt3DRender[198]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QTextureImageDataGenerator;

#define sipType_Qt3DRender_QTextureWrapMode sipExportedTypes_Qt3DRender[201]

#define sipType_Qt3DRender_QTextureWrapMode_WrapMode sipExportedTypes_Qt3DRender[202]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QTextureWrapMode;

#define sipType_Qt3DRender_QViewport sipExportedTypes_Qt3DRender[203]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QViewport;

#define sipType_Qt3DRender_QWaitFence sipExportedTypes_Qt3DRender[204]

#define sipType_Qt3DRender_QWaitFence_HandleType sipExportedTypes_Qt3DRender[205]

extern sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QWaitFence;

#define sipType_QVector_0101Qt3DRender_QRenderPass sipExportedTypes_Qt3DRender[13]

extern sipMappedTypeDef sipTypeDef_Qt3DRender_QVector_0101Qt3DRender_QRenderPass;

#define sipType_QVector_0101Qt3DRender_QRenderTargetOutput sipExportedTypes_Qt3DRender[15]

extern sipMappedTypeDef sipTypeDef_Qt3DRender_QVector_0101Qt3DRender_QRenderTargetOutput;

#define sipType_QVector_0101Qt3DRender_QRenderState sipExportedTypes_Qt3DRender[14]

extern sipMappedTypeDef sipTypeDef_Qt3DRender_QVector_0101Qt3DRender_QRenderState;

#define sipType_QVector_0101Qt3DRender_QFilterKey sipExportedTypes_Qt3DRender[9]

extern sipMappedTypeDef sipTypeDef_Qt3DRender_QVector_0101Qt3DRender_QFilterKey;

#define sipType_QVector_0101Qt3DRender_QAttribute sipExportedTypes_Qt3DRender[8]

extern sipMappedTypeDef sipTypeDef_Qt3DRender_QVector_0101Qt3DRender_QAttribute;

#define sipType_QVector_0101Qt3DRender_QTechnique sipExportedTypes_Qt3DRender[18]

extern sipMappedTypeDef sipTypeDef_Qt3DRender_QVector_0101Qt3DRender_QTechnique;

#define sipType_QVector_0101Qt3DRender_QParameter sipExportedTypes_Qt3DRender[11]

extern sipMappedTypeDef sipTypeDef_Qt3DRender_QVector_0101Qt3DRender_QParameter;

#define sipType_QVector_0101Qt3DRender_QAbstractTextureImage sipExportedTypes_Qt3DRender[7]

extern sipMappedTypeDef sipTypeDef_Qt3DRender_QVector_0101Qt3DRender_QAbstractTextureImage;

#define sipType_QVector_0101Qt3DRender_QLayer sipExportedTypes_Qt3DRender[10]

extern sipMappedTypeDef sipTypeDef_Qt3DRender_QVector_0101Qt3DRender_QLayer;

#define sipType_QSharedPointer_0100Qt3DRender_QTextureImageData sipExportedTypes_Qt3DRender[5]

extern sipMappedTypeDef sipTypeDef_Qt3DRender_QSharedPointer_0100Qt3DRender_QTextureImageData;

#define sipType_QSharedPointer_0100Qt3DRender_QTextureImageDataGenerator sipExportedTypes_Qt3DRender[6]

extern sipMappedTypeDef sipTypeDef_Qt3DRender_QSharedPointer_0100Qt3DRender_QTextureImageDataGenerator;

#define sipType_QSharedPointer_0100Qt3DRender_QTextureGenerator sipExportedTypes_Qt3DRender[4]

extern sipMappedTypeDef sipTypeDef_Qt3DRender_QSharedPointer_0100Qt3DRender_QTextureGenerator;

#define sipType_QSharedPointer_0100Qt3DRender_QTextureData sipExportedTypes_Qt3DRender[3]

extern sipMappedTypeDef sipTypeDef_Qt3DRender_QSharedPointer_0100Qt3DRender_QTextureData;

#define sipType_QSharedPointer_0100Qt3DRender_QGeometryFactory sipExportedTypes_Qt3DRender[2]

extern sipMappedTypeDef sipTypeDef_Qt3DRender_QSharedPointer_0100Qt3DRender_QGeometryFactory;

#define sipType_QSharedPointer_0100Qt3DRender_QBufferDataGenerator sipExportedTypes_Qt3DRender[1]

extern sipMappedTypeDef sipTypeDef_Qt3DRender_QSharedPointer_0100Qt3DRender_QBufferDataGenerator;

#define sipType_QVector_0100Qt3DRender_QRayCasterHit sipExportedTypes_Qt3DRender[12]

extern sipMappedTypeDef sipTypeDef_Qt3DRender_QVector_0100Qt3DRender_QRayCasterHit;

#define sipType_QSharedPointer_0100Qt3DRender_PropertyReaderInterface sipExportedTypes_Qt3DRender[0]

extern sipMappedTypeDef sipTypeDef_Qt3DRender_QSharedPointer_0100Qt3DRender_PropertyReaderInterface;

#define sipType_QVector_0100Qt3DRender_QSortPolicy_SortType sipExportedTypes_Qt3DRender[17]

extern sipMappedTypeDef sipTypeDef_Qt3DRender_QVector_0100Qt3DRender_QSortPolicy_SortType;

#define sipType_QVector_0100Qt3DRender_QRenderTargetOutput_AttachmentPoint sipExportedTypes_Qt3DRender[16]

extern sipMappedTypeDef sipTypeDef_Qt3DRender_QVector_0100Qt3DRender_QRenderTargetOutput_AttachmentPoint;

#define sipType_QVector_0100Qt3DRender_QTextureImageDataPtr sipExportedTypes_Qt3DRender[19]

extern sipMappedTypeDef sipTypeDef_Qt3DRender_QVector_0100Qt3DRender_QTextureImageDataPtr;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_Qt3DRender;
extern sipExportedModuleDef sipModuleAPI_Qt3DRender;
extern sipTypeDef *sipExportedTypes_Qt3DRender[];

#define sipType_QObject sipImportedTypes_Qt3DRender_QtCore[4].it_td

#define sipType_QByteArray sipImportedTypes_Qt3DRender_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_Qt3DRender_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_Qt3DRender_QtCore[12].it_td

#define sipType_QChildEvent sipImportedTypes_Qt3DRender_QtCore[1].it_td

#define sipType_QMetaMethod sipImportedTypes_Qt3DRender_QtCore[3].it_td

#define sipType_QPoint sipImportedTypes_Qt3DRender_QtCore[5].it_td

#define sipType_QPointF sipImportedTypes_Qt3DRender_QtCore[6].it_td

#define sipType_QRect sipImportedTypes_Qt3DRender_QtCore[7].it_td

#define sipType_QRectF sipImportedTypes_Qt3DRender_QtCore[8].it_td

#define sipType_QSize sipImportedTypes_Qt3DRender_QtCore[9].it_td

#define sipType_QUrl sipImportedTypes_Qt3DRender_QtCore[13].it_td

#define sipType_QVariant sipImportedTypes_Qt3DRender_QtCore[14].it_td

#define sipType_QVector_1800 sipImportedTypes_Qt3DRender_QtCore[15].it_td

#define sipType_QStringList sipImportedTypes_Qt3DRender_QtCore[11].it_td

#define sipType_QString sipImportedTypes_Qt3DRender_QtCore[10].it_td

#define sipType_qintptr sipImportedTypes_Qt3DRender_QtCore[16].it_td
extern sipImportedTypeDef sipImportedTypes_Qt3DRender_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_Qt3DRender_QtCore[];

#define sipType_QColor sipImportedTypes_Qt3DRender_QtGui[0].it_td

#define sipType_QImage sipImportedTypes_Qt3DRender_QtGui[1].it_td

#define sipType_QMatrix4x4 sipImportedTypes_Qt3DRender_QtGui[2].it_td

#define sipType_QOpenGLTexture_PixelType sipImportedTypes_Qt3DRender_QtGui[4].it_td

#define sipType_QOpenGLTexture_PixelFormat sipImportedTypes_Qt3DRender_QtGui[3].it_td

#define sipType_QOpenGLTexture_TextureFormat sipImportedTypes_Qt3DRender_QtGui[6].it_td

#define sipType_QOpenGLTexture_Target sipImportedTypes_Qt3DRender_QtGui[5].it_td

#define sipType_QPainter sipImportedTypes_Qt3DRender_QtGui[7].it_td

#define sipType_QQuaternion sipImportedTypes_Qt3DRender_QtGui[8].it_td

#define sipType_QVector3D sipImportedTypes_Qt3DRender_QtGui[9].it_td

#define sipType_QVector_2400 sipImportedTypes_Qt3DRender_QtGui[10].it_td
extern sipImportedTypeDef sipImportedTypes_Qt3DRender_QtGui[];

#define sipType_Qt3DCore_QAbstractAspect sipImportedTypes_Qt3DRender_Qt3DCore[1].it_td

#define sipType_Qt3DCore_QNode sipImportedTypes_Qt3DRender_Qt3DCore[4].it_td

#define sipType_Qt3DCore_QComponent sipImportedTypes_Qt3DRender_Qt3DCore[2].it_td

#define sipType_Qt3DCore_QEntity sipImportedTypes_Qt3DRender_Qt3DCore[3].it_td

#define sipType_Qt3DCore_QNodeId sipImportedTypes_Qt3DRender_Qt3DCore[5].it_td

#define sipType_Qt3DCore_QTransform sipImportedTypes_Qt3DRender_Qt3DCore[6].it_td

#define sipType_QSharedPointer_0100Qt3DCore_QSceneChange sipImportedTypes_Qt3DRender_Qt3DCore[0].it_td
extern sipImportedTypeDef sipImportedTypes_Qt3DRender_Qt3DCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_Qt3DRender_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_Qt3DRender_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_Qt3DRender_qt_metacast;
#line 100 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"

#include <qsharedpointer.h>


// The dtor for the saved QSharedPointer.
#if defined(SIP_USE_PYCAPSULE)
template<class T>
void qt3d_QspDtor(PyObject *capsule)
{
    delete reinterpret_cast<QSharedPointer<T> *>(
            PyCapsule_GetPointer(capsule, 0));
}
#else
template<class T>
void qt3d_QspDtor(void *shared)
{
    delete reinterpret_cast<QSharedPointer<T> *>(array);
}
#endif


template<class T>
bool qt3d_SaveQsp(PyObject *py, QSharedPointer<T> *qsp)
{
    // Wrap the copy in a Python object.
#if defined(SIP_USE_PYCAPSULE)
    PyObject *qsp_obj = PyCapsule_New(qsp, 0, qt3d_QspDtor<T>);
#else
    PyObject *qsp_obj = PyCObject_FromVoidPtr(qsp, qt3d_QspDto<T>r);
#endif

    if (!qsp_obj)
        return false;

    sipSetUserObject((sipSimpleWrapper *)py, qsp_obj);

    return true;
}

#line 4070 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipAPIQt3DRender.h"

#endif
